@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -26,11 +26,7 @@
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qtextstream.h>
-#include <kapp.h>
-#if KDE_VERSION_MAJOR < 3
-#include <qmultilineedit.h>
-#endif
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 #include <kfiledialog.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -40,8 +36,10 @@
 #include "arrayitem.h"
 #include "brushdlg.h"
 #include "editdlg.h"
+#include "kpl.h"
 #include "kpldoc.h"
 #include "kpldoubleedit.h"
+#include "kpldoublespinbox.h"
 #include "kplspinbox.h"
 #include "symboldlg.h"
 #include "utils.h"
@@ -55,7 +53,7 @@ ArrayDlg::ArrayDlg(QWidget* _parent, KplDoc* model, ArrayItem* _ad) :
   QVBoxLayout* vbox = new QVBoxLayout(frame, 0, spacingHint());
   QGroupBox* g = new QGroupBox(0, Qt::Vertical, i18n("Data"), frame);
   vbox->addWidget(g);
-  QGridLayout* grid = new QGridLayout(g->layout(), 6, 6, spacingHint());
+  QGridLayout* grid = new QGridLayout(g->layout(), 7, 6, spacingHint());
   QPushButton* b = new QPushButton(i18n("&File"), g);
   grid->addWidget(b, 0, 0);
   connect(b, SIGNAL(clicked()), SLOT(slotFile()));
@@ -64,15 +62,10 @@ ArrayDlg::ArrayDlg(QWidget* _parent, KplDoc* model, ArrayItem* _ad) :
   if (!ad->internal)
     fileName->setText(ad->url.isLocalFile() ?  ad->url.path() : ad->url.url());
   fileName->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-#if QT_VERSION >= 0x030100
   fileName->setSizePolicy(QSizePolicy::MinimumExpanding,
                           QSizePolicy::Minimum);
-#else
-  fileName->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
-                                      QSizePolicy::Minimum));
-#endif
   hbox->addWidget(bReload = new QPushButton(g));
-  bReload->setPixmap(BarIcon("reload"));
+  bReload->setIconSet(BarIconSet("reload"));
   bReload->setDisabled(fileName->text().isEmpty());
   connect(bReload, SIGNAL(clicked()), SLOT(slotReload()));
   grid->addMultiCellLayout(hbox, 0, 0, 1, 5);
@@ -97,17 +90,23 @@ ArrayDlg::ArrayDlg(QWidget* _parent, KplDoc* model, ArrayItem* _ad) :
   grid->addWidget(iStart = new KplSpinBox(0, 0, 1, g), 4, 1);
   grid->addWidget(new QLabel(i18n("Number of points"), g), 4, 4);
   grid->addWidget(n = new KplSpinBox(0, 0, 1, g), 4, 5);
-  grid->addWidget(new QLabel(i18n("x normalization"), g), 5, 0);
-  grid->addWidget(efx = new KplDoubleEdit(ad->fx, g), 5, 1);
-  grid->addWidget(new QLabel(i18n("y normalization"), g), 5, 4);
-  grid->addWidget(efy = new KplDoubleEdit(ad->fy, g), 5, 5);
+  grid->addWidget(new QLabel(i18n("x shift"), g), 5, 0);
+  Kpl* kpl = ((Kpl*) m->parent());
+  grid->addWidget(ex0 = new KplDoubleSpinBox(ad->x0, kpl->xStep(), g), 5, 1);
+  grid->addWidget(new QLabel(i18n("y shift"), g), 5, 4);
+  grid->addWidget(ey0 = new KplDoubleSpinBox(ad->y0, kpl->yStep(), g), 5, 5);
+  grid->addWidget(new QLabel(i18n("x normalization"), g), 6, 0);
+  grid->addWidget(efx = new KplDoubleEdit(ad->fx, g), 6, 1);
+  grid->addWidget(new QLabel(i18n("y normalization"), g), 6, 4);
+  grid->addWidget(efy = new KplDoubleEdit(ad->fy, g), 6, 5);
   vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Representation"),
                                     frame));
   grid = new QGridLayout(g->layout(), 2, 6, spacingHint());
   grid->addWidget(new QLabel(i18n("Symbol"), g), 0, 0);
   grid->addWidget(symb = new KplSpinBox(-17, 9, 1, g), 0, 1);
   symb->setValue(ad->symb);
-  grid->addWidget(new SymbolButton(g, symb), 0, 2);
+  SymbolButton* bSymb;
+  grid->addWidget(bSymb = new SymbolButton(g, symb, ad->fillStyle), 0, 2);
   grid->addWidget(new QLabel(i18n("Color"), g), 0, 4);
   grid->addWidget(colData = new KColorButton(ad->color, g), 0, 5);
   colData->setMinimumWidth(50);
@@ -115,6 +114,7 @@ ArrayDlg::ArrayDlg(QWidget* _parent, KplDoc* model, ArrayItem* _ad) :
   grid->addWidget(eRelSize = new KplSpinBox(10, 800, 1, g), 1, 1);
   eRelSize->setValue(qRound(100 * ad->relsiz));
   eRelSize->setSuffix(" %");
+  eRelSize->setDisabled(ad->fillStyle);
   grid->addWidget(new QLabel(i18n("Fill pattern"), g), 1, 4);
   grid->addWidget(fill = new BrushButton(g, ad->fillStyle), 1, 5);
   setSpinBoxes(ad);
@@ -124,6 +124,11 @@ ArrayDlg::ArrayDlg(QWidget* _parent, KplDoc* model, ArrayItem* _ad) :
   connect(err, SIGNAL(toggled(bool)), ie, SLOT(setEnabled(bool)));
   connect(iStart, SIGNAL(valueChanged(int)), SLOT(slotStartChanged(int)));
   connect(n, SIGNAL(valueChanged(int)), SLOT(slotNChanged(int)));
+  connect(fill, SIGNAL(valueChanged(bool)), symb, SLOT(setDisabled(bool)));
+  connect(fill, SIGNAL(valueChanged(bool)), bSymb, SLOT(setDisabled(bool)));
+  connect(fill, SIGNAL(valueChanged(bool)), eRelSize, SLOT(setDisabled(bool)));
+  connect(ex0, SIGNAL(valueChanged(double)), SLOT(slotApply()));
+  connect(ey0, SIGNAL(valueChanged(double)), SLOT(slotApply()));
 }
 
 ArrayDlg::~ArrayDlg()
@@ -167,6 +172,8 @@ void ArrayDlg::getValues(bool ok)
     delete adt;
     adt = 0;
   }
+  ad->x0 = ex0->value();
+  ad->y0 = ey0->value();
   ad->fx = efx->value();
   ad->fy = efy->value();
   ad->color = colData->color().rgb();
@@ -215,6 +222,7 @@ void ArrayDlg::slotFile()
     disconnect(internal, SIGNAL(toggled(bool)), this,
                SLOT(slotInternal(bool)));
     internal->setChecked(false);
+    edit->setEnabled(false);
     connect(internal, SIGNAL(toggled(bool)), SLOT(slotInternal(bool)));
   }
 }
@@ -303,40 +311,24 @@ void ArrayDlg::slotEdit()
     for (int j = 0; j < src->ncols; j++)
       t << m->number(src->x[j][i])
         << (j < (src->ncols - 1) ? m->separator() : QString("\n"));
-#if KDE_VERSION_MAJOR > 2
   EditDlg dlg(this, &buf, m->options()->prec + 4);
-#else
-  int sav = QMultiLineEdit::defaultTabStop();
-  QMultiLineEdit::setDefaultTabStop(m->options()->prec + 4);
-  EditDlg dlg(this, &buf);
-#endif
   connect(&dlg, SIGNAL(applyClicked()), SLOT(slotEditApply()));
   if (dlg.exec()) {
     delete adt;
     adt = new ArrayItem;
     readData(true);
   }
-#if KDE_VERSION_MAJOR < 3
-  QMultiLineEdit::setDefaultTabStop(sav);
-#endif
 }
 
 bool ArrayDlg::readData(bool fromBuffer)
 {
   if (fromBuffer)
-    adt->nrows = ArrayItem::readFile(&buf, &adt->ncols, &adt->x);
+    adt->readFile(&buf);
   else
-    adt->nrows = ArrayItem::readFile(adt->url, &adt->ncols, &adt->x,
-                                     adt->idec);
+    adt->readFile();
   if (adt->nrows) {
-    int maxCol = adt->ncols - 1;
-    adt->ix = QMIN(ad->ix, maxCol);
-    adt->iy = QMIN(ad->iy, maxCol);
-    adt->ie = QMIN(ad->ie, maxCol);
-    adt->istart = QMIN(ad->istart, adt->nrows - 1);
-    adt->n = adt->nrows - adt->istart;
-    if (ad->n && (!fromBuffer))
-      adt->n = QMIN(ad->n, adt->n);
+    adt->adjustCols(ad->ix, ad->iy, ad->ie);
+    adt->adjustRows(ad->istart, fromBuffer ? adt->nrows : ad->n);
     setSpinBoxes(adt);
     return adt->nrows;
   } else {
