@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -34,6 +34,7 @@ class ArrayItem;
 class BrushButton;
 class KplDoc;
 class KplDoubleEdit;
+class KplDoubleSpinBox;
 class KplSpinBox;
 
 /**
@@ -83,6 +84,7 @@ protected:
   KplDoc* m;
   ArrayItem *ad, *adt;
   KplDoubleEdit *efx, *efy;
+  KplDoubleSpinBox *ex0, *ey0;
   QLabel* fileName;
   KplSpinBox *ix, *iy, *ie, *iStart, *n, *symb, *eRelSize;
   QCheckBox *err, *internal;
