@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sat Aug 28 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,22 +19,24 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <stdlib.h>
 #include <math.h>
+#include <stdlib.h>
 #include <qfileinfo.h>
+#include <qregexp.h>
 #include <qtextstream.h>
 #include <qurl.h>
-#include <qregexp.h>
-#include <kapp.h>
-#include <klocale.h>
-#include <ksimpleconfig.h>
-#include <kmessagebox.h>
+#include <kapplication.h>
 #include <kio/netaccess.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <ksimpleconfig.h>
 #include "arrayitem.h"
-#include "arraydlg.h"
-#include "kplgraph.h"
-#include "kplchecklistitem.h"
+#include "kgraph.h"
 #include "utils.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
+#include "arraydlg.h"
+#endif
 
 ArrayItem::ArrayItem() : internal(false), ix(0), iy(0), ie(0), istart(0), n(0),
  errbars(0), nrows(0), ncols(0), idec(0), x(0)
@@ -44,18 +46,18 @@ ArrayItem::ArrayItem() : internal(false), ix(0), iy(0), ie(0), istart(0), n(0),
 ArrayItem::ArrayItem(const ArrayItem& a) :
  ScaledItem(a), internal(a.internal), ix(a.ix), iy(a.iy), ie(a.ie),
  istart(a.istart), n(a.n), errbars(a.errbars), nrows(a.nrows), ncols(a.ncols),
- idec(a.idec), x(a.x), url(a.url)
+ idec(a.idec), url(a.url)
 {
   x = ArrayItem::copyX(a.x, a.ncols, a.nrows);
 }
 
-ArrayItem::ArrayItem(Kpl::AutoStruct* aut) : ScaledItem(aut), internal(false),
- ix(aut->ixAuto), iy(aut->iyAuto), ie(aut->ieAuto), istart(0), n(0),
- errbars(aut->autoErr), nrows(0), ncols(0), idec(aut->iDec), x(0)
+ArrayItem::ArrayItem(KplNamespace::AutoStruct* aut) : ScaledItem(aut),
+ internal(false), ix(aut->ixAuto), iy(aut->iyAuto), ie(aut->ieAuto), istart(0),
+ n(0), errbars(aut->autoErr), nrows(0), ncols(0), idec(aut->iDec), x(0)
 {
 }
 
-ArrayItem::ArrayItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
+ArrayItem::ArrayItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
                      const KURL& uPlo) : ScaledItem(plo, aut),
  ix(0), iy(0), ie(0), istart(0), n(0), errbars(0), x(0)
 {
@@ -68,10 +70,10 @@ ArrayItem::ArrayItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
     errbars = plo->readNumEntry("errbars");
     ncols = 3;
     idec = 0;
-    double* x1 = new double[ncols * nrows];
     x = new double*[ncols];
-    for (int j = 0; j < ncols; j++)
-      x[j] = &x1[j * nrows];
+    x[0] = new double[ncols * nrows];
+    for (int j = 1; j < ncols; j++)
+      x[j] = x[j - 1] + nrows;
     for (int i = 0; i < nrows; i++) {
       QString s;
       QStringList list = plo->readListEntry(s.sprintf("r%i", i), ' ');
@@ -81,20 +83,16 @@ ArrayItem::ArrayItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
     }
   } else {
     idec = plo->readNumEntry("idec");
-    nrows = readFile(url, &ncols, &x, idec);
-    if (!nrows) {
+    if (!readFile()) {
       KMessageBox::error(0, url.url());
-        return;
+      return;
     }
-    istart = QMIN(plo->readNumEntry("istart"), nrows - 1);
-    int nmax =  nrows - istart;
-    n = QMIN(plo->readNumEntry("n", nmax), nmax);
+    adjustRows(plo->readNumEntry("istart"), plo->readNumEntry("n", nrows));
     errbars = plo->readNumEntry("errbars", aut->autoErr);
   }
-  int icolmax = ncols - 1;
-  ix = QMIN(plo->readNumEntry("ix", aut->ixAuto), icolmax);
-  iy = QMIN(plo->readNumEntry("iy", aut->iyAuto), icolmax);
-  ie = QMIN(plo->readNumEntry("ie", aut->ieAuto), icolmax);
+  adjustCols(plo->readNumEntry("ix", aut->ixAuto),
+             plo->readNumEntry("iy", aut->iyAuto),
+             plo->readNumEntry("ie", aut->ieAuto));
 }
 
 ArrayItem::ArrayItem(bool act, int fill, int sym, const QString& col,
@@ -109,19 +107,18 @@ ArrayItem::ArrayItem(bool act, int fill, int sym, const QString& col,
     ncols = 3;
     idec = 0;
     int dim = ncols * nrows;
-    double* x1 = new double[dim];
-    memset(x1, 0, dim * sizeof(double));
     x = new double*[ncols];
-    for (int j = 0; j < ncols; j++)
-      x[j] = &x1[j * nrows];
+    x[0] = new double[dim];
+    memset(x[0], 0, dim * sizeof(double));
+    for (int j = 1; j < ncols; j++)
+      x[j] = x[j - 1] + nrows;
   } else {
-    nrows = readFile(url, &ncols, &x, idec);
-    if (!nrows) {
+    if (!readFile()) {
       KMessageBox::error(0, url.url());
       return;
     }
-    istart = QMIN(i_start, nrows - 1);
-    n = QMIN(np, nrows - istart);
+    adjustRows(i_start, np);
+    adjustCols();
   }
 }
 
@@ -156,11 +153,11 @@ double** ArrayItem::copyX(double **xv, int nc, int nr)
   double** x2 = 0;
   if (xv) {
     int n = nc * nr;
-    double* x1 = new double[n];
-    memcpy(x1, xv[0], n * sizeof(double));
     x2 = new double*[nc];
-    for (int i = 0; i < nc; i++)
-      x2[i] = &x1[i * nr];
+    x2[0] = new double[n];
+    memcpy(x2[0], xv[0], n * sizeof(double));
+    for (int i = 1; i < nc; i++)
+      x2[i] = x2[i - 1] + nr;
   }
   return x2;
 }
@@ -177,7 +174,7 @@ void ArrayItem::freeX(double ***xv)
 int ArrayItem::nColumns(QTextStream& t, int idec)
 {
   int nc = 0;
-  while (!t.eof()) {
+  while (!t.atEnd()) {
     QString line = t.readLine().stripWhiteSpace();
     if ((!line.isEmpty()) && (line[0] != '#')) {
       nc = QStringList::split(QRegExp(idec ? "[ \t]" : "[ ,\t]"),
@@ -190,11 +187,11 @@ int ArrayItem::nColumns(QTextStream& t, int idec)
 
 int ArrayItem::readLines(QTextStream& t, int nc, double ***xv, int idec)
 {
-  QArray<double> x2;
+  QMemArray<double> x2;
   int np = 0;
   int k = 0;
   int nr = 0;
-  while (!t.eof()) {
+  while (!t.atEnd()) {
     QString line = t.readLine().stripWhiteSpace();
     if ((!line.isEmpty()) && (line[0] != '#')) {
       Utils::translate(line, idec);
@@ -210,10 +207,10 @@ int ArrayItem::readLines(QTextStream& t, int nc, double ***xv, int idec)
       }
     }
   }
-  double* x1 = new double[np];
   *xv = new double*[nc];
-  for (int i = 0; i < nc; i++)
-    (*xv)[i] = &x1[i * nr];
+  (*xv)[0] = new double[np];
+  for (int i = 1; i < nc; i++)
+    (*xv)[i] = (*xv)[i - 1] + nr;
   k = 0;
   for (int j = 0; j < nr; j++)
     for (int i = 0; i < nc; i++)
@@ -230,7 +227,7 @@ int ArrayItem::readFile(const KURL& u, int *nc, double ***xv, int idec)
   if (u.isLocalFile())
     fn = u.path();
   else
-#if KDE_VERSION >= 0x03015a
+#if KDE_VERSION >= 0x030200
     if (!KIO::NetAccess::download(u, fn, 0))
 #else
     if (!KIO::NetAccess::download(u, fn))
@@ -238,11 +235,12 @@ int ArrayItem::readFile(const KURL& u, int *nc, double ***xv, int idec)
       return nr;
   QFile f(fn);
   if (f.open(IO_ReadOnly)) {
-    QTextStream t(&f);
-    *nc = nColumns(t, idec);
+    QTextStream t1(&f);
+    *nc = nColumns(t1, idec);
     if (*nc) {
       f.reset();
-      nr = readLines(t, *nc, xv, idec);
+      QTextStream t2(&f);
+      nr = readLines(t2, *nc, xv, idec);
     }
     f.close();
   }
@@ -251,6 +249,12 @@ int ArrayItem::readFile(const KURL& u, int *nc, double ***xv, int idec)
   return nr;
 }
 
+int ArrayItem::readFile()
+{
+  nrows = readFile(url, &ncols, &x, idec);
+  return nrows;
+}
+
 int ArrayItem::readFile(QString* text, int *nc, double ***xv)
 {
   QTextStream t1(text, IO_ReadOnly);
@@ -263,6 +267,26 @@ int ArrayItem::readFile(QString* text, int *nc, double ***xv)
   return nr;
 }
 
+int ArrayItem::readFile(QString* text)
+{
+  nrows = readFile(text, &ncols, &x);
+  return nrows;
+}
+
+void ArrayItem::adjustCols(int i_x, int i_y, int i_e)
+{
+  int icolmax = ncols - 1;
+  ix = QMIN(i_x, icolmax);
+  iy = QMIN(i_y, icolmax);
+  ie = QMIN(i_e, icolmax);
+}
+
+void ArrayItem::adjustRows(int i_start, int np)
+{
+  istart = QMIN(i_start, nrows - 1);
+  n = QMIN(np, nrows - istart);
+}
+
 KplItem::ItemTypes ArrayItem::iType() const
 {
   return Array;
@@ -274,13 +298,24 @@ void ArrayItem::draw(KplGraph* g)
     setProperties(g);
     double sav = g->relSize();
     g->setRelSize(relsiz * sav);
-    g->plArray(&x[ix][istart], &x[iy][istart], fx, fy, n, fillStyle);
+    g->plArray(&x[ix][istart], &x[iy][istart], fx, fy, n, fillStyle, true, x0,
+               y0);
     if (errbars)
-      g->plError(&x[ix][istart], &x[iy][istart], &x[ie][istart], fx, fy, n);
+      g->plError(&x[ix][istart], &x[iy][istart], &x[ie][istart], fx, fy, n,
+                 true, x0, y0);
     g->setRelSize(sav);
   }
 }
 
+#ifdef KPL_CLASSES_ONLY
+void ArrayItem::setRange(int _istart, int _n, int _symb, const QString& col)
+{
+  adjustRows(_istart, _n);
+  symb = _symb;
+  color = KplGraph::rgbQt(col);
+}
+
+#else
 void ArrayItem::writePlo(KSimpleConfig* plo, const KURL& uPlo, bool _abs,
                          KplDoc* m) const
 {
@@ -295,9 +330,9 @@ void ArrayItem::writePlo(KSimpleConfig* plo, const KURL& uPlo, bool _abs,
   if (internal) {
     plo->writeEntry("istart", 0);
     for (int i = 0; i < n; i++) {
-      QStrList list;
+      QStringList list;
       for (int j = 0; j < ncols; j++)
-        list.insert(j, QString::number(x[j][i + istart]));
+        list.append(QString::number(x[j][i + istart]));
       QString s;
       plo->writeEntry(s.sprintf("r%i", i), list, ' ');
     }
@@ -308,14 +343,16 @@ void ArrayItem::writePlo(KSimpleConfig* plo, const KURL& uPlo, bool _abs,
   }
 }
 
-void ArrayItem::setText(KplCheckListItem* it, bool* arrays, bool*) const
+void ArrayItem::setText(QListViewItem* it, bool* arrays, bool*) const
 {
   *arrays = true;
   it->setText(1, i18n("Array"));
+  KGraph g;
+  it->setPixmap(2, g.pixmap(symb, color));
   QString s = (internal ? i18n("internal data") :
-                         (i18n("file") + " " + url.fileName())) +
-              ", " + i18n("columns") + " " +
-              QString::number(ix) + ", " + QString::number(iy);
+                          (i18n("file") + " " + url.fileName())) +
+    ", " + i18n("columns") + " " + QString::number(ix) + ", " +
+    QString::number(iy);
   if (errbars)
     s += ", " + QString::number(ie);
   it->setText(2, s);
@@ -326,6 +363,7 @@ int ArrayItem::editItem(QWidget* parent, KplDoc* m, int)
   ArrayDlg dlg(parent, m, this);
   return dlg.exec();
 }
+#endif
 
 KplItem* ArrayItem::copy() const
 {
@@ -347,5 +385,9 @@ void ArrayItem::minMax(double* xmi, double* xma, double* ymi, double* yma) const
   if (x) {
     Utils::minMaxFile(xmi, xma, &x[ix][istart], n);
     Utils::minMaxFile(ymi, yma, &x[iy][istart], n);
+    *xmi += x0;
+    *xma += x0;
+    *ymi += y0;
+    *yma += y0;
   }
 }
