@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sat Aug 28 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -25,9 +25,6 @@
 #include <kurl.h>
 #include "kplitem.h"
 
-class QTextStream;
-class KSimpleConfig;
-
 /**
   * Array item class. Class for array items showing data arrays by lines
   * or markers.
@@ -44,21 +41,22 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  ArrayItem(Kpl::AutoStruct* aut);
+  ArrayItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     * @param url URL of plot file.
     */
-  ArrayItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& url);
+  ArrayItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
+            const KURL& url);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
     * @param fillStyle > 0 for filled polygon representation.
     * @param symb 0 for circles, < 0 for different markers,
     * >0 for different line types.
-    * @param color color for function plot.
+    * @param color color for data plot.
     * @param fx normalization factor for x values.
     * @param fy normalization factor for y values.
     * @param ix x column index.
@@ -118,6 +116,11 @@ public:
     * @return number of lines, 0 for error.
     */
   static int readFile(const KURL& url, int *nc, double ***xv, int idec = 0);
+  /**
+    * Reads double values from the URL.
+    * @return number of lines, 0 for error.
+    */
+  int readFile();
   /**
     * Reads double values from a string into an array.
     * @param text string to read from.
@@ -126,15 +129,53 @@ public:
     * @return number of lines, 0 for error.
     */
   static int readFile(QString* text, int *nc, double ***xv);
+  /**
+    * Reads double values from a string.
+    * @return number of lines, 0 for error.
+    */
+  int readFile(QString* text);
+  /**
+    * Sets and limits the column indices.
+    * @param ix x column.
+    * @param iy y column.
+    * @param ie error column.
+    */
+  void adjustCols(int ix, int iy, int ie);
+  /** Limits the column indices. */
+  inline void adjustCols() { adjustCols(ix, iy, ie); };
+  /**
+    * Sets and limits the start row index and the number of points.
+    * @param istart start row.
+    * @param np number of points.
+    */
+  void adjustRows(int istart, int np);
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifdef KPL_CLASSES_ONLY
+  /**
+    * Sets range, symbol, color for plot.
+    * @param istart start row index.
+    * @param n number of data points.
+    * @param symb 0 for circles, < 0 for different markers,
+    * >0 for different line types.
+    * @param color color for data plot.
+    */
+  void setRange(int istart, int n, int symb, const QString& color);
+  /**
+    * Returns pointer to internal array.
+    * @return pointer to two-dimensional array.
+    */
+  inline double** data() { return x; };
+#else
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
+#endif
   virtual KplItem* copy() const;
   virtual void expoItem(int* iex, int* iey, double* fx, double* fy) const;
-  virtual void minMax(double* xmi, double* xma, double* ymi, double* yma) const;
+  virtual void minMax(double* xmi, double* xma, double* ymi,
+                      double* yma) const;
 
 protected:
   bool internal;
@@ -144,10 +185,12 @@ protected:
 
   friend class ArrayDlg;
   friend class FitDlg;
-  friend class SplFitDlg;
-  friend class LMFit;
+  friend class FunItem;
+  friend class Kpl;
   friend class KplDoc;
-  friend class KplApp;
+  friend class LMFit;
+  friend class SplFitDlg;
+  friend class SplineItem;
 };
 
 #endif
