@@ -2,7 +2,7 @@
                           arrowdlg.cpp  -  description
                              -------------------
     begin                : Sat Apr 14 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -40,7 +40,7 @@ void ArrowDlg::initPolarEntries(QWidget* _parent, ArrowItem* _ad,
   _grid->addWidget(new QLabel(i18n("Direction"), _parent), 0, 0);
   _grid->addWidget(*_eDir = new KplDoubleEdit(_ad->dir, -360.0, 360.0,
                    _parent), 0, 1);
-  _grid->addWidget(new QLabel("", _parent), 0, 2);
+  _grid->addWidget(new QLabel("\260", _parent), 0, 2);
   _grid->addWidget(new QLabel(i18n("Length"), _parent), 0, 4);
   _grid->addWidget(*_eLen = new KplDoubleEdit(_ad->len, 0.0, 200.0, _parent),
                    0, 5);
