@@ -2,7 +2,7 @@
                           arrowitem.cpp  -  description
                              -------------------
     begin                : Sat Apr 14 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,23 +18,25 @@
 #include <klocale.h>
 #include <ksimpleconfig.h>
 #include "arrowitem.h"
-#include "utils.h"
 #include "kgraph.h"
-#include "kplchecklistitem.h"
+#include "utils.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
 #include "arrowdlg.h"
+#endif
 
 ArrowItem::ArrowItem() : dir(0.0), len(1.0)
 {
 }
 
-ArrowItem::ArrowItem(Kpl::AutoStruct* aut) :
+ArrowItem::ArrowItem(KplNamespace::AutoStruct* aut) :
  DecoItem(aut), dir(0.0), len(1.0)
 {
   x0 = aut->x0Auto + 0.5 * aut->xlAuto;
   y0 = aut->y0Auto + 0.5 * aut->ylAuto;
 }
 
-ArrowItem::ArrowItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
+ArrowItem::ArrowItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
  DecoItem(plo, aut)
 {
   dir = plo->readDoubleNumEntry("dir");
@@ -68,6 +70,7 @@ void ArrowItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void ArrowItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                          KplDoc* m) const
 {
@@ -77,12 +80,14 @@ void ArrowItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
   plo->writeEntry("len", len);
 }
 
-void ArrowItem::setText(KplCheckListItem* it, bool*, bool*) const
+void ArrowItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Arrow"));
+  KGraph g;
+  it->setPixmap(2, g.pixmap(1, color));
   QString s1, s2;
   it->setText(2, s1.sprintf("x = %g cm, y = %g cm, ", x0, y0) +
-              i18n("direction") + s2.sprintf(" %g", dir));
+              i18n("direction") + s2.sprintf(" %g\260", dir));
 }
 
 int ArrowItem::editItem(QWidget* parent, KplDoc* m, int)
@@ -90,6 +95,7 @@ int ArrowItem::editItem(QWidget* parent, KplDoc* m, int)
   ArrowDlg dlg(parent, m, this);
   return dlg.exec();
 }
+#endif
 
 KplItem* ArrowItem::copy() const
 {
