@@ -2,7 +2,7 @@
                           decodlg.cpp  -  description
                              -------------------
     begin                : Fri Apr 20 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,7 +18,7 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <klocale.h>
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 #include "kpldoubleedit.h"
 #include "kplspinbox.h"
 #include "kpldoc.h"
