@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -25,7 +25,7 @@
 #include <qradiobutton.h>
 #include <qlayout.h>
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include "utils.h"
 #include "edittextdlg.h"
 
