@@ -2,7 +2,7 @@
                           ellipseitem.cpp  -  description
                              -------------------
     begin                : Sun Apr 29 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -17,24 +17,26 @@
 
 #include <klocale.h>
 #include <ksimpleconfig.h>
-#include "kplchecklistitem.h"
-#include "kgraph.h"
-#include "rectdlg.h"
 #include "ellipseitem.h"
+#include "kgraph.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
+#include "rectdlg.h"
+#endif
 
 EllipseItem::EllipseItem()
 {
   height = 3.0;
 }
 
-EllipseItem::EllipseItem(Kpl::AutoStruct* aut) :
+EllipseItem::EllipseItem(KplNamespace::AutoStruct* aut) :
  RectItem(aut)
 {
   x0 = aut->x0Auto + 0.5 * aut->xlAuto;
   y0 = aut->y0Auto + 0.5 * aut->ylAuto;
 }
 
-EllipseItem::EllipseItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
+EllipseItem::EllipseItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
  RectItem(plo, aut)
 {
 }
@@ -67,6 +69,7 @@ void EllipseItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void EllipseItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                            KplDoc* m) const
 {
@@ -74,9 +77,11 @@ void EllipseItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
   plo->writeEntry("Type", "ELLIPSEITEM");
 }
 
-void EllipseItem::setText(KplCheckListItem* it, bool*, bool*) const
+void EllipseItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Ellipse"));
+  KGraph g;
+  it->setPixmap(2, g.pixmap(fillStyle ? -11 : 0, color));
   QString s1, s2;
   it->setText(2, s1.sprintf("x = %g cm, y = %g cm, ", x0, y0) + i18n("size")
               + s2.sprintf(" %g cm x %g cm", width, height));
@@ -88,6 +93,7 @@ int EllipseItem::editItem(QWidget* parent, KplDoc* m, int)
   dlg.setCaption(i18n("Ellipse"));
   return dlg.exec();
 }
+#endif
 
 KplItem* EllipseItem::copy() const
 {
