@@ -2,7 +2,7 @@
                           fitdlg.cpp  -  description
                              -------------------
     begin                : Tue May 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -24,6 +24,7 @@
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qlibrary.h>
 #include <qlistbox.h>
 #include <qlineedit.h>
 #include <qpainter.h>
@@ -31,12 +32,13 @@
 #include <qregexp.h>
 #include <qtable.h>
 #include <qtimer.h>
-#include <kapp.h>
-#include <kcolorbtn.h>
+#include <kapplication.h>
+#include <kcolorbutton.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <knotifyclient.h>
 #include <kseparator.h>
 #include <kurl.h>
 #include "arrayitem.h"
@@ -84,11 +86,11 @@ CorrDlg::~CorrDlg()
 }
 
 ErrModDlg::ErrModDlg(QWidget* _parent, KplDoc* model,
-                     Kpl::DataErrorStruct* err0) :
+                     KplNamespace::DataErrorStruct* err0) :
  KDialogBase(Plain, i18n("Error model function"), Help | Ok | Cancel, Ok,
             _parent, 0, true, true), m(model), err(err0)
 {
-  errt = new Kpl::DataErrorStruct(*err);
+  errt = new KplNamespace::DataErrorStruct(*err);
   QFrame* frame = plainPage();
   QGridLayout* grid = new QGridLayout(frame, 4, 2, 0, spacingHint());
   grid->addWidget(new QLabel(i18n("Library"), frame), 0, 0);
@@ -129,6 +131,7 @@ ErrModDlg::ErrModDlg(QWidget* _parent, KplDoc* model,
 ErrModDlg::~ErrModDlg()
 {
   delete errt;
+  delete bg;
 }
 
 void ErrModDlg::slotFile()
@@ -170,25 +173,25 @@ void ErrModDlg::slotOk()
   errt->errModPath = fileName->text();
   errt->errModName = func->text();
   errt->errModArg = bg->id(bg->selected());
-  lt_dlhandle hErrMod = 0;
+  QLibrary* lib;
   double (*fkt)(double, const double *);
-  if (FunItem::getFuncAddr(errt->errModPath, errt->errModName, &hErrMod, &fkt))
+  if (!FunItem::getFuncAddr(errt->errModPath, errt->errModName, &lib, &fkt))
     return;
-  lt_dlclose(hErrMod);
+  delete lib;
   *err = *errt;
   accept();
 }
 
-FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
-               QList<FunItem>* fd0, int mode) :
+FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QPtrList<ArrayItem>* ad0,
+               QPtrList<FunItem>* fd0, int mode) :
  KDialogBase(Plain, i18n("Parameter fit"),
              Help | Ok | Apply | Cancel | User1 | User2,
              Ok, _parent, 0, true, true, i18n("&Start"), i18n("&Residuals")),
  running(false), dlgMode(mode), m(model), ad(ad0), fd(fd0), sw(0)
 {
-  aut = new Kpl::AutoStruct(*m->options());
+  aut = new KplNamespace::AutoStruct(*m->options());
   config = KGlobal::config();
-  err = new Kpl::DataErrorStruct[ad->count()];
+  err = new KplNamespace::DataErrorStruct[ad->count()];
   int i;
   QString s;
   ArrayItem* a;
@@ -220,7 +223,6 @@ FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
     m->pLast[i] = ff->py[i];
     m->pErr[i] = 0.0;
   }
-  lm = new LMFit(this);
   if (dlgMode & ShowDlg) {
     Utils::setSize(this, "FitDialog");
     QHBoxLayout* hbox = 0;
@@ -246,15 +248,17 @@ FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
     for (i = 0; i < KPL_NPMAX; i++) {
       int ix = 5 * (i / 10);
       int iy = i % 10;
-      grid->addWidget(enFit[i] = new QCheckBox(s.sprintf("p%i", i), g, "f"),
+      grid->addWidget(enFit[i] = new QCheckBox(s.sprintf("p%i", i), g),
                       iy, ix);
       enFit[i]->setChecked(aut->fitPar[i]);
+      widgetList.append(enFit[i]);
       grid->addWidget(par[i] = new KplDoubleEdit(m->pLast[i], g, frm, prec),
                       iy, ix + 1);
       if (!i)
         w = QMAX(80, par[0]->fontMetrics().width(m->number(-1.0e-123 / 3.0)) +
                                                  3);
       par[i]->setFixedWidth(w);
+      widgetList.append(par[i]);
       grid->addWidget(new QLabel("\261", g), iy, ix + 2);
       grid->addWidget(epar[i] = new QLabel(s0, g), iy, ix + 3);
       epar[i]->setFrameStyle(QFrame::Panel | QFrame::Sunken);
@@ -311,8 +315,6 @@ FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
     connect(nonLin, SIGNAL(toggled(bool)), SLOT(enableNonLin(bool)));
     connect(errCol, SIGNAL(toggled(bool)), SLOT(errColToggled(bool)));
     connect(sArr, SIGNAL(valueChanged(int)), SLOT(updArray(int)));
-    connect(lm, SIGNAL(updateMessage(const QString &)),
-            SLOT(slotMessage(const QString &)));
     enableNonLin(aut->fitNonLin);
     updArray(0);
     if (m->options()->showSource)
@@ -326,7 +328,6 @@ FitDlg::~FitDlg()
     Utils::saveSize(this, "FitDialog");
   delete [] err;
   delete aut;
-  delete lm;
 }
 
 void FitDlg::getValues(bool ok)
@@ -348,9 +349,9 @@ void FitDlg::getValues(bool ok)
       config->writeEntry("FitErrorColumn", err[j].fitErrCol);
       config->writeEntry("ErrorModelPath", err[j].errModPath);
       config->writeEntry("ErrorModelName", err[j].errModName);
-      QStrList s1;
+      QStringList s1;
       for (i = 0; i < KPL_NPMAX; i++)
-        s1.insert(i, m->number(err[j].pErrMod[i]));
+        s1.append(m->number(err[j].pErrMod[i]));
       config->writeEntry("ErrorModelParam", s1, ' ');
       config->writeEntry("ErrorModelArgument", err[j].errModArg);
     }
@@ -410,18 +411,10 @@ void FitDlg::updArray(int i)
   if (m->options()->showSource) {
     FunItem* ff = fd->at(i);
     QFileInfo fi(ff->pathy.path());
-#if KDE_VERSION_MAJOR > 2
     QRegExp rx2("\\S+__FdPCd");
     QRegExp rx3("_Z\\d+\\S+dPKd");
     int pp2 = rx2.search(ff->namey);
     int pp3 = rx3.search(ff->namey);
-#else
-    QRegExp rx2("[^\\s]+__FdPCd");
-    QRegExp rx3("_Z\\d+[^\\s]+dPKd");
-    int l2, l3;
-    int pp2 = rx2.match(ff->namey, 0, &l2);
-    int pp3 = rx3.match(ff->namey, 0, &l3);
-#endif
     QString s = fi.dirPath(true) + "/" + fi.baseName();
     bool guessC = pp2 && pp3;
     QFile f(s + (guessC ? ".c" : ".cpp"));
@@ -433,17 +426,10 @@ void FitDlg::updArray(int i)
     if (open) {
       sw->fill(&f);
       if (!pp2)
-#if KDE_VERSION_MAJOR > 2
         sw->highlight(ff->namey.left(rx2.matchedLength() - 7));
       else
         if (!pp3)
           sw->highlight(ff->namey.mid(3, rx3.matchedLength() - 7));
-#else
-        sw->highlight(ff->namey.left(l2 - 7));
-      else
-        if (!pp3)
-          sw->highlight(ff->namey.mid(3, l3 - 7));
-#endif
         else
           sw->highlight(ff->namey);
     }
@@ -475,12 +461,21 @@ void FitDlg::slotUser1()
 
 void FitDlg::fit()
 {
-  for (FunItem* f = fd->first(); f; f = fd->next())
-    if (!f->fkty) {
-      KMessageBox::error(this, i18n("no function address!"));
-      return;
-    }
-  bool nLin;
+  int i;
+  np = 0;
+  for (i = 0; i < KPL_NPMAX; i++) {
+    if (dlgMode & ShowDlg)
+      aut->fitPar[i] = enFit[i]->isChecked();
+    if (aut->fitPar[i])
+      np++;
+  }
+  if (!np) {
+    KMessageBox::sorry(this, i18n("No parameter to fit!"));
+    return;
+  }
+  lm = new LMFit(ad, fd, aut->fitPar, m->pLast, this);
+  lm->sig = sig.data();
+  bool nLin = aut->fitNonLin;
   if (dlgMode & ShowDlg) {
     nLin = nonLin->isChecked();
     if (nLin) {
@@ -489,166 +484,69 @@ void FitDlg::fit()
     }
     showCorr->setEnabled(false);
     results->clear();
-  } else
-    nLin = aut->fitNonLin;
-  np = 0;
-  int i;
-  for (i = 0; i < KPL_NPMAX; i++) {
-    if (dlgMode & ShowDlg) {
+    connect(lm, SIGNAL(updateMessage(const QString &)),
+            SLOT(slotMessage(const QString &)));
+    for (i = 0; i < KPL_NPMAX; i++)
       m->pLast[i] = par[i]->value();
-      aut->fitPar[i] = enFit[i]->isChecked();
-    }
-    if (aut->fitPar[i])
-      np++;
-  }
-  if (!np) {
-    KMessageBox::sorry(this, i18n("No parameter to fit!"));
-    return;
-  }
-  int n = 0;
-  ArrayItem* a;
-  for (a = ad->first(); a; a = ad->next())
-    n += a->n;
-  fvec.resize(n);
-  lm->sig.resize(n);
-  int j = 0;
-  int k;
-  for (k = 0; k < (int) ad->count(); k++) {
-    a = ad->at(k);
-    if (err[k].fitErrCol) {
-      for (i = 0; i < a->n; i++)
-        lm->sig[j++] = a->x[a->ie][a->istart + i];
-    } else {
-      double (*fktErrMod)(double, const double*);
-      lt_dlhandle hErrMod;
-      if (FunItem::getFuncAddr(err[k].errModPath, err[k].errModName, &hErrMod,
-                               &fktErrMod))
-        return;
-      for (i = 0; i < a->n; i++)
-        lm->sig[j++] = fktErrMod(a->x[err[k].errModArg ? a->iy : a->ix]
-                                     [a->istart + i], err[k].pErrMod);
-      lt_dlclose(hErrMod);
-    }
-  }
-  lm->ad = ad;
-  lm->fd = fd;
-  lm->bFit = aut->fitPar;
-  lm->p = m->pLast;
-  int wadim = (6 + np + n) * np + n;
-  double* wa = new double[wadim];
-  memset(wa, 0, wadim * sizeof(double));
-  double* guess = wa + 3 * np + n;
-  double* diag = guess + np;
-  double* fjac = diag + np;
-  double* qtf = fjac + n * np;
-  double* alpha = qtf + np;
-  j = 0;
-  for (i = 0; i < KPL_NPMAX; i++)
-    if (aut->fitPar[i])
-      guess[j++] = m->pLast[i];
-  if (dlgMode & ShowDlg) {
     for (QWidget* w = widgetList.first(); w; w = widgetList.next())
       w->setEnabled(false);
-    for (i = 0; i < KPL_NPMAX; i++) {
-      par[i]->setEnabled(false);
-      enFit[i]->setEnabled(false);
-    }
   }
   kapp->processEvents();
-  bool aborted = lm->userBreak = false;
+  double avgErr;
   running = true;
+  int info = FunItem::fit(ad, fd, aut->fitPar, m->pLast, &fvec, &sig, err,
+                          nLin, aut->fitTol, aut->fitMaxIt, lm, &m->chisq,
+                          corr, m->pErr, &avgErr, this);
+  if (info == -101)
+    KMessageBox::error(this, i18n("no function address!"));
   QString s;
-  if (nLin) {
-    int info = 0;
-    int nfev;
-    lm->lmdif(n, np, guess, fvec.data(), aut->fitTol, aut->fitTol, 0.0,
-              (np + 1) * aut->fitMaxIt, 0.0, diag, 1, 100.0, 1, &info, &nfev,
-              fjac, n, ip, qtf, wa, wa + np, wa + 2 * np, wa + 3 * np);
-    if (info >= 8)
-      info = 4;
-    if (dlgMode & ShowDlg) {
-      switch (info) {
-        case 0:
-          s = i18n("Improper input parameters");
-          break;
-        case 1:
-          s = i18n("Relative error in chi-square is at most tolerance");
-          break;
-        case 2:
-          s = i18n("Relative error in parameters is at most tolerance");
-          break;
-        case 3:
-          s = i18n("Relative error in chi-square and in parameters is at most "
-                   "tolerance");
-          break;
-        case 4:
-          s = i18n("Function vector is orthogonal to the columns of "
-                   "the jacobian");
-          break;
-        case 5:
-          s = i18n("Number of iterations has reached or exceeded maximum");
-          break;
-        case 6:
-          s = i18n("Tolerance too small. No further reduction of "
-                   "chi-square possible");
-          break;
-        case 7:
-          s = i18n("Tolerance too small. No further improvement of "
-                   "parameters possible");
-          break;
-        default:
-          s = i18n("Terminated by user");
+  if (info >= -100) {
+    if (nLin) {
+      if (info >= 8)
+        info = 4;
+      if (dlgMode & ShowDlg) {
+        switch (info) {
+          case 0:
+            s = i18n("Improper input parameters");
+            break;
+          case 1:
+            s = i18n("Relative error in chi-square is at most tolerance");
+            break;
+          case 2:
+            s = i18n("Relative error in parameters is at most tolerance");
+            break;
+          case 3:
+            s = i18n("Relative error in chi-square and in parameters is at most "
+                     "tolerance");
+            break;
+          case 4:
+            s = i18n("Function vector is orthogonal to the columns of "
+                     "the jacobian");
+            break;
+          case 5:
+            s = i18n("Number of iterations has reached or exceeded maximum");
+            break;
+          case 6:
+            s = i18n("Tolerance too small. No further reduction of "
+                     "chi-square possible");
+            break;
+          case 7:
+            s = i18n("Tolerance too small. No further improvement of "
+                     "parameters possible");
+            break;
+          default:
+            s = i18n("Terminated by user");
+        }
+        slotMessage(s);
       }
-      slotMessage(s);
     }
-  } else {
-    aborted = lm->linFit(n, np, guess, fvec.data(), fjac, ip, qtf, wa, wa + np,
-                         wa + 2 * np, wa + 3 * np);
   }
   running = false;
-  if (!aborted) {
-    j = 0;
-    for (i = 0; i < KPL_NPMAX; i++)
-      if (aut->fitPar[i])
-        m->pLast[i] = guess[j++];
-    double chi = LMFit::enorm(n, fvec);
-    m->chisq = chi * chi;
-    for (i = 0; i < np; i++) {
-      for (j = 0; j < np; j++) {
-        alpha[ip[i] + ip[j] * np] = 0.0;
-        for (k = 0; k <= j; k++)
-          if (k <= i)
-            alpha[ip[i] + ip[j] * np] += fjac[i * n + k] * fjac[j * n + k];
-      }
-    }
-    LMFit::minv(alpha, corr, np, wa, ip);
-    int ij = 0;
-    for (i = 0; i < np; i++) {
-      diag[i] = sqrt(corr[ij]);
-      ij += np + 1;
-    }
-    k = 0;
-    for (i = 0; i < np; i++)
-      for (j = 0; j < np; j++) {
-        if (double temp = diag[i] * diag[j])
-          corr[k] /= temp;
-        k++;
-      }
-    int ny = n - np;
-    double q = 0.0;
-    if (ny) {
-      q = LMFit::igamc(0.5 * ny, 0.5 * m->chisq);
-      double temp = sqrt(m->chisq / ny);
-      for (i = 0; i < np; i++)
-        diag[i] *= temp;
-    }
-    k = 0;
+  if (info > -100) {
+    int k = 0;
     for (i = 0; i < KPL_NPMAX; i++) {
-      if (aut->fitPar[i]) {
-        ip[k] = i;
-        m->pErr[i] = diag[k++];
-      } else
-        m->pErr[i] = 0.0;
+      if (aut->fitPar[i])
+        ip[k++] = i;
       if (dlgMode & ShowDlg) {
         par[i]->setValue(m->pLast[i]);
         epar[i]->setText(m->number(m->pErr[i]));
@@ -656,34 +554,36 @@ void FitDlg::fit()
       if (dlgMode & Follow)
         aut->pFit[i] = m->pLast[i];
     }
-    double avgErr = 0.0;
-    for (i = 0; i < n; i++) {
-      double temp = fvec[i] * lm->sig[i];
-      avgErr += temp * temp;
-    }
-    avgErr = sqrt(avgErr / n);
-    if (dlgMode & ShowDlg)
+    if (dlgMode & ShowDlg) {
+      int n = 0;
+      for (ArrayItem* a = ad->first(); a; a = ad->next())
+        n += a->n;
+      int ny = n - np;
+      double q = ny ? LMFit::igamc(0.5 * ny, 0.5 * m->chisq) : 0.0;
       slotMessage(s.sprintf(i18n("Average error = %.3g    ny = %i    "
                                  "Significance Q = %.3g"),
                             avgErr, ny, q));
+    }
     if (dlgMode & SavePar) {
       KURL url = m->URL();
       QFileInfo fi(url.path());
       url.setPath(fi.dirPath(true) + "/" + fi.baseName() + ".par");
       m->saveParameter(this, url, m->pLast, m->pErr);
     }
+    if (!lm->userBreak)
+      KNotifyClient::event(
+#if KDE_VERSION >= 0x030101
+                           winId(),
+#endif
+                           "FitCompleted", i18n("Parameter fit completed."));
   }
+  delete lm;
   if (dlgMode & ShowDlg) {
     showCorr->setEnabled(true);
     for (QWidget* w = widgetList.first(); w; w = widgetList.next())
       w->setEnabled(true);
     enableNonLin(nonLin->isChecked());
-    for (i = 0; i < KPL_NPMAX; i++) {
-      par[i]->setEnabled(true);
-      enFit[i]->setEnabled(true);
-    }
   }
-  delete [] wa;
 }
 
 void FitDlg::slotErrMod()
@@ -694,12 +594,13 @@ void FitDlg::slotErrMod()
 
 void FitDlg::slotUser2()
 {
-  QList<KplItem> items;
+  QPtrList<KplItem> items;
   items.setAutoDelete(true);
-  FrameItem* fd = new FrameItem();
-  fd->gridmode = KplGraph::GridWithLabels;
-  fd->sx = "x";
-  fd->sy = i18n("Residuals");
+  FrameItem* fd = new FrameItem(true, false, false, -1, -1, 5, 2,
+                                KplGraph::GridWithLabels, 0, 0, "0", "0",
+                                4.0, 15.0, 3.0, 10.0, 0.0, 15.0, 0.0, 10.0,
+                                5.0, 2.0, 1.0, "x", i18n("Residuals"), "",
+                                m->options());
   items.append(fd);
   int j = 0;
   for (ArrayItem* a = ad->first(); a; a = ad->next()) {
@@ -708,50 +609,12 @@ void FitDlg::slotUser2()
     ar->color = a->color;
     for (int i = 0; i < a->n; i++) {
       ar->x[0][i] = a->x[a->ix][a->istart + i];
-      ar->x[1][i] = fvec[j] * lm->sig[j];
-      ar->x[2][i] = lm->sig[j++];
+      ar->x[1][i] = fvec[j] * sig[j];
+      ar->x[2][i] = sig[j++];
     }
     items.append(ar);
   }
-  double fxt, fyt;
-  double fx = 1.0;
-  double fy = 1.0;
-  int iext, ieyt;
-  fd->iex = fd->iey = 999;
-  for (KplItem* itm = items.at(1); itm; itm = items.next()) {
-    iext = fd->iex;
-    ieyt = fd->iey;
-    itm->expoItem(&iext, &ieyt, &fxt, &fyt);
-    if (iext < fd->iex) {
-      fd->iex = iext;
-      fx = fxt;
-    }
-    if (ieyt < fd->iey) {
-      fd->iey = ieyt;
-      fy = fyt;
-    }
-  }
-  double xmin = 1.0e300;
-  double ymin = xmin;
-  double xmax = -xmin;
-  double ymax = xmax;
-  for (KplItem *itm = items.at(1); itm; itm = items.next()) {
-    fd->xmi = xmin;
-    fd->ymi = ymin;
-    fd->xma = xmax;
-    fd->yma = ymax;
-    itm->minMax(&fd->xmi, &fd->xma, &fd->ymi, &fd->yma);
-    xmin = QMIN(xmin, fd->xmi);
-    xmax = QMAX(xmax, fd->xma);
-    ymin = QMIN(ymin, fd->ymi);
-    ymax = QMAX(ymax, fd->yma);
-  }
-  Utils::autoSc(&fd->xmi, &fd->xma, &fd->xtic, &fd->mticx, &fd->ndigx,
-                xmin, xmax, fx, 0.2, false);
-  Utils::autoSc(&fd->ymi, &fd->yma, &fd->ytic, &fd->mticy, &fd->ndigy,
-                ymin, ymax, fy, 0.3, false);
-  for (KplItem* itm = items.at(1); itm; itm = items.next())
-    itm->normalize(fx, fy);
+  fd->autoScale(true, &items);
   ResidualsDlg dlg(this, m, &items);
   dlg.exec();
 }
