@@ -2,7 +2,7 @@
                           fitdlg.h  -  description
                              -------------------
     begin                : Tue May 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,16 +18,17 @@
 #ifndef FITDLG_H
 #define FITDLG_H
 
+#include <qmemarray.h>
+#include <qptrlist.h>
 #include <kdialogbase.h>
-#include <qlist.h>
 #include "kplnamespace.h"
 
 class QButtonGroup;
 class QCheckBox;
-class KConfig;
 class QLabel;
 class QLineEdit;
 class QListBox;
+class KConfig;
 class KURL;
 class ArrayItem;
 class FunItem;
@@ -73,13 +74,14 @@ public:
    * @param model pointer to KplDoc model object.
    * @param err0 pointer to structure containing the data error settings.
    */
-  ErrModDlg(QWidget* parent, KplDoc* model, Kpl::DataErrorStruct* err0);
+  ErrModDlg(QWidget* parent, KplDoc* model,
+            KplNamespace::DataErrorStruct* err0);
   /** Destructor. */
   ~ErrModDlg();
 
 protected:
   KplDoc* m;
-  Kpl::DataErrorStruct *err, *errt;
+  KplNamespace::DataErrorStruct *err, *errt;
   QLineEdit *fileName, *func;
   QButtonGroup *bg;
 
@@ -115,8 +117,8 @@ public:
    * @param fd pointer to function item list.
    * @param mode combination of ShowDlg and AutoFit.
    */
-  FitDlg(QWidget* parent, KplDoc* model, QList<ArrayItem>* ad,
-         QList<FunItem>* fd, int mode);
+  FitDlg(QWidget* parent, KplDoc* model, QPtrList<ArrayItem>* ad,
+         QPtrList<FunItem>* fd, int mode);
   /** Destructor. */
   ~FitDlg();
   /**
@@ -135,10 +137,11 @@ protected:
   int np, dlgMode;
   double corr[KPL_NPMAX * KPL_NPMAX];
   KplDoc* m;
-  QArray<double> fvec;
-  QList<ArrayItem>* ad;
-  QList<FunItem>* fd;
-  Kpl::AutoStruct* aut;
+  QMemArray<double> fvec, sig;
+  QPtrList<ArrayItem>* ad;
+  QPtrList<FunItem>* fd;
+  QPtrList<QWidget> widgetList;
+  KplNamespace::AutoStruct* aut;
   LMFit* lm;
   QListBox* results;
   KplDoubleEdit* eTol;
@@ -150,8 +153,7 @@ protected:
   KplSpinBox *sArr, *sItmax;
   QPushButton* showCorr;
   QPushButton* errMod;
-  QList<QWidget> widgetList;
-  Kpl::DataErrorStruct* err;
+  KplNamespace::DataErrorStruct* err;
   KConfig* config;
   SourceWidget* sw;
 
