@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -20,31 +20,31 @@
  ***************************************************************************/
 
 #include <math.h>
-#include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qradiobutton.h>
-#include <qlineedit.h>
+#include <qcheckbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <klocale.h>
-#include <kcolorbtn.h>
-#include <kglobal.h>
+#include <qlineedit.h>
+#include <qradiobutton.h>
+#include <kcolorbutton.h>
 #include <kconfig.h>
-#include "framedlg.h"
-#include "kpldoc.h"
-#include "edittextdlg.h"
+#include <kglobal.h>
+#include <klocale.h>
 #include "arrayitem.h"
+#include "edittextdlg.h"
+#include "framedlg.h"
+#include "frameitem.h"
 #include "funitem.h"
+#include "kpldoc.h"
 #include "kpldoubleedit.h"
 #include "kplspinbox.h"
 #include "utils.h"
 
 FrameDlg::FrameDlg(QWidget* _parent, KplDoc* model, int it) :
  KDialogBase(Plain, i18n("Frame"), Help | Ok | Apply | Cancel, Ok, _parent, 0,
-             true, true), m(model), item(it), iex(999), iey(999)
+             true, true), m(model), norm(false), item(it)
 {
-  pfd = (FrameItem*) m->items()->at(item);
-  fd = *pfd;
+  fi = (FrameItem*) m->items()->at(item);
   Utils::setSize(this, "FrameDialog");
   QFrame* frame = plainPage();
   QGridLayout* grid = new QGridLayout(frame, 3, 2, 0, spacingHint());
@@ -56,92 +56,92 @@ FrameDlg::FrameDlg(QWidget* _parent, KplDoc* model, int it) :
   vbox2->addWidget(new QRadioButton(i18n("Tics with numbers"), bg));
   vbox2->addWidget(new QRadioButton(i18n("Grid"), bg));
   vbox2->addWidget(new QRadioButton(i18n("Grid with numbers"), bg));
-  ((QRadioButton*) bg->find(fd.gridmode))->setChecked(true);
+  ((QRadioButton*) bg->find(fi->gridmode))->setChecked(true);
   vbox2 = new QVBoxLayout(spacingHint());
   grid->addLayout(vbox2, 0, 1);
   QGroupBox* g = new QGroupBox(0, Qt::Vertical, i18n("Window"), frame);
   vbox2->addWidget(g);
   QGridLayout* grid2 = new QGridLayout(g->layout(), 2, 7, spacingHint());
   grid2->addWidget(new QLabel(i18n("Left margin"), g), 0, 0);
-  grid2->addWidget(ex0 = new KplDoubleEdit(fd.x0, 0.0, 200.0, g), 0, 1);
+  grid2->addWidget(ex0 = new KplDoubleEdit(fi->x0, 0.0, 200.0, g), 0, 1);
   grid2->addWidget(new QLabel("cm", g), 0, 2);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 3);
   grid2->addWidget(new QLabel(i18n("Width"), g), 0, 4);
-  grid2->addWidget(exl = new KplDoubleEdit(fd.w, 0.5, 200.0, g), 0, 5);
+  grid2->addWidget(exl = new KplDoubleEdit(fi->w, 0.5, 200.0, g), 0, 5);
   grid2->addWidget(new QLabel("cm", g), 0, 6);
   grid2->addWidget(new QLabel(i18n("Bottom margin"), g), 1, 0);
-  grid2->addWidget(ey0 = new KplDoubleEdit(fd.y0, 0.0, 200.0, g), 1, 1);
+  grid2->addWidget(ey0 = new KplDoubleEdit(fi->y0, 0.0, 200.0, g), 1, 1);
   grid2->addWidget(new QLabel("cm", g), 1, 2);
   grid2->addWidget(new QLabel(i18n("Height"), g), 1, 4);
-  grid2->addWidget(eyl = new KplDoubleEdit(fd.h, 0.5, 200.0, g), 1, 5);
+  grid2->addWidget(eyl = new KplDoubleEdit(fi->h, 0.5, 200.0, g), 1, 5);
   grid2->addWidget(new QLabel("cm", g), 1, 6);
   vbox2->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Scaling"), frame));
   grid2 = new QGridLayout(g->layout(), 2, 7, 6);
   grid2->addWidget(new QLabel("xmin", g), 0, 0);
-  grid2->addWidget(exMin = new KplDoubleEdit(fd.xmi, fd.logx ?
+  grid2->addWidget(exMin = new KplDoubleEdit(fi->xmi, fi->logx ?
                                              1.0e-300 : -1.0e300,
                                              1.0e300, g, 'g', 6), 0, 1);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 2);
   grid2->addWidget(new QLabel("xmax", g), 0, 3);
-  grid2->addWidget(exMax = new KplDoubleEdit(fd.xma, fd.logx ?
+  grid2->addWidget(exMax = new KplDoubleEdit(fi->xma, fi->logx ?
                                              1.0e-300 : -1.0e300,
                                              1.0e300, g, 'g', 6), 0, 4);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 5);
   grid2->addWidget(logX = new QCheckBox("log", g), 0, 6);
-  logX->setChecked(fd.logx);
+  logX->setChecked(fi->logx);
   grid2->addWidget(new QLabel("ymin", g), 1, 0);
-  grid2->addWidget(eyMin = new KplDoubleEdit(fd.ymi, fd.logy ?
+  grid2->addWidget(eyMin = new KplDoubleEdit(fi->ymi, fi->logy ?
                                              1.0e-300 : -1.0e300,
                                              1.0e300, g, 'g', 6), 1, 1);
   grid2->addWidget(new QLabel("ymax", g), 1, 3);
-  grid2->addWidget(eyMax = new KplDoubleEdit(fd.yma, fd.logy ?
+  grid2->addWidget(eyMax = new KplDoubleEdit(fi->yma, fi->logy ?
                                              1.0e-300 : -1.0e300,
                                              1.0e300, g, 'g', 6), 1, 4);
   grid2->addWidget(logY = new QCheckBox("log", g), 1, 6);
-  logY->setChecked(fd.logy);
+  logY->setChecked(fi->logy);
   grid->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Colors"), frame),
                   1, 0);
   grid2 = new QGridLayout(g->layout(), 2, 2, spacingHint());
   grid2->addWidget(new QLabel(i18n("Frame"), g), 0, 0);
-  grid2->addWidget(colFrame = new KColorButton(QColor(fd.colFrame), g), 0, 1);
+  grid2->addWidget(colFrame = new KColorButton(QColor(fi->colFrame), g), 0, 1);
   grid2->addWidget(new QLabel(i18n("Grid"), g), 1, 0);
-  grid2->addWidget(colGrid = new KColorButton(QColor(fd.colGrid), g), 1, 1);
+  grid2->addWidget(colGrid = new KColorButton(QColor(fi->colGrid), g), 1, 1);
   grid->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Axes"), frame),
                   1, 1);
   grid2 = new QGridLayout(g->layout(), 2, 11, spacingHint());
   grid2->addWidget(new QLabel("xtic", g), 0, 0);
-  grid2->addWidget(exTic = new KplDoubleEdit(fd.xtic, g), 0, 1);
+  grid2->addWidget(exTic = new KplDoubleEdit(fi->xtic, g), 0, 1);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 2);
   grid2->addWidget(new QLabel("xoff", g), 0, 3);
-  grid2->addWidget(exOff = new KplDoubleEdit(fd.xOff, 0.0, 1.0e300, g, 'g', 6),
+  grid2->addWidget(exOff = new KplDoubleEdit(fi->xOff, 0.0, 1.0e300, g, 'g', 6),
                    0, 4);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 5);
   grid2->addWidget(new QLabel("mticx", g), 0, 6);
   grid2->addWidget(emTicx = new KplSpinBox(0, 10, 1, g), 0, 7);
-  emTicx->setValue(fd.mticx);
+  emTicx->setValue(fi->mticx);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 8);
   grid2->addWidget(new QLabel("ndigx", g), 0, 9);
   grid2->addWidget(enDigx = new KplSpinBox(-1, 8, 1, g), 0, 10);
-  enDigx->setValue(fd.ndigx);
-  enDigx->setEnabled(!fd.logx);
+  enDigx->setValue(fi->ndigx);
+  enDigx->setEnabled(!fi->logx);
   grid2->addWidget(new QLabel("ytic", g), 1, 0);
-  grid2->addWidget(eyTic = new KplDoubleEdit(fd.ytic, g), 1, 1);
+  grid2->addWidget(eyTic = new KplDoubleEdit(fi->ytic, g), 1, 1);
   grid2->addWidget(new QLabel("yoff", g), 1, 3);
-  grid2->addWidget(eyOff = new KplDoubleEdit(fd.yOff, 0.0, 1.0e300, g, 'g', 6),
+  grid2->addWidget(eyOff = new KplDoubleEdit(fi->yOff, 0.0, 1.0e300, g, 'g', 6),
                    1, 4);
   grid2->addWidget(new QLabel("mticy", g), 1, 6);
   grid2->addWidget(emTicy = new KplSpinBox(0, 10, 1, g), 1, 7);
-  emTicy->setValue(fd.mticy);
+  emTicy->setValue(fi->mticy);
   grid2->addWidget(new QLabel("ndigy", g), 1, 9);
   grid2->addWidget(enDigy = new KplSpinBox(-1, 8, 1, g), 1, 10);
-  enDigy->setValue(fd.ndigy);
-  enDigy->setEnabled(!fd.logy);
+  enDigy->setValue(fi->ndigy);
+  enDigy->setEnabled(!fi->logy);
   grid->addLayout(vbox2 = new QVBoxLayout(6), 2, 0);
   vbox2->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Automatic"),
                    frame));
   QVBoxLayout* vbox3 = new QVBoxLayout(g->layout(), spacingHint());
   vbox3->addWidget(autoNorm = new QCheckBox(i18n("Normalization"), g));
-  autoNorm->setChecked(m->options()->autoNorm && (!(fd.logx || fd.logy)));
+  autoNorm->setChecked(m->options()->autoNorm && (!(fi->logx || fi->logy)));
   QPushButton* b = new QPushButton(i18n("Autoscale"), g);
   vbox3->addWidget(b);
   connect(b, SIGNAL(clicked()), SLOT(slotAutoScale()));
@@ -169,38 +169,38 @@ FrameDlg::FrameDlg(QWidget* _parent, KplDoc* model, int it) :
   grid2 = new QGridLayout(g->layout(), 3, 8, spacingHint());
   grid2->addWidget(new QLabel("iex", g), 0, 0);
   grid2->addWidget(ex = new KplSpinBox(-300, 300, 1, g), 0, 1);
-  ex->setValue(fd.iex);
+  ex->setValue(fi->iex);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::Minimum), 0, 2);
   grid2->addWidget(new QLabel(i18n("x axis"), g), 0, 3);
-  grid2->addWidget(eLetX = new QLineEdit(fd.sx, g), 0, 4);
+  grid2->addWidget(eLetX = new QLineEdit(fi->sx, g), 0, 4);
   grid2->addWidget(b = new QPushButton("...", g), 0, 5);
   b->setFixedWidth(28);
   connect(b, SIGNAL(clicked()), SLOT(slotEditLetX()));
   grid2->addWidget(xBottom = new QCheckBox(i18n("Bottom"), g), 0, 6);
-  xBottom->setChecked(fd.xBottom);
+  xBottom->setChecked(fi->xBottom);
   grid2->addWidget(xTop = new QCheckBox(i18n("Top"), g), 0, 7);
-  xTop->setChecked(fd.xTop);
+  xTop->setChecked(fi->xTop);
   grid2->addWidget(new QLabel("iey", g), 1, 0);
   grid2->addWidget(ey = new KplSpinBox(-300, 300, 1, g), 1, 1);
-  ey->setValue(fd.iey);
+  ey->setValue(fi->iey);
   grid2->addWidget(new QLabel(i18n("y axis"), g), 1, 3);
-  grid2->addWidget(eLetY = new QLineEdit(fd.sy, g), 1, 4);
+  grid2->addWidget(eLetY = new QLineEdit(fi->sy, g), 1, 4);
   grid2->addWidget(b = new QPushButton("...", g), 1, 5);
   b->setFixedWidth(28);
   connect(b, SIGNAL(clicked()), SLOT(slotEditLetY()));
   grid2->addWidget(yLeft = new QCheckBox(i18n("Left"), g), 1, 6);
-  yLeft->setChecked(fd.yLeft);
+  yLeft->setChecked(fi->yLeft);
   grid2->addWidget(yRight = new QCheckBox(i18n("Right"), g), 1, 7);
-  yRight->setChecked(fd.yRight);
+  yRight->setChecked(fi->yRight);
   grid2->addWidget(new QLabel(i18n("Heading"), g), 2, 3);
-  grid2->addWidget(eLetH = new QLineEdit(fd.sh, g), 2, 4);
+  grid2->addWidget(eLetH = new QLineEdit(fi->sh, g), 2, 4);
   grid2->addWidget(b = new QPushButton("...", g), 2, 5);
   b->setFixedWidth(28);
   connect(b, SIGNAL(clicked()), SLOT(slotEditLetH()));
   QHBoxLayout* hbox = new QHBoxLayout(vbox2, 6);
   hbox->addWidget(new QLabel(i18n("Symbol size"), frame));
   hbox->addWidget(eRelSiz = new KplSpinBox(10, 800, 1, frame));
-  eRelSiz->setValue(qRound(100 * fd.relsiz));
+  eRelSiz->setValue(qRound(100 * fi->relsiz));
   eRelSiz->setSuffix(" %");
   setHelp("SEC-FRAME");
   connect(logX, SIGNAL(toggled(bool)), SLOT(slotLogToggled(bool)));
@@ -215,55 +215,48 @@ FrameDlg::~FrameDlg()
 
 void FrameDlg::getValues(bool ok)
 {
-  fd.xmi = exMin->value();
-  fd.xma = exMax->value();
-  fd.ymi = eyMin->value();
-  fd.yma = eyMax->value();
-  fd.logx = logX->isChecked();
-  fd.logy = logY->isChecked();
-  fd.xBottom = xBottom->isChecked();
-  fd.xTop = xTop->isChecked();
-  fd.yLeft = yLeft->isChecked();
-  fd.yRight = yRight->isChecked();
-  fd.xtic = exTic->value();
-  if (!fd.logx) {
-    double d = 0.01 *(fd.xma - fd.xmi);
-    if (fd.xtic < d)
-      fd.xtic = exTic->setValue(d);
+  fi->xmi = exMin->value();
+  fi->xma = exMax->value();
+  fi->ymi = eyMin->value();
+  fi->yma = eyMax->value();
+  fi->logx = logX->isChecked();
+  fi->logy = logY->isChecked();
+  fi->xBottom = xBottom->isChecked();
+  fi->xTop = xTop->isChecked();
+  fi->yLeft = yLeft->isChecked();
+  fi->yRight = yRight->isChecked();
+  fi->xtic = exTic->value();
+  if (!fi->logx) {
+    double d = 0.01 *(fi->xma - fi->xmi);
+    if (fi->xtic < d)
+      fi->xtic = exTic->setValue(d);
   }
-  fd.ytic = eyTic->value();
-  if (!fd.logy) {
-    double d = 0.01 *(fd.yma - fd.ymi);
-    if (fd.ytic < d)
-      fd.ytic = eyTic->setValue(d);
+  fi->ytic = eyTic->value();
+  if (!fi->logy) {
+    double d = 0.01 *(fi->yma - fi->ymi);
+    if (fi->ytic < d)
+      fi->ytic = eyTic->setValue(d);
   }
-  fd.xOff = exOff->value();
-  fd.yOff = eyOff->value();
-  fd.setPos(ex0->value(), ey0->value());
-  fd.w = exl->value();
-  fd.h = eyl->value();
-  fd.colFrame = colFrame->color().rgb();
-  fd.colGrid = colGrid->color().rgb();
-  fd.iex = ex->interpretedValue();
-  fd.iey = ey->interpretedValue();
-  fd.mticx = emTicx->interpretedValue();
-  fd.mticy = emTicy->interpretedValue();
-  fd.ndigx = enDigx->interpretedValue();
-  fd.ndigy = enDigy->interpretedValue();
-  fd.sx = eLetX->text();
-  fd.sy = eLetY->text();
-  fd.sh = eLetH->text();
-  fd.relsiz = 0.01 * eRelSiz->interpretedValue();
-  fd.gridmode = bg->id(bg->selected());
-  if ((iex != 999) && (iey != 999)) {
-    for (KplItem* itm = m->items()->at(item + 1); itm;
-         itm = m->items()->next()) {
-      itm->normalize(fx, fy);
-      if (itm->iType() == KplItem::Frame)
-        break;
-    }
-  }
-  *pfd = fd;
+  fi->xOff = exOff->value();
+  fi->yOff = eyOff->value();
+  fi->setPos(ex0->value(), ey0->value());
+  fi->w = exl->value();
+  fi->h = eyl->value();
+  fi->colFrame = colFrame->color().rgb();
+  fi->colGrid = colGrid->color().rgb();
+  fi->iex = ex->interpretedValue();
+  fi->iey = ey->interpretedValue();
+  fi->mticx = emTicx->interpretedValue();
+  fi->mticy = emTicy->interpretedValue();
+  fi->ndigx = enDigx->interpretedValue();
+  fi->ndigy = enDigy->interpretedValue();
+  fi->sx = eLetX->text();
+  fi->sy = eLetY->text();
+  fi->sh = eLetH->text();
+  fi->relsiz = 0.01 * eRelSiz->interpretedValue();
+  fi->gridmode = bg->id(bg->selected());
+  if (norm)
+    fi->normalize(item, m->items(), fx, fy);
   m->setModified();
   m->backupItems();
   if (ok)
@@ -324,25 +317,25 @@ void FrameDlg::slotEditLetH()
 
 void FrameDlg::slotAutoScale()
 {
-  double xmi, xma, ymi, yma, xtic, ytic;
-  int mticx, mticy, ndigx, ndigy;
-  m->autoScaleFrame(autoNorm->isChecked(), item, &iex, &iey, &fx, &fy,
-                    &xmi, &xma, &ymi, &yma, &xtic, &ytic, &mticx, &mticy,
-                    &ndigx, &ndigy, exl->value() / eyl->value(),
-                    logX->isChecked(), logY->isChecked());
-  if ((iex != 999) && (iey != 999)) {
-    ex->setValue(iex);
-    emTicx->setValue(mticx);
-    enDigx->setValue(ndigx);
-    exMin->setValue(xmi);
-    exMax->setValue(xma);
-    exTic->setValue(xtic);
-    ey->setValue(iey);
-    emTicy->setValue(mticy);
-    enDigy->setValue(ndigy);
-    eyMin->setValue(ymi);
-    eyMax->setValue(yma);
-    eyTic->setValue(ytic);
+  FrameItem ft = *fi;
+  ft.w = exl->value();
+  ft.h = eyl->value();
+  ft.logx = logX->isChecked();
+  ft.logy = logY->isChecked();
+  norm = ft.calcAutoScale(autoNorm->isChecked(), item, m->items(), &fx, &fy);
+  if (norm) {
+    ex->setValue(ft.iex);
+    emTicx->setValue(ft.mticx);
+    enDigx->setValue(ft.ndigx);
+    exMin->setValue(ft.xmi);
+    exMax->setValue(ft.xma);
+    exTic->setValue(ft.xtic);
+    ey->setValue(ft.iey);
+    emTicy->setValue(ft.mticy);
+    enDigy->setValue(ft.ndigy);
+    eyMin->setValue(ft.ymi);
+    eyMax->setValue(ft.yma);
+    eyTic->setValue(ft.ytic);
     exOff->setValue(0.0);
     eyOff->setValue(0.0);
   }
