@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -23,12 +23,12 @@
 #define FRAMEDLG_H
 
 #include <kdialogbase.h>
-#include "frameitem.h"
 
 class QLineEdit;
 class QButtonGroup;
 class QCheckBox;
 class KColorButton;
+class FrameItem;
 class KplDoc;
 class KplDoubleEdit;
 class KplSpinBox;
@@ -59,10 +59,10 @@ public:
 
 protected:
   KplDoc* m;
-  int item, iex, iey;
+  bool norm;
+  int item;
   double fx, fy;
-  FrameItem* pfd;
-  FrameItem fd;
+  FrameItem* fi;
   KplDoubleEdit *ex0, *exl, *ey0, *eyl, *exMin, *exMax, *eyMin, *eyMax,
                 *exTic, *eyTic, *exOff, *eyOff;
   QLineEdit *eLetX, *eLetY, *eLetH;
