@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 29 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,12 +19,16 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <ksimpleconfig.h>
+#include <qptrlist.h>
 #include <klocale.h>
-#include "kgraph.h"
-#include "kplchecklistitem.h"
+#include <ksimpleconfig.h>
 #include "frameitem.h"
+#include "kgraph.h"
+#include "utils.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
 #include "framedlg.h"
+#endif
 
 FrameItem::FrameItem() : logx(false), logy(false), xBottom(true), xTop(false),
  yLeft(true), yRight(false), collapsed(false), ndigx(-1), ndigy(-1), mticx(5),
@@ -36,7 +40,7 @@ FrameItem::FrameItem() : logx(false), logy(false), xBottom(true), xTop(false),
   y0 = 3.0;
 }
 
-FrameItem::FrameItem(Kpl::AutoStruct* aut) :
+FrameItem::FrameItem(KplNamespace::AutoStruct* aut) :
  logx(aut->autoLogX), logy(aut->autoLogY), xBottom(true), xTop(false),
  yLeft(true), yRight(false), collapsed(false), ndigx(-1), ndigy(-1), mticx(5),
  mticy(2), gridmode(aut->autoGrid), iex(0), iey(0), colFrame(aut->colFrame),
@@ -47,9 +51,11 @@ FrameItem::FrameItem(Kpl::AutoStruct* aut) :
 {
   x0 = aut->x0Auto;
   y0 = aut->y0Auto;
+  relsiz = aut->relSize;
 }
 
-FrameItem::FrameItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) : KplItem(plo)
+FrameItem::FrameItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
+ KplItem(plo)
 {
   logx = plo->readBoolEntry("logx");
   logy = plo->readBoolEntry("logy");
@@ -66,18 +72,9 @@ FrameItem::FrameItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) : KplItem(plo)
   iex = plo->readNumEntry("iex");
   iey = plo->readNumEntry("iey");
   QString s = plo->readEntry("colframe", "");
-  unsigned u;
-  if (!s.isEmpty()) {
-    sscanf(s.latin1(), "%x", &u);
-    colFrame = KplGraph::rgbQt(u);
-  } else
-    colFrame = aut->colFrame;
+  colFrame = s.isEmpty() ? aut->colFrame : KplGraph::rgbQt(s);
   s = plo->readEntry("colgrid", "");
-  if (!s.isEmpty()) {
-    sscanf(s, "%x", &u);
-    colGrid = KplGraph::rgbQt(u);
-  } else
-    colGrid = aut->colGrid;
+  colGrid = s.isEmpty() ? aut->colGrid : KplGraph::rgbQt(s);
   xf = plo->readDoubleNumEntry("xf", aut->xf);
   yf = plo->readDoubleNumEntry("yf", aut->yf);
   x0 = plo->readDoubleNumEntry("xw0", aut->x0Auto);
@@ -104,8 +101,9 @@ FrameItem::FrameItem(bool act, bool lgx, bool lgy, int ndx, int ndy,
                      double xmin, double xmax, double ymin,
                      double ymax, double xt, double yt, double relSize,
                      const QString& sX, const QString& sY, const QString& sH,
-                     Kpl::AutoStruct* aut, double x_off, double y_off,
-                     bool xB, bool xT, bool yL, bool yR, bool coll) :
+                     KplNamespace::AutoStruct* aut, double x_off,
+                     double y_off, bool xB, bool xT, bool yL, bool yR,
+                     bool coll) :
  logx(lgx), logy(lgy), xBottom(xB), xTop(xT), yLeft(yL), yRight(yR),
  collapsed(coll),  ndigx(ndx), ndigy(ndy), mticx(mtx), mticy(mty),
  gridmode(gm), iex(ex), iey(ey), xf(aut->xf), yf(aut->yf), w(wx), h(hy),
@@ -116,11 +114,8 @@ FrameItem::FrameItem(bool act, bool lgx, bool lgy, int ndx, int ndy,
   x0 = x_0;
   y0 = y_0;
   relsiz = relSize;
-  unsigned u;
-  sscanf(col_f.latin1(), "%x", &u);
-  colFrame = KplGraph::rgbQt(u);
-  sscanf(col_g.latin1(), "%x", &u);
-  colGrid = KplGraph::rgbQt(u);
+  colFrame = KplGraph::rgbQt(col_f);
+  colGrid = KplGraph::rgbQt(col_g);
 }
 
 FrameItem::~FrameItem()
@@ -162,6 +157,7 @@ void FrameItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void FrameItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                          KplDoc* m) const
 {
@@ -188,9 +184,8 @@ void FrameItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
   plo->writeEntry("gridmode", gridmode);
   plo->writeEntry("iex", iex);
   plo->writeEntry("iey", iey);
-  QString s;
-  plo->writeEntry("colframe", s.sprintf("%x", KplGraph::rgbQt1(colFrame)));
-  plo->writeEntry("colgrid", s.sprintf("%x", KplGraph::rgbQt1(colGrid)));
+  plo->writeEntry("colframe", QString::number(KplGraph::rgbQt1(colFrame), 16));
+  plo->writeEntry("colgrid", QString::number(KplGraph::rgbQt1(colGrid), 16));
   plo->writeEntry("xf", xf);
   plo->writeEntry("yf", yf);
   plo->writeEntry("xw0", x0);
@@ -212,7 +207,7 @@ void FrameItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
   plo->writeEntry("sh", sh);
 }
 
-void FrameItem::setText(KplCheckListItem* it, bool*, bool*) const
+void FrameItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Frame"));
   QString s1, s2;
@@ -225,18 +220,97 @@ int FrameItem::editItem(QWidget* parent, KplDoc* m, int i)
   FrameDlg dlg(parent, m, i);
   return dlg.exec();
 }
+#endif
 
 KplItem* FrameItem::copy() const
 {
   return new FrameItem(*this);
 }
 
-void FrameItem::setCollapsed(bool b)
-{
-  collapsed = b;
+bool FrameItem::calcAutoScale(bool autoNorm, int item,
+                              QPtrList<KplItem>* items, double* fx, double* fy)
+{ int iexmin, ieymin;
+  if (autoNorm) {
+    double fxt, fyt;
+    int iext, ieyt;
+    iexmin = ieymin = 999;
+    for (KplItem* itm = items->at(item + 1); itm; itm = items->next()) {
+      if (itm->iType() == KplItem::Frame)
+        break;
+      if (itm->isActive()) {
+        iext = iexmin;
+        ieyt = ieymin;
+        itm->expoItem(&iext, &ieyt, &fxt, &fyt);
+        if (iext < iexmin) {
+          iexmin = iext;
+          *fx = fxt;
+        }
+        if (ieyt < ieymin) {
+          ieymin = ieyt;
+          *fy = fyt;
+        }
+      }
+    }
+  } else {
+    iexmin = ieymin = 0;
+    *fx = *fy = 1.0;
+  }
+  bool success = (iexmin != 999) && (ieymin != 999);
+  if (success) {
+    iex = iexmin;
+    iey = ieymin;
+    double xmin = 1.0e300;
+    double ymin = xmin;
+    double xmax = -xmin;
+    double ymax = xmax;
+    for (KplItem *itm = items->at(item + 1); itm; itm = items->next()) {
+      if (itm->iType() == KplItem::Frame)
+        break;
+      if (itm->isActive()) {
+        double xmint = xmin;
+        double ymint = ymin;
+        double xmaxt = xmax;
+        double ymaxt = ymax;
+        itm->minMax(&xmint, &xmaxt, &ymint, &ymaxt);
+        xmin = QMIN(xmin, xmint);
+        xmax = QMAX(xmax, xmaxt);
+        ymin = QMIN(ymin, ymint);
+        ymax = QMAX(ymax, ymaxt);
+      }
+    }
+    autoScale(xmin, xmax, *fx, ymin, ymax, *fy);
+  }
+  return success;
 }
 
-bool FrameItem::isCollapsed() const
+void FrameItem::normalize(int item, QPtrList<KplItem>* items, double fx,
+                          double fy)
 {
-  return collapsed;
+  for (KplItem* itm = items->at(item + 1); itm; itm = items->next()) {
+    if (itm->iType() == KplItem::Frame)
+      break;
+    itm->normalize(fx, fy);
+  }
+}
+
+void FrameItem::autoScale(double xmin, double xmax, double fx, double ymin,
+                          double ymax, double fy)
+{
+  Utils::autoSc(&xmi, &xma, &xtic, &mticx, &ndigx, xmin, xmax, fx, 0.2, logx);
+  Utils::autoSc(&ymi, &yma, &ytic, &mticy, &ndigy, ymin, ymax, fy,
+                0.2 * w / h, logy);
+}
+
+bool FrameItem::autoScale(bool autoNorm, QPtrList<KplItem>* items)
+{
+  int item = items->find(this);
+  if (item == -1)
+    return false;
+  double fx, fy;
+  if (autoNorm)
+    logx = logy = false;
+  bool success = calcAutoScale(autoNorm, item, items, &fx, &fy);
+  if (success)
+    normalize(item, items, fx, fy);
+  return success;
 }
