@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 29 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,10 +22,9 @@
 #ifndef FRAMEITEM_H
 #define FRAMEITEM_H
 
-#include <qstring.h>
 #include "kplitem.h"
 
-class KplCheckListItem;
+template<class> class QPtrList;
 
 /**
   * Frame item class. Class for frame items with tics, grid, labels.
@@ -40,13 +39,13 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  FrameItem(Kpl::AutoStruct* aut);
+  FrameItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  FrameItem(KSimpleConfig* plo, Kpl::AutoStruct* aut);
+  FrameItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
@@ -92,28 +91,67 @@ public:
             double xmin, double xmax, double ymin, double ymax,
             double xtic, double ytic, double relSize,
             const QString& sx, const QString& sy, const QString& sh,
-            Kpl::AutoStruct* aut, double xOff = 0.0, double yOff = 0.0,
-            bool xBottom = true, bool xTop = false,
+            KplNamespace::AutoStruct* aut, double xOff = 0.0,
+            double yOff = 0.0, bool xBottom = true, bool xTop = false,
             bool yLeft = true, bool yRight = false, bool collapsed = false);
   /** Destructor */
   virtual ~FrameItem();
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
+#endif
   virtual KplItem* copy() const;
   /**
    * Sets collapse state for list view.
    * @param b state.
    */
-  void setCollapsed(bool b);
+  inline void setCollapsed(bool b) { collapsed = b; };
   /**
    * Returns clloapse state for list view.
    * @return state.
    */
-  bool isCollapsed() const;
+  inline bool isCollapsed() const { return collapsed; };
+  /**
+   * Calculates scaling parameters for a frame item and all its child items.
+   * @param autoNorm true for automatic normalization.
+   * @param item index of frame item.
+   * @param items list of plot items.
+   * @param fx normalization factor for x axis.
+   * @param fy normalization factor for y axis.
+   * @return true when scaling was successfull.
+   */
+  bool calcAutoScale(bool autoNorm, int item, QPtrList<KplItem>* items,
+                     double* fx, double* fy);
+  /**
+   * Normalizes all child items of a frame item.
+   * @param item index of frame item.
+   * @param items list of plot items.
+   * @param fx normalization factor for x axis.
+   * @param fy normalization factor for y axis.
+   */
+  void normalize(int item, QPtrList<KplItem>* items, double fx, double fy);
+  /**
+   * Calculates and sets the scaling parameters.
+   * @param xmin minimum x value.
+   * @param xmax maximum x value.
+   * @param fx x normalization factor.
+   * @param ymin minimum y value.
+   * @param ymax maximum y value.
+   * @param fy y normalization factor.
+   */
+  void autoScale(double xmin, double xmax, double fx, double ymin, double ymax,
+                 double fy);
+  /**
+   * Scales automatically the frame item and all its child items.
+   * @param autoNorm true for automatic normalization.
+   * @param items list of plot items.
+   * @return true when scaling was successfull.
+   */
+  bool autoScale(bool autoNorm, QPtrList<KplItem>* items);
 
 protected:
   bool logx, logy, xBottom, xTop, yLeft, yRight, collapsed;
@@ -123,10 +161,6 @@ protected:
   QString sx, sy, sh;
 
   friend class FrameDlg;
-  friend class ThreeDDlg;
-  friend class KplApp;
-  friend class FitDlg;
-  friend class SplFitDlg;
   friend class KplDoc;
   friend class KplView;
 };
