@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -25,11 +25,12 @@
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qlibrary.h>
 #include <qlineedit.h>
 #include <qlistbox.h>
 #include <qmultilinedit.h>
-#include <kapp.h>
-#include <kcolorbtn.h>
+#include <qtextstream.h>
+#include <kcolorbutton.h>
 #include <kfiledialog.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
@@ -38,11 +39,12 @@
 #include "brushdlg.h"
 #include "choosefuncdlg.h"
 #include "editparameterdlg.h"
-#include "fitpack.h"
 #include "funcdlg.h"
 #include "funitem.h"
+#include "kpl.h"
 #include "kpldoc.h"
 #include "kpldoubleedit.h"
+#include "kpldoublespinbox.h"
 #include "kplspinbox.h"
 #include "rootdlg.h"
 #include "splineitem.h"
@@ -86,7 +88,7 @@ FuncDlg::FuncDlg(QWidget* _parent, KplDoc* model, FunItem* fd0) :
   hbox->addWidget(b = new QPushButton(i18n("Save"), g));
   connect(b, SIGNAL(clicked()), SLOT(slotSaveParameter()));
   vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Range"), frame));
-  grid = new QGridLayout(g->layout(), 3, 5, spacingHint());
+  grid = new QGridLayout(g->layout(), 4, 5, spacingHint());
   grid->addWidget(new QLabel("xmin", g), 0, 0);
   char frm = m->options()->format;
   int prec = m->options()->prec;
@@ -97,29 +99,26 @@ FuncDlg::FuncDlg(QWidget* _parent, KplDoc* model, FunItem* fd0) :
   grid->addWidget(new QLabel("xmax", g), 0, 3);
   grid->addWidget(exMax = new KplDoubleEdit(fd->tmax, g, frm, prec), 0, 4);
   exMax->setMinimumWidth(w);
-#if KDE_VERSION_MAJOR > 2
   grid->addWidget(new QLabel(QString::fromUtf8("\316\224x"), g), 1, 0);
-#else
-  grid->addLayout(hbox = new QHBoxLayout(1), 1, 0);
-  QLabel* l = new QLabel("D", g);
-  l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
-  hbox->addWidget(l);
-  hbox->addWidget(new QLabel("x", g));
-  hbox->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding));
-#endif
   grid->addWidget(exStep = new KplDoubleEdit(fd->dt, g, frm, prec), 1, 1);
   exStep->setMinimumWidth(w);
-  grid->addWidget(new QLabel(i18n("x normalization"), g), 2, 0);
-  grid->addWidget(efx = new KplDoubleEdit(fd->fx, g), 2, 1);
-  grid->addWidget(new QLabel(i18n("y normalization"), g), 2, 3);
-  grid->addWidget(efy = new KplDoubleEdit(fd->fy, g), 2, 4);
+  grid->addWidget(new QLabel(i18n("x shift"), g), 2, 0);
+  Kpl* kpl = ((Kpl*) m->parent());
+  grid->addWidget(ex0 = new KplDoubleSpinBox(fd->x0, kpl->xStep(), g), 2, 1);
+  grid->addWidget(new QLabel(i18n("y shift"), g), 2, 3);
+  grid->addWidget(ey0 = new KplDoubleSpinBox(fd->y0, kpl->yStep(), g), 2, 4);
+  grid->addWidget(new QLabel(i18n("x normalization"), g), 3, 0);
+  grid->addWidget(efx = new KplDoubleEdit(fd->fx, g), 3, 1);
+  grid->addWidget(new QLabel(i18n("y normalization"), g), 3, 3);
+  grid->addWidget(efy = new KplDoubleEdit(fd->fy, g), 3, 4);
   vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Representation"),
                                     frame));
   grid = new QGridLayout(g->layout(), 2, 6, spacingHint());
   grid->addWidget(new QLabel(i18n("Symbol"), g), 0, 0);
   grid->addWidget(symb = new KplSpinBox(-17, 9, 1, g), 0, 1);
   symb->setValue(fd->symb);
-  grid->addWidget(new SymbolButton(g, symb), 0, 2);
+  SymbolButton* bSymb;
+  grid->addWidget(bSymb = new SymbolButton(g, symb, fd->fillStyle), 0, 2);
   grid->addWidget(new QLabel(i18n("Color"), g), 0, 4);
   grid->addWidget(colData = new KColorButton(fd->color, g), 0, 5);
   colData->setMinimumWidth(50);
@@ -127,10 +126,16 @@ FuncDlg::FuncDlg(QWidget* _parent, KplDoc* model, FunItem* fd0) :
   grid->addWidget(eRelSize = new KplSpinBox(10, 800, 1, g), 1, 1);
   eRelSize->setValue(qRound(100 * fd->relsiz));
   eRelSize->setSuffix(" %");
+  eRelSize->setDisabled(fd->fillStyle);
   grid->addWidget(new QLabel(i18n("Fill pattern"), g), 1, 4);
   grid->addWidget(fill = new BrushButton(g, fd->fillStyle), 1, 5);
   setHelp("SEC-FUNC");
   Utils::setSize(this, "FuncDialog");
+  connect(fill, SIGNAL(valueChanged(bool)), symb, SLOT(setDisabled(bool)));
+  connect(fill, SIGNAL(valueChanged(bool)), bSymb, SLOT(setDisabled(bool)));
+  connect(fill, SIGNAL(valueChanged(bool)), eRelSize, SLOT(setDisabled(bool)));
+  connect(ex0, SIGNAL(valueChanged(double)), SLOT(slotApply()));
+  connect(ey0, SIGNAL(valueChanged(double)), SLOT(slotApply()));
 }
 
 FuncDlg::~FuncDlg()
@@ -154,6 +159,8 @@ void FuncDlg::getFunc(QWidget* parent, QLineEdit* name, QLineEdit* func, bool d3
 
 bool FuncDlg::getTemp()
 {
+  fdt->x0 = ex0->value();
+  fdt->y0 = ey0->value();
   fdt->fx = efx->value();
   fdt->fy = efy->value();
   fdt->tmin = exMin->value();
@@ -161,10 +168,10 @@ bool FuncDlg::getTemp()
   fdt->dt = exStep->value();
   fdt->pathy = fileName->text();
   fdt->namey = func->text();
-  if (fdt->hmody)
-    lt_dlclose(fdt->hmody);
-  if (FunItem::getFuncAddr(fdt->pathy.path(), fdt->namey, &fdt->hmody,
-                           &fdt->fkty))
+  if (fdt->liby)
+    delete fdt->liby;
+  if (!FunItem::getFuncAddr(fdt->pathy.path(), fdt->namey, &fdt->liby,
+                            &fdt->fkty))
     return false;
   fdt->color = colData->color().rgb();
   fdt->symb = symb->interpretedValue();
@@ -236,22 +243,9 @@ void FuncDlg::slotUser2()
 {
   if (getTemp())
     if (fdt->tmax > fdt->tmin) {
-      int n = fdt->calcTable(fdt->logxo);
-      QArray<double> w(n);
-      for (int i = 0; i < n; i++)
-        w[i] = 1.0;
-      int nest = n + 4;
-      int lwrk = n * 4 + nest * 16;
-      QArray<double> wrk(lwrk);
-      QArray<int> iwrk(nest);
-      double fp;
       SplineItem spl;
-      spl.t.resize(nest);
-      spl.c.resize(nest);
-      int ier;
-      FitPack::curfit(0, n, fdt->tv, fdt->yv, w, fdt->tmin, fdt->tmax, 3, 0.0,
-                      nest, &spl.nk, spl.t.data(), spl.c.data(), &fp,
-                      wrk.data(), lwrk, iwrk.data(), &ier);
+      spl.interpolation(fdt->tv.data(), fdt->yv.data(),
+                        fdt->calcTable(fdt->logxo), fdt->tmin, fdt->tmax);
       RootDlg dlg(this, m, &spl);
       dlg.exec();
     } else
@@ -329,7 +323,7 @@ ParFuncDlg::ParFuncDlg(QWidget* _parent, KplDoc* model, ParFunItem* fd0) :
   hbox->addWidget(b = new QPushButton(i18n("Save"), g));
   connect(b, SIGNAL(clicked()), SLOT(slotSaveParametery()));
   vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Range"), frame));
-  grid = new QGridLayout(g->layout(), 3, 5, spacingHint());
+  grid = new QGridLayout(g->layout(), 4, 5, spacingHint());
   grid->addWidget(new QLabel("tmin", g), 0, 0);
   char frm = m->options()->format;
   int prec = m->options()->prec;
@@ -340,29 +334,26 @@ ParFuncDlg::ParFuncDlg(QWidget* _parent, KplDoc* model, ParFunItem* fd0) :
   grid->addWidget(new QLabel("tmax", g), 0, 3);
   grid->addWidget(etMax = new KplDoubleEdit(fd->tmax, g, frm, prec), 0, 4);
   etMax->setMinimumWidth(w);
-#if KDE_VERSION_MAJOR > 2
   grid->addWidget(new QLabel(QString::fromUtf8("\316\224t"), g), 1, 0);
-#else
-  grid->addLayout(hbox = new QHBoxLayout(1), 1, 0);
-  QLabel* l = new QLabel("D", g);
-  l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
-  hbox->addWidget(l);
-  hbox->addWidget(new QLabel("t", g));
-  hbox->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding));
-#endif
   grid->addWidget(etStep = new KplDoubleEdit(fd->dt, g, frm, prec), 1, 1);
   etStep->setMinimumWidth(w);
-  grid->addWidget(new QLabel(i18n("x normalization"), g), 2, 0);
-  grid->addWidget(efx = new KplDoubleEdit(fd->fx, g), 2, 1);
-  grid->addWidget(new QLabel(i18n("y normalization"), g), 2, 3);
-  grid->addWidget(efy = new KplDoubleEdit(fd->fy, g), 2, 4);
+  grid->addWidget(new QLabel(i18n("x shift"), g), 2, 0);
+  Kpl* kpl = ((Kpl*) m->parent());
+  grid->addWidget(ex0 = new KplDoubleSpinBox(fd->x0, kpl->xStep(), g), 2, 1);
+  grid->addWidget(new QLabel(i18n("y shift"), g), 2, 3);
+  grid->addWidget(ey0 = new KplDoubleSpinBox(fd->y0, kpl->yStep(), g), 2, 4);
+  grid->addWidget(new QLabel(i18n("x normalization"), g), 3, 0);
+  grid->addWidget(efx = new KplDoubleEdit(fd->fx, g), 3, 1);
+  grid->addWidget(new QLabel(i18n("y normalization"), g), 3, 3);
+  grid->addWidget(efy = new KplDoubleEdit(fd->fy, g), 3, 4);
   vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Representation"),
                                     frame));
   grid = new QGridLayout(g->layout(), 2, 6, spacingHint());
   grid->addWidget(new QLabel(i18n("Symbol"), g), 0, 0);
   grid->addWidget(symb = new KplSpinBox(-17, 9, 1, g), 0, 1);
   symb->setValue(fd->symb);
-  grid->addWidget(new SymbolButton(g, symb), 0, 2);
+  SymbolButton* bSymb;
+  grid->addWidget(bSymb = new SymbolButton(g, symb, fd->fillStyle), 0, 2);
   grid->addWidget(new QLabel(i18n("Color"), g), 0, 4);
   grid->addWidget(colData = new KColorButton(fd->color, g), 0, 5);
   colData->setMinimumWidth(50);
@@ -370,10 +361,16 @@ ParFuncDlg::ParFuncDlg(QWidget* _parent, KplDoc* model, ParFunItem* fd0) :
   grid->addWidget(eRelSize = new KplSpinBox(10, 800, 1, g), 1, 1);
   eRelSize->setValue(qRound(100 * fd->relsiz));
   eRelSize->setSuffix(" %");
+  eRelSize->setDisabled(fd->fillStyle);
   grid->addWidget(new QLabel(i18n("Fill pattern"), g), 1, 4);
   grid->addWidget(fill = new BrushButton(g, fd->fillStyle), 1, 5);
   setHelp("SEC-PARFUNC");
   Utils::setSize(this, "ParFuncDialog");
+  connect(fill, SIGNAL(valueChanged(bool)), symb, SLOT(setDisabled(bool)));
+  connect(fill, SIGNAL(valueChanged(bool)), bSymb, SLOT(setDisabled(bool)));
+  connect(fill, SIGNAL(valueChanged(bool)), eRelSize, SLOT(setDisabled(bool)));
+  connect(ex0, SIGNAL(valueChanged(double)), SLOT(slotApply()));
+  connect(ey0, SIGNAL(valueChanged(double)), SLOT(slotApply()));
 }
 
 ParFuncDlg::~ParFuncDlg()
@@ -384,6 +381,8 @@ ParFuncDlg::~ParFuncDlg()
 
 bool ParFuncDlg::getTemp()
 {
+  fdt->x0 = ex0->value();
+  fdt->y0 = ey0->value();
   fdt->fx = efx->value();
   fdt->fy = efy->value();
   fdt->tmin = etMin->value();
@@ -391,17 +390,17 @@ bool ParFuncDlg::getTemp()
   fdt->dt = etStep->value();
   fdt->pathx = fileNamex->text();
   fdt->namex = funcx->text();
-  if (fdt->hmodx)
-    lt_dlclose(fdt->hmodx);
-  if (FunItem::getFuncAddr(fdt->pathx.path(), fdt->namex, &fdt->hmodx,
-                           &fdt->fktx))
+  if (fdt->libx)
+    delete fdt->libx;
+  if (!FunItem::getFuncAddr(fdt->pathx.path(), fdt->namex, &fdt->libx,
+                            &fdt->fktx))
     return false;
   fdt->pathy = fileNamey->text();
   fdt->namey = funcy->text();
-  if (fdt->hmody)
-    lt_dlclose(fdt->hmody);
-  if (FunItem::getFuncAddr(fdt->pathy.path(), fdt->namey, &fdt->hmody,
-                           &fdt->fkty))
+  if (fdt->liby)
+    delete fdt->liby;
+  if (!FunItem::getFuncAddr(fdt->pathy.path(), fdt->namey, &fdt->liby,
+                            &fdt->fkty))
     return false;
   fdt->color = colData->color().rgb();
   fdt->symb = symb->interpretedValue();
