@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 29 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,24 +19,29 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <math.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
 #include <qfileinfo.h>
+#include <qlibrary.h>
 #include <qtextstream.h>
 #include <qurl.h>
 #include <klocale.h>
-#include <ksimpleconfig.h>
 #include <kmessagebox.h>
+#include <ksimpleconfig.h>
+#include "arrayitem.h"
 #include "funitem.h"
+#include "kgraph.h"
+#include "lmfit.h"
+#include "utils.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
 #include "funcdlg.h"
 #include "kpldoc.h"
-#include "kplgraph.h"
-#include "kplchecklistitem.h"
-#include "utils.h"
+#endif
 
 FunItem::FunItem() : logxo(false), tmin(0.0), tmax(0.0), dt(0.0),
- tmino(0.0), tmaxo(0.0), dto(0.0), fkty(0), fktyo(0), hmody(0)
+ tmino(0.0), tmaxo(0.0), dto(0.0), fkty(0), fktyo(0), liby(0)
 {
   init();
 }
@@ -44,29 +49,28 @@ FunItem::FunItem() : logxo(false), tmin(0.0), tmax(0.0), dt(0.0),
 FunItem::FunItem(const FunItem& f) :
  ScaledItem(f), logxo(f.logxo), tmin(f.tmin), tmax(f.tmax), dt(f.dt),
  tmino(f.tmino), tmaxo(f.tmaxo), dto(f.dto), fkty(f.fkty), fktyo(f.fktyo),
- tv(f.tv), yv(f.yv), namey(f.namey), pathy(f.pathy), hmody(f.hmody)
+ tv(f.tv), yv(f.yv), namey(f.namey), pathy(f.pathy), liby(0)
 {
-  lt_dlinit();
   memcpy(py, f.py, sizeof(py));
   memcpy(pyo, f.pyo, sizeof(pyo));
   tv.detach();
   yv.detach();
-  if (f.hmody)
-    getFuncAddr(pathy.path(), namey, &hmody, &fkty);
+  if (f.liby)
+    getFuncAddr(pathy.path(), namey, &liby, &fkty);
 }
 
-FunItem::FunItem(Kpl::AutoStruct* aut) : ScaledItem(aut), logxo(false),
- tmin(0.0), tmax(0.0), dt(0.0), tmino(0.0), tmaxo(0.0), dto(0.0),
- fkty(0), fktyo(0), hmody(0)
+FunItem::FunItem(KplNamespace::AutoStruct* aut) : ScaledItem(aut),
+ logxo(false), tmin(0.0), tmax(0.0), dt(0.0), tmino(0.0), tmaxo(0.0), dto(0.0),
+ fkty(0), fktyo(0), liby(0)
 {
   init();
 }
 
-FunItem::FunItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& uPlo) :
+FunItem::FunItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
+                 const KURL& uPlo) :
  ScaledItem(plo, aut), logxo(false), tmino(0.0), tmaxo(0.0), dto(0.0),
  fktyo(0)
 {
-  lt_dlinit();
   tmin = plo->readDoubleNumEntry("xfmin");
   tmax = plo->readDoubleNumEntry("xfmax", tmin + 1.0);
   dt = plo->readDoubleNumEntry("dx");
@@ -79,7 +83,7 @@ FunItem::FunItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& uPlo) :
   QString s = plo->readEntry("path", "");
   pathy = QUrl::isRelativeUrl(s) ? (uPlo.directory(false) + s) : s;
   pathy.cleanPath();
-  getFuncAddr(pathy.path(), namey, &hmody, &fkty);
+  getFuncAddr(pathy.path(), namey, &liby, &fkty);
 }
 
 FunItem::FunItem(bool act, int fill, int sym, const QString& col,
@@ -87,17 +91,15 @@ FunItem::FunItem(bool act, int fill, int sym, const QString& col,
                  const QString& name, const KURL& path, double relSize)
  : ScaledItem(act, fill, sym, col, xn, yn, relSize), logxo(false), tmin(xmin),
  tmax(xmax), dt(dx), tmino(0.0), tmaxo(0.0), dto(0.0), fkty(0), fktyo(0),
- namey(name), pathy(path), hmody(0)
+ namey(name), pathy(path), liby(0)
 {
   init();
-  getFuncAddr(pathy.path(), namey, &hmody, &fkty);
+  getFuncAddr(pathy.path(), namey, &liby, &fkty);
 }
 
 FunItem::~FunItem()
 {
-  if (hmody)
-    lt_dlclose(hmody);
-  lt_dlexit();
+  delete liby;
 }
 
 FunItem& FunItem::operator=(const FunItem& f)
@@ -121,11 +123,10 @@ FunItem& FunItem::operator=(const FunItem& f)
     yv.detach();
     namey = f.namey;
     pathy = f.pathy;
-    if (hmody)
-      lt_dlclose(hmody);
-    hmody = 0;
-    if (f.hmody)
-      getFuncAddr(pathy.path(), namey, &hmody, &fkty);
+    delete liby;
+    liby = 0;
+    if (f.liby)
+      getFuncAddr(pathy.path(), namey, &liby, &fkty);
   }
   return *this;
 }
@@ -142,11 +143,12 @@ void FunItem::draw(KplGraph* g)
     double sav = g->relSize();
     g->setRelSize(relsiz * sav);
     int n = calcTable(g->logx);
-    g->plArray(tv.data(), yv.data(), fx, fy, n, fillStyle);
+    g->plArray(tv.data(), yv.data(), fx, fy, n, fillStyle, true, x0, y0);
     g->setRelSize(sav);
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void FunItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
                        KplDoc* m) const
 {
@@ -157,19 +159,21 @@ void FunItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
   plo->writeEntry("xfmin", tmin, true, false, frm, prec);
   plo->writeEntry("xfmax", tmax, true, false, frm, prec);
   plo->writeEntry("dx", dt, true, false, frm, prec);
-  QStrList list;
+  QStringList list;
   for (int i = 0; i < KPL_NPMAX; i++)
-    list.insert(i, m->number(py[i]));
+    list.append(m->number(py[i]));
   plo->writeEntry("p", list, ' ');
   plo->writeEntry("name", namey);
   plo->writeEntry("path", Utils::relPath(url, pathy, _abs));
 }
 
-void FunItem::setText(KplCheckListItem* it, bool*, bool* funcs) const
+void FunItem::setText(QListViewItem* it, bool*, bool* funcs) const
 {
   *funcs = true;
   it->setText(1, i18n("Function"));
   QFileInfo fi(pathy.path());
+  KGraph g;
+  it->setPixmap(2, g.pixmap(symb, color));
   it->setText(2, QString("y = ") + fi.baseName() + "." + namey + "(x)");
 }
 
@@ -179,6 +183,15 @@ int FunItem::editItem(QWidget* parent, KplDoc* m, int)
   return dlg.exec();
 }
 
+void FunItem::exportTable(QTextStream& ts, KplDoc* m) const
+{
+  int n = calcTable(logxo);
+  for (int i = 0; i < n; i++)
+    ts << m->number(fx * tv[i]) << m->separator()
+       << m->number(fy * yv[i]) << "\n";
+}
+#endif
+
 KplItem* FunItem::copy() const
 {
   return new FunItem(*this);
@@ -197,10 +210,12 @@ void FunItem::expoItem(int* iext, int* ieyt, double* fxt, double* fyt) const
 void FunItem::minMax(double* xmi, double* xma, double* ymi, double* yma) const
 {
   if (fkty) {
-    *xmi = tmin;
-    *xma = tmax;
+    *xmi = tmin + x0;
+    *xma = tmax + x0;
     int n = calcTable(logxo);
-    Utils::minMaxFile(ymi, yma, yv, n);
+    Utils::minMaxFile(ymi, yma, yv.data(), n);
+    *ymi += y0;
+    *yma += y0;
   }
 }
 
@@ -210,46 +225,190 @@ void FunItem::setPar(int i, double value, bool yFun)
     py[i] = value;
 }
 
-void FunItem::exportTable(QTextStream& ts, KplDoc* m) const
+int FunItem::fit(ArrayItem* ad, bool* bFit, KplNamespace::DataErrorStruct* err,
+                 bool nonLin, double tol, int itMax, double* chisq,
+                 double* corr, double* pErr, double* avgErr)
 {
-  int n = calcTable(logxo);
-  for (int i = 0; i < n; i++)
-    ts << m->number(fx * tv[i]) << m->separator()
-       << m->number(fy * yv[i]) << "\n";
+  QPtrList<ArrayItem> al;
+  al.append(ad);
+  QPtrList<FunItem> fl;
+  fl.append(this);
+  return fit(&al, &fl, bFit, py, 0, 0, err, nonLin, tol, itMax, 0, chisq, corr,
+             pErr, avgErr);
+}
+
+int FunItem::fit(QPtrList<ArrayItem>* ad, QPtrList<FunItem>* fd, bool* bFit,
+                 double* p, QMemArray<double>* _fvec, QMemArray<double>* _sig,
+                 KplNamespace::DataErrorStruct* err, bool nonLin, double tol,
+                 int itMax, LMFit* _lm, double* chisq, double* corr,
+                 double* pErr, double* avgErr, QObject* parent)
+{
+  for (FunItem* f = fd->first(); f; f = fd->next())
+    if (!f->fkty)
+      return -101;
+  int i, k;
+  int np = 0;
+  for (i = 0; i < KPL_NPMAX; i++)
+    if (bFit[i])
+      np++;
+  if (!np)
+    return -102;
+  ArrayItem* a;
+  int n = 0;
+  for (a = ad->first(); a; a = ad->next())
+    n += a->n;
+  QMemArray<double> *fvec, *sig;
+  if (_fvec) {
+    fvec = _fvec;
+    fvec->resize(n);
+  } else
+    fvec = new QMemArray<double>(n);
+  if (_sig) {
+    sig = _sig;
+    sig->resize(n);
+  } else
+    sig = new QMemArray<double>(n);
+  int j = 0;
+  for (k = 0; k < (int) ad->count(); k++) {
+    a = ad->at(k);
+    if ((!err) || err[k].fitErrCol) {
+      for (i = 0; i < a->n; i++)
+        (*sig)[j++] = a->x[a->ie][a->istart + i];
+    } else {
+      double (*fktErrMod)(double, const double*);
+      QLibrary* lib;
+      if (!getFuncAddr(err[k].errModPath, err[k].errModName, &lib, &fktErrMod))
+        return -103;
+      for (i = 0; i < a->n; i++)
+        (*sig)[j++] = fktErrMod(a->x[err[k].errModArg ? a->iy : a->ix]
+                                    [a->istart + i], err[k].pErrMod);
+      delete lib;
+    }
+  }
+  LMFit* lm = _lm ? _lm : new LMFit(ad, fd, bFit, p, parent);
+  lm->sig = sig->data();
+  int wadim = (6 + np + n) * np + n;
+  double* wa = new double[wadim];
+  memset(wa, 0, wadim * sizeof(double));
+  double* guess = wa + 3 * np + n;
+  double* diag = guess + np;
+  double* fjac = diag + np;
+  double* qtf = fjac + n * np;
+  double* alpha = qtf + np;
+  j = 0;
+  for (i = 0; i < KPL_NPMAX; i++)
+    if (bFit[i])
+      guess[j++] = p[i];
+  bool aborted = lm->userBreak = false;
+  QMemArray<int> ip(KPL_NPMAX);
+  ip[0] = -1;
+  int info = 0;
+  if (nonLin) {
+    int nfev;
+    lm->lmdif(n, np, guess, fvec->data(), tol, tol, 0.0,
+              (np + 1) * itMax, 0.0, diag, 1, 100.0, 1, &info, &nfev,
+              fjac, n, ip.data(), qtf, wa, wa + np, wa + 2 * np, wa + 3 * np);
+    aborted = (ip[0] < 0);
+    if (info >= 8)
+      info = 4;
+  } else
+    aborted = lm->linFit(n, np, guess, fvec->data(), fjac, ip.data(), qtf, wa,
+                         wa + np, wa + 2 * np, wa + 3 * np);
+  if (!aborted) {
+    j = 0;
+    for (i = 0; i < KPL_NPMAX; i++)
+      if (bFit[i])
+        p[i] = guess[j++];
+    if (chisq) {
+      double chi = LMFit::enorm(n, fvec->data());
+      *chisq = chi * chi;
+    }
+    if (corr) {
+      for (i = 0; i < np; i++) {
+        for (j = 0; j < np; j++) {
+          alpha[ip[i] + ip[j] * np] = 0.0;
+          for (int k = 0; k <= j; k++)
+            if (k <= i)
+              alpha[ip[i] + ip[j] * np] += fjac[i * n + k] * fjac[j * n + k];
+        }
+      }
+      LMFit::minv(alpha, corr, np, wa, ip.data());
+      int ij = 0;
+      for (i = 0; i < np; i++) {
+        diag[i] = sqrt(corr[ij]);
+        ij += np + 1;
+      }
+      k = 0;
+      for (i = 0; i < np; i++)
+        for (j = 0; j < np; j++) {
+          if (double temp = diag[i] * diag[j])
+            corr[k] /= temp;
+          k++;
+        }
+      int ny = n - np;
+      if (chisq && pErr && ny) {
+        double temp = sqrt(*chisq / ny);
+        for (i = 0; i < np; i++)
+          diag[i] *= temp;
+        k = 0;
+        for (i = 0; i < KPL_NPMAX; i++)
+          pErr[i] = bFit[i] ? diag[k++] : 0.0;
+      }
+    }
+    if (avgErr) {
+      *avgErr = 0.0;
+      for (i = 0; i < n; i++) {
+        double temp = (*fvec)[i] * (*sig)[i];
+        *avgErr += temp * temp;
+      }
+      *avgErr = sqrt(*avgErr / n);
+    }
+  }
+  delete [] wa;
+  if (!_lm)
+    delete lm;
+  if (!_sig)
+    delete sig;
+  if (!_fvec)
+    delete fvec;
+  if (aborted)
+    info = -100;
+  return info;
 }
 
 bool FunItem::getFuncAddr(const QString& path, const QString& name,
-                          lt_dlhandle* hmod,
+                          QLibrary** lib,
                           double (**fkt)(double, const double*))
 {
-  *hmod = 0;
+  *lib = 0;
   *fkt = 0;
   if (path.isEmpty() || name.isEmpty())
     KMessageBox::sorry(0, i18n("no library or no function specified!"));
-  else
-    if (!(*hmod = lt_dlopen(path)))
-      KMessageBox::error(0, lt_dlerror());
+  else {
+    *lib = new QLibrary(path);
+    if (!(*lib)->load())
+      KMessageBox::error(0, path + "\n" + i18n("library cannot be opened!"));
     else
-      if ((*fkt = (double (*)(double, const double *)) lt_dlsym(*hmod, name)))
-        return false;
-      else {
-        KMessageBox::error(0, lt_dlerror());
-        lt_dlclose(*hmod);
-        *hmod = 0;
-      }
-  return true;
+      if ((*fkt = (double (*)(double, const double *)) (*lib)->resolve(name)))
+        return true;
+      else
+        KMessageBox::error(0, path + ": " + name + "\n" +
+                           i18n("function name cannot be resolved!"));
+    delete *lib;
+    *lib = 0;
+  }
+  return false;
 }
 
 void FunItem::init()
 {
-  lt_dlinit();
   memset(py, 0, sizeof(py));
   memset(pyo, 0, sizeof(pyo));
 }
 
 int FunItem::calcTable(bool logx) const
 {
-  bool newv = tv.isNull();
+  bool newv = tv.isEmpty();
   double d;
   int n;
   if (dt) {
@@ -264,8 +423,10 @@ int FunItem::calcTable(bool logx) const
       (logx != logxo)) {
     tv.detach();
     tv.resize(n);
+    int n1 = n - 1;
     for (i = 0; i < n; i++)
-      tv[i] = logx ? pow(10.0, log10(tmin) + i * d) : (tmin + i * d);
+      tv[i] = (i == n1) ? tmax : (logx ? pow(10.0, log10(tmin) + i * d) :
+                                         (tmin + i * d));
   }
   bool pchanged = false;
   for (i = 0; i < KPL_NPMAX; i++)
@@ -296,30 +457,30 @@ int FunItem::calcTable(bool logx) const
   return n;
 }
 
-ParFunItem::ParFunItem(): fktx(0), fktxo(0), hmodx(0)
+ParFunItem::ParFunItem(): fktx(0), fktxo(0), libx(0)
 {
   init();
 }
 
 ParFunItem::ParFunItem(const ParFunItem& f) :
  FunItem(f), fktx(f.fktx), fktxo(f.fktxo), xv(f.xv),
- namex(f.namex), pathx(f.pathx), hmodx(f.hmodx)
+ namex(f.namex), pathx(f.pathx), libx(0)
 {
   memcpy(px, f.px, sizeof(px));
   memcpy(pxo, f.pxo, sizeof(pxo));
   xv.detach();
-  if (f.hmodx)
-    getFuncAddr(pathx.path(), namex, &hmodx, &fktx);
+  if (f.libx)
+    getFuncAddr(pathx.path(), namex, &libx, &fktx);
 }
 
-ParFunItem::ParFunItem(Kpl::AutoStruct* aut) :
- FunItem(aut), fktx(0), fktxo(0), hmodx(0)
+ParFunItem::ParFunItem(KplNamespace::AutoStruct* aut) :
+ FunItem(aut), fktx(0), fktxo(0), libx(0)
 {
   init();
 }
 
-ParFunItem::ParFunItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
-                       const KURL& uPlo) : fktx(0), fktxo(0), hmodx(0)
+ParFunItem::ParFunItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
+                       const KURL& uPlo) : fktx(0), fktxo(0), libx(0)
 {
   active = plo->readBoolEntry("active", true);
   relsiz = plo->readDoubleNumEntry("relsiz", 1.0);
@@ -343,8 +504,8 @@ ParFunItem::ParFunItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
   s = plo->readEntry("pathy", "");
   pathy = QUrl::isRelativeUrl(s) ? (uPlo.directory(false) + s) : s;
   pathy.cleanPath();
-  getFuncAddr(pathx.path(), namex, &hmodx, &fktx);
-  getFuncAddr(pathy.path(), namey, &hmody, &fkty);
+  getFuncAddr(pathx.path(), namex, &libx, &fktx);
+  getFuncAddr(pathy.path(), namey, &liby, &fkty);
 }
 
 ParFunItem::ParFunItem(bool act, int fill,int sym, const QString& col,
@@ -356,13 +517,12 @@ ParFunItem::ParFunItem(bool act, int fill,int sym, const QString& col,
  fktxo(0), namex(name_x), pathx(path_x)
 {
   init();
-  getFuncAddr(pathx.path(), namex, &hmodx, &fktx);
+  getFuncAddr(pathx.path(), namex, &libx, &fktx);
 }
 
 ParFunItem::~ParFunItem()
 {
-  if (hmodx)
-    lt_dlclose(hmodx);
+  delete libx;
 }
 
 ParFunItem& ParFunItem::operator=(const ParFunItem& f)
@@ -377,11 +537,10 @@ ParFunItem& ParFunItem::operator=(const ParFunItem& f)
     xv.detach();
     namex = f.namex;
     pathx = f.pathx;
-    if (hmodx)
-      lt_dlclose(hmodx);
-    hmodx = 0;
-    if (f.hmodx)
-      getFuncAddr(pathx.path(), namex, &hmodx, &fktx);
+    delete libx;
+    libx = 0;
+    if (f.libx)
+      getFuncAddr(pathx.path(), namex, &libx, &fktx);
   }
   return *this;
 }
@@ -398,11 +557,12 @@ void ParFunItem::draw(KplGraph* g)
     double sav = g->relSize();
     g->setRelSize(relsiz * sav);
     int n = calcTable();
-    g->plArray(xv.data(), yv.data(), fx, fy, n, fillStyle);
+    g->plArray(xv.data(), yv.data(), fx, fy, n, fillStyle, true, x0, y0);
     g->setRelSize(sav);
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void ParFunItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
                           KplDoc* m) const
 {
@@ -413,10 +573,10 @@ void ParFunItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
   plo->writeEntry("tmin", tmin, true, false, frm, prec);
   plo->writeEntry("tmax", tmax, true, false, frm, prec);
   plo->writeEntry("dt", dt, true, false, frm, prec);
-  QStrList lx, ly;
+  QStringList lx, ly;
   for (int i = 0; i < KPL_NPMAX; i++) {
-    lx.insert(i, m->number(px[i]));
-    ly.insert(i, m->number(py[i]));
+    lx.append(m->number(px[i]));
+    ly.append(m->number(py[i]));
   }
   plo->writeEntry("px", lx, ' ');
   plo->writeEntry("py", ly, ' ');
@@ -426,11 +586,13 @@ void ParFunItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
   plo->writeEntry("pathy", Utils::relPath(url, pathy, _abs));
 }
 
-void ParFunItem::setText(KplCheckListItem* it, bool*, bool*) const
+void ParFunItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Par. function"));
   QFileInfo fi1(pathx.path());
   QFileInfo fi2(pathy.path());
+  KGraph g;
+  it->setPixmap(2, g.pixmap(symb, color));
   it->setText(2, QString("x = ") + fi1.baseName() + "." + namex
               + "(t), y = " + fi2.baseName() + "." + namey + "(t)");
 }
@@ -441,6 +603,15 @@ int ParFunItem::editItem(QWidget* parent, KplDoc* m, int)
   return dlg.exec();
 }
 
+void ParFunItem::exportTable(QTextStream& ts, KplDoc* m) const
+{
+  int n = calcTable();
+  for (int i = 0; i < n; i++)
+    ts << m->number(fx * xv[i]) << m->separator()
+       << m->number(fy * yv[i]) << "\n";
+}
+#endif
+
 KplItem* ParFunItem::copy() const
 {
   return new ParFunItem(*this);
@@ -460,8 +631,12 @@ void ParFunItem::minMax(double* xmi, double* xma, double* ymi, double* yma) cons
 {
   if (fktx && fkty) {
     int n = calcTable();
-    Utils::minMaxFile(xmi, xma, xv, n);
-    Utils::minMaxFile(ymi, yma, yv, n);
+    Utils::minMaxFile(xmi, xma, xv.data(), n);
+    Utils::minMaxFile(ymi, yma, yv.data(), n);
+    *xmi += x0;
+    *xma += x0;
+    *ymi += y0;
+    *yma += y0;
   }
 }
 
@@ -473,14 +648,6 @@ void ParFunItem::setPar(int i, double value, bool yFun)
     px[i] = value;
 }
 
-void ParFunItem::exportTable(QTextStream& ts, KplDoc* m) const
-{
-  int n = calcTable();
-  for (int i = 0; i < n; i++)
-    ts << m->number(fx * xv[i]) << m->separator()
-       << m->number(fy * yv[i]) << "\n";
-}
-
 void ParFunItem::init()
 {
   memset(px, 0, sizeof(px));
@@ -489,7 +656,7 @@ void ParFunItem::init()
 
 int ParFunItem::calcTable() const
 {
-  bool newv = tv.isNull();
+  bool newv = tv.isEmpty();
   double d;
   int n;
   if (dt) {
@@ -503,8 +670,9 @@ int ParFunItem::calcTable() const
   if (newv || (tmin != tmino) || (tmax != tmaxo) || (d != dto)) {
     tv.detach();
     tv.resize(n);
+    int n1 = n - 1;
     for (i = 0; i < n; i++)
-      tv[i] = tmin + i * d;
+      tv[i] = (i == n1) ? tmax : (tmin + i * d);
   }
   bool pchanged = false;
   for (i = 0; i < KPL_NPMAX; i++)
