@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 29 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,13 +22,14 @@
 #ifndef FUNITEM_H
 #define FUNITEM_H
 
+#include <qmemarray.h>
 #include <kurl.h>
-#include "ltdl.h"
 #include "kplitem.h"
 
-class QTextStream;
-class KSimpleConfig;
-class KplCheckListItem;
+class QLibrary;
+template<class> class QPtrList;
+class ArrayItem;
+class LMFit;
 
 /**
   * Function item class. Class for function items showing ordinary functions
@@ -46,14 +47,14 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  FunItem(Kpl::AutoStruct* aut);
+  FunItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     * @param url URL of plot file.
     */
-  FunItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& url);
+  FunItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut, const KURL& url);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
@@ -79,24 +80,72 @@ public:
   FunItem& operator=(const FunItem& f);
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
+  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
+#endif
   virtual KplItem* copy() const;
   virtual void expoItem(int* iex, int* iey, double* fx, double* fy) const;
   virtual void minMax(double* xmi, double* xma, double* ymi, double* yma) const;
   virtual void setPar(int i, double value, bool yFun);
-  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
+  /**
+   * Performs fit of parameters to a data array.
+   * @param ad array item.
+   * @param bFit array containing true values for parameters to be fitted.
+   * @param err array of structures containing the data error settings.
+   * @param nonLin true for nonlinear fit.
+   * @param tol tolerance value for stopping nonlinear fit iterations.
+   * @param itMax maximum number of nonlinear fit iterations.
+   * @param chisq chi-square.
+   * @param corr array for parameter correlation matrix.
+   * @param pErr array for parameter erros.
+   * @param avgErr average error.
+   * @return error code.
+   */
+  int fit(ArrayItem* ad, bool* bFit, KplNamespace::DataErrorStruct* err = 0,
+          bool nonLin = true, double tol = 1.0e-14, int itMax = 100,
+          double* chisq = 0, double* corr = 0, double* pErr = 0,
+          double* avgErr = 0);
+  /**
+   * Performs fit of parameters of a set of functions to a set of arrays.
+   * @param ad array item list.
+   * @param fd function item list.
+   * @param bFit array containing true values for parameters to be fitted.
+   * @param p parameter array.
+   * @param fvec array for weighted residuals.
+   * @param sig array for data errors.
+   * @param err array of structures containing the data error settings.
+   * @param nonLin true for nonlinear fit.
+   * @param tol tolerance value for stopping nonlinear fit iterations.
+   * @param itMax maximum number of nonlinear fit iterations.
+   * @param lm object for Levenberg-Marquardt fits.
+   * @param chisq chi-square.
+   * @param corr array for parameter correlation matrix.
+   * @param pErr array for parameter erros.
+   * @param avgErr average error.
+   * @param parent parant object for lm.
+   * @return error code.
+   */
+  static int fit(QPtrList<ArrayItem>* ad, QPtrList<FunItem>* fd, bool* bFit,
+                 double* p, QMemArray<double>* fvec = 0,
+                 QMemArray<double>* sig = 0,
+                 KplNamespace::DataErrorStruct* err = 0, bool nonLin = true,
+                 double tol = 1.0e-14, int itMax = 100, LMFit* lm = 0,
+                 double* chisq = 0, double* corr = 0, double* pErr = 0,
+                 double* avgErr = 0, QObject* parent = 0);
   /**
    * Gets module handle and address of a shared library function.
    * @param path path of the library.
    * @param name function name.
-   * @param hmod pointer to module handle.
+   * @param lib pointer to library.
    * @param fkt pointer to function address.
+   * @return true for success.
    */
   static bool getFuncAddr(const QString& path, const QString& name,
-                          lt_dlhandle* hmod,
+                          QLibrary** lib,
                           double (**fkt)(double, const double*));
 
 protected:
@@ -117,15 +166,15 @@ protected:
   mutable double (*fktyo)(double, const double*);
   double py[KPL_NPMAX];
   mutable double pyo[KPL_NPMAX];
-  mutable QArray<double> tv, yv;
+  mutable QMemArray<double> tv, yv;
   QString namey;
   KURL pathy;
-  lt_dlhandle hmody;
+  QLibrary* liby;
 
   friend class FitDlg;
   friend class FuncDlg;
   friend class LMFit;
-  friend class KplApp;
+  friend class Kpl;
   friend class KplDoc;
   friend class KplView;
 };
@@ -145,14 +194,15 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  ParFunItem(Kpl::AutoStruct* aut);
+  ParFunItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     * @param url URL of plot file.
     */
-  ParFunItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& url);
+  ParFunItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
+             const KURL& url);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
@@ -181,15 +231,17 @@ public:
   ParFunItem& operator=(const ParFunItem& f);
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
+  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
+#endif
   virtual KplItem* copy() const;
   virtual void expoItem(int* iex, int* iey, double* fx, double* fy) const;
   virtual void minMax(double* xmi, double* xma, double* ymi, double* yma) const;
   virtual void setPar(int i, double value, bool yFun);
-  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
 
 protected:
   /**
@@ -205,12 +257,12 @@ protected:
   mutable double (*fktxo)(double, const double*);
   double px[KPL_NPMAX];
   mutable double pxo[KPL_NPMAX];
-  mutable QArray<double> xv;
+  mutable QMemArray<double> xv;
   QString namex;
   KURL pathx;
-  lt_dlhandle hmodx;
+  QLibrary* libx;
   friend class ParFuncDlg;
-  friend class KplApp;
+  friend class Kpl;
 };
 
 #endif
