@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -28,7 +28,7 @@
 #include <qpushbutton.h>
 #include <qtimer.h>
 #include <qtooltip.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <klistview.h>
@@ -142,20 +142,14 @@ ItemDlg::ItemDlg(KplDoc* model) : m(model)
   itemList->header()->setClickEnabled(false);
   itemList->setDragEnabled(true);
   itemList->setAcceptDrops(true);
-#if KDE_VERSION_MAJOR > 2
   itemList->setSelectionModeExt(KListView::FileManager);
   connect(itemList, SIGNAL(contextMenuRequested(QListViewItem*,
     const QPoint&, int)), SLOT(slotPopup(QListViewItem*, const QPoint&)));
-#else
-  itemList->setSelectionModeExt(KListView::Konqueror);
-  connect(itemList, SIGNAL(rightButtonClicked(QListViewItem*,
-    const QPoint&, int)), SLOT(slotPopup(QListViewItem*, const QPoint&)));
-#endif
-  connect(itemList,
-          SIGNAL(moved(QListViewItem*, QListViewItem*, QListViewItem*)),
-          SLOT(slotMoved(QListViewItem*, QListViewItem*, QListViewItem*)));
+  connect(itemList, SIGNAL(moved()), SLOT(slotMoved()));
   connect(itemList, SIGNAL(returnPressed(QListViewItem*)),
           SLOT(slotList(QListViewItem*)));
+  connect(itemList, SIGNAL(selectionChanged()),
+          SLOT(updWin()));
   connect(itemList, SIGNAL(currentChanged(QListViewItem*)),
           SLOT(slotSelectionChanged(QListViewItem*)));
   connect(itemList, SIGNAL(executed(QListViewItem*)),
@@ -164,10 +158,10 @@ ItemDlg::ItemDlg(KplDoc* model) : m(model)
   QVBoxLayout* vbox = new QVBoxLayout(hbox, spacingHint());
   vbox->addItem(new QSpacerItem(10, 10));
   vbox->addWidget(up = new QPushButton(this));
-  up->setPixmap(BarIcon("up"));
+  up->setIconSet(BarIconSet("up"));
   connect(up, SIGNAL(clicked()), SLOT(slotMoveUp()));
   vbox->addWidget(down = new QPushButton(this));
-  down->setPixmap(BarIcon("down"));
+  down->setIconSet(BarIconSet("down"));
   connect(down, SIGNAL(clicked()), SLOT(slotMoveDown()));
   vbox->addItem(new QSpacerItem(10, 10));
   vbox = new QVBoxLayout(hbox, spacingHint());
@@ -192,7 +186,7 @@ ItemDlg::ItemDlg(KplDoc* model) : m(model)
   vbox->addWidget(b = new QPushButton(i18n("C&lose"), this));
   connect(b, SIGNAL(clicked()), SLOT(hide()));
   updItemList();
-#if KDE_VERSION >= 0x03015a
+#if KDE_VERSION >= 0x030200
   QTimer::singleShot(0, this, SLOT(setPosition()));
 #else
   Utils::setGeometry(this, "ItemDialog");
@@ -238,7 +232,7 @@ void ItemDlg::updItemList()
                          !((FrameItem*) item)->isCollapsed() : true);
       }
       item->setText(lItem.current(), &arrays, &funcs);
-      lItem.current()->setOn(item->active);
+      lItem.current()->setOn(item->isActive());
       connect(lItem.current(), SIGNAL(stateChanged(KplCheckListItem*, bool)),
               SLOT(slotStateChanged(KplCheckListItem*, bool)));
       connect(lItem.current(), SIGNAL(openChanged(KplCheckListItem*, bool)),
@@ -248,14 +242,10 @@ void ItemDlg::updItemList()
     itemList->setSelected(itm, true);
     itemList->setCurrentItem(itm);
     itemList->ensureItemVisible(itm);
-#if KDE_VERSION_MAJOR > 2
     slotSelectionChanged(itm);
-#endif
   }
   edit->setEnabled(nItems);
-  fit->setEnabled(arrays && funcs);
-  copy->setEnabled(nItems);
-  del->setEnabled(nItems);
+  updWin();
   itemList->setFocus();
 }
 
@@ -268,8 +258,10 @@ void ItemDlg::showPopup(int it, const QPoint& p)
   slotPopup(item, p);
 }
 
-void ItemDlg::moveItem()
+void ItemDlg::moveItem(int di)
 {
+  int iSource = lItem.findRef((KplCheckListItem*) itemList->currentItem());
+  int iDest = iSource + di;
   m->moveItem(iSource, iDest);
   itemList->clearSelection();
   QListViewItem* item = lItem.at(iDest);
@@ -279,13 +271,6 @@ void ItemDlg::moveItem()
     slotSelectionChanged(item);
 }
 
-void ItemDlg::moveItem(int di)
-{
-  iSource = lItem.findRef((KplCheckListItem*) itemList->currentItem());
-  iDest = iSource + di;
-  moveItem();
-}
-
 void ItemDlg::keyPressEvent(QKeyEvent* e)
 {
   if ((e->state() == 0) && (e->key() == Key_F1)) {
@@ -301,16 +286,15 @@ void ItemDlg::slotList(QListViewItem* it)
   m->items()->at(i)->editItem(this, m, i);
 }
 
-void ItemDlg::slotMoved(QListViewItem* item, QListViewItem*,
-                        QListViewItem* afterNow)
+void ItemDlg::slotMoved()
 {
-  iSource = lItem.findRef((KplCheckListItem*) item);
-  iDest = lItem.findRef((KplCheckListItem*) afterNow);
-  if (iSource >= 0) {
-    if (iDest <= iSource)
-      iDest++;
-    QTimer::singleShot(0, this, SLOT(moveItem()));
+  QValueList<int> list;
+  QListViewItemIterator it(itemList);
+  while (it.current()) {
+    list.append(lItem.findRef((KplCheckListItem*) it.current()));
+    it++;
   }
+  m->orderItems(list);
 }
 
 void ItemDlg::slotNew()
@@ -350,52 +334,32 @@ void ItemDlg::slotEdit()
 
 void ItemDlg::slotFit()
 {
-  QList<ArrayItem> arr;
-  QList<FunItem> fun;
-  QList<SplineItem> spl;
-  for (unsigned i = 0; i < m->items()->count(); i++) {
-    if (m->items()->at(i)->iType() == KplItem::Array)
-      arr.append((ArrayItem*) m->items()->at(i));
-    if (m->items()->at(i)->iType() == KplItem::Function)
-      fun.append((FunItem*) m->items()->at(i));
-    if (m->items()->at(i)->iType() == KplItem::Spline)
-      spl.append((SplineItem*) m->items()->at(i));
-  }
-  if ((arr.count() != (fun.count() + spl.count())) || (arr.count() != 1)) {
-    arr.clear();
-    fun.clear();
-    spl.clear();
-    for (unsigned i = 0; i < m->items()->count(); i++)
-      if (itemList->isSelected(lItem.at(i))) {
-        switch (m->items()->at(i)->iType()) {
-          case KplItem::Array:
-            arr.append((ArrayItem*) m->items()->at(i));
-            break;
-          case KplItem::Function:
-            fun.append((FunItem*) m->items()->at(i));
-            break;
-          case KplItem::Spline:
-            spl.append((SplineItem*) m->items()->at(i));
-            break;
-          default:
-            itemList->setSelected(lItem.at(i), false);
-        }
+  QPtrList<ArrayItem> arr;
+  QPtrList<FunItem> fun;
+  QPtrList<SplineItem> spl;
+  for (unsigned i = 0; i < m->items()->count(); i++)
+    if (defSel || itemList->isSelected(lItem.at(i))) {
+      switch (m->items()->at(i)->iType()) {
+        case KplItem::Array:
+          arr.append((ArrayItem*) m->items()->at(i));
+          break;
+        case KplItem::Function:
+          fun.append((FunItem*) m->items()->at(i));
+          break;
+        case KplItem::Spline:
+          spl.append((SplineItem*) m->items()->at(i));
+          break;
+        default:
+          ;
       }
-    if ((arr.count() != (fun.count() + spl.count())) || (!arr.count()) ||
-        (fun.count() && spl.count()) || (spl.count() > 1)) {
-      QToolTip::add(this, i18n("Select equal number of data sets\n"
-                               "and either functions or splines!"));
-      itemList->setFocus();
-      return;
     }
-  }
   if (fun.count()) {
     emit displayMessage(i18n("Fitting function parameters..."));
     FitDlg dlg(this, m, &arr, &fun, FitDlg::ShowDlg);
     dlg.exec();
   } else {
     emit displayMessage(i18n("Fitting spline..."));
-    SplFitDlg dlg(this, m, arr.first(), spl.first(), FitDlg::ShowDlg);
+    SplFitDlg dlg(this, m, arr.first(), &spl, FitDlg::ShowDlg);
     dlg.exec();
   }
   updItemList();
@@ -458,7 +422,7 @@ void ItemDlg::slotExecuted(QListViewItem* item)
 
 void ItemDlg::slotStateChanged(KplCheckListItem* it, bool bState)
 {
-  m->items()->at(lItem.findRef(it))->active = bState;
+  m->items()->at(lItem.findRef(it))->setActive(bState);
   m->setModified();
   m->backupItems(false);
 }
@@ -500,3 +464,54 @@ void ItemDlg::setPosition()
 {
   Utils::setGeometry(this, "ItemDialog");
 }
+
+void ItemDlg::updWin()
+{
+  int nSel = 0;
+  int nArr = 0;
+  int nFun = 0;
+  int nSpl = 0;
+  int nSelArr = 0;
+  int nSelFun = 0;
+  int nSelSpl = 0;
+  int kDeg = 0;
+  bool splValid = true;
+  for (unsigned i = 0; i < m->items()->count(); i++) {
+    KplCheckListItem* itm = lItem.at(i);
+    bool sel = itemList->isSelected(itm);
+    if (sel)
+      nSel++;
+    switch (m->items()->at(i)->iType()) {
+      case KplItem::Array:
+        nArr++;
+        if (sel)
+          nSelArr++;
+        break;
+      case KplItem::Function:
+        nFun++;
+        if (sel)
+          nSelFun++;
+        break;
+      case KplItem::Spline:
+        nSpl++;
+        if (sel) {
+          if (nSelSpl) {
+            if (((SplineItem*) m->items()->at(i))->kdeg != kDeg)
+              splValid = false;
+          } else
+            kDeg = ((SplineItem*) m->items()->at(i))->kdeg;
+          nSelSpl++;
+        }
+        break;
+      default:
+        ;
+    }
+  }
+  defSel = ((nArr == 1) && ((nFun + nSpl) == 1));
+  fit->setEnabled(defSel ||
+                  (nSelArr && nSelFun && (!nSelSpl) && (nSelArr == nSelFun)) ||
+                  (nSelArr && nSelSpl && splValid && (!nSelFun) &&
+                   (nSelArr == 1)));
+  copy->setEnabled(nSel);
+  del->setEnabled(nSel);
+}
