@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -20,36 +20,32 @@
  ***************************************************************************/
 
 #include <math.h>
+#include <qbitmap.h>
+#include <qfontdatabase.h>
 #include <qimage.h>
 #include <qpaintdevicemetrics.h>
-#include <qpixmap.h>
-#include <kapp.h>
 #include <kio/netaccess.h>
 #include <kmessagebox.h>
 #include <kurl.h>
 #include "kgraph.h"
 #include "utils.h"
 
-#if QT_VERSION >= 0x030200
-#include <qfontdatabase.h>
-#endif
-
 //#define NO_CLIPPING
 
 const char* KGraph::face[] = {"Helvetica", "Symbol", "Dingbats"};
 
-const int KGraph::pattern[] = {NoBrush, SolidPattern, HorPattern,
-                               VerPattern, CrossPattern, BDiagPattern,
-                               FDiagPattern, DiagCrossPattern};
+const int KGraph::pattern[] = {Qt::NoBrush, Qt::SolidPattern, Qt::HorPattern,
+                               Qt::VerPattern, Qt::CrossPattern,
+                               Qt::BDiagPattern, Qt::FDiagPattern,
+                               Qt::DiagCrossPattern};
 
 KGraph::KGraph() : minx(0), maxx(0), miny(0), maxy(0), kxcur(0), kycur(0),
- ndigx(0), ndigy(0), minx0(0), miny0(0), pFactor(0), textdir(0.0),
- scalx(30.0), scaly(-30.0), xmin(0.0), xmax(15.0), ymin(0.0), ymax(10.0),
- xcur(0.0), ycur(0.0), dlen(15.0), dhite(10.0), xscal(30.0), yscal(-30.0),
+ ndigx(0), ndigy(0), minx0(0), miny0(0), textdir(0.0), scalx(30.0),
+ scaly(-30.0), xcur(0.0), ycur(0.0), xscal(30.0), yscal(-30.0),
  relang(0.0), relsin(0.0), relcos(1.0), dcur(0.0), factor(1.0),
- pen1(black, 0, SolidLine, RoundCap, RoundJoin),
- pen2(black, 0, SolidLine, RoundCap, RoundJoin),
- pen3(black, 0, SolidLine, RoundCap, RoundJoin)
+ pen1(Qt::black, 0, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin),
+ pen2(Qt::black, 0, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin),
+ pen3(Qt::black, 0, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
 {
   memset(dash, 0, sizeof(dash));
 }
@@ -66,11 +62,19 @@ void KGraph::r2i(double x, double y, int* ix, int* iy)
   *iy = miny + qRound(yscal * (y - ymin));
 }
 
+void KGraph::drawLineTo(double x, double y)
+{
+  QPoint p1(kxcur, kycur);
+  r2i(x, y, &kxcur, &kycur);
+  drawLine(p1, QPoint(kxcur, kycur));
+}
+
 bool KGraph::i2cm(const QPoint& p, double* xcm, double* ycm) const
 {
   *xcm = (p.x() - minx0) / (scalx * factor);
   *ycm = (p.y() - miny0) / (scaly * factor);
-  return ((p.x() < minx) || (p.x() > maxx) || (p.y() > miny) || (p.y() < maxy));
+  return ((p.x() < minx) || (p.x() > maxx) || (p.y() > miny) ||
+          (p.y() < maxy));
 }
 
 void KGraph::i2r(const QPoint& p, double _fxn, double _fyn,
@@ -84,31 +88,18 @@ void KGraph::i2r(const QPoint& p, double _fxn, double _fyn,
     *yr = pow(10, *yr);
 }
 
-QPoint KGraph::fromcm(double xcm, double ycm) const
-{
-  return QPoint(qRound(xcm * scalx * factor) + minx0,
-                qRound(ycm * scaly * factor) + miny0);
-}
-
 void KGraph::cm2r(double xcm, double ycm, double _fxn, double _fyn,
                   double* xr, double* yr) const
 {
   i2r(fromcm(xcm, ycm), _fxn, _fyn, xr, yr);
 }
 
-void KGraph::move(double x, double y)
-{
-  r2i(x, y, &kxcur, &kycur);
-  moveTo(kxcur, kycur);
-}
-
 void KGraph::draw(double x, double y)
 {
   if ((x != xcur) || (y != ycur)) {
-    if (dash[1] == dash[0]) {
-      r2i(x, y, &kxcur, &kycur);
-      lineTo(kxcur, kycur);
-    } else {
+    if (dash[1] == dash[0])
+      drawLineTo(x, y);
+    else {
       dcur = dcur - dash[3] * (int) (dcur / dash[3]);
       double x1 = (x - xcur) * xscal / scalx;
       double y1 = (y - ycur) * yscal / scaly;
@@ -127,24 +118,20 @@ void KGraph::draw(double x, double y)
           ycur = y - d * (y - y1) / d0;
           dcur = dash[i];
           if (i % 2)
-            move(xcur,ycur);
-          else {
-            r2i(xcur, ycur, &kxcur, &kycur);
-            lineTo(kxcur, kycur);
-          }
+            move(xcur, ycur);
+          else
+            drawLineTo(xcur, ycur);
         }
         if (i == 3)
           dcur = 0.0;
-        i = ++i % 4;
+        i = (i + 1) % 4;
       }
       xcur = x;
       ycur = y;
       if (i % 2)
         move(xcur, ycur);
-      else {
-        r2i(xcur, ycur, &kxcur, &kycur);
-        lineTo(kxcur, kycur);
-      }
+      else
+        drawLineTo(xcur, ycur);
       dcur += d;
     }
   }
@@ -156,41 +143,32 @@ void KGraph::line(double x1, double y1, double x2, double y2)
   draw(x2, y2);
 }
 
-void KGraph::plInit(const QPaintDevice* pd, int offLeft, int offTop)
+void KGraph::plInit(QPaintDevice* pd, int offLeft, int offTop)
 {
   QPaintDeviceMetrics pdm(pd);
   begin(pd);
   eraseRect(window());
-  if (pd->devType() == QInternal::Printer) {
+  if (pd->devType() == QInternal::Printer)
     devType = Printer;
-#if KDE_VERSION_MAJOR > 2
-    pFactor = 1;
-#else
-    pFactor = 4;
-    QRect r = window();
-    r.setSize(pFactor * r.size());
-    setWindow(r);
-#endif
-  } else
-    pFactor = 1;
   fDpi = 75.0 / pdm.logicalDpiY();
-  scalx = pFactor * pdm.logicalDpiX() / 2.54;
-  scaly = -pFactor * pdm.logicalDpiY() / 2.54;
-  minx0 = minx = -pFactor * offLeft;
-  maxx = pFactor * pdm.width() + minx;
-  miny0 = miny = pFactor * (pdm.height() + offTop);
-  maxy = pFactor * offTop;
+  scalx = pdm.logicalDpiX() / 2.54;
+  scaly = -pdm.logicalDpiY() / 2.54;
+  minx0 = minx = -offLeft;
+  maxx = pdm.width() + minx;
+  miny0 = miny = pdm.height() + offTop;
+  maxy = offTop;
   logx = logy = false;
   xscal = scalx;
   yscal = scaly;
-  dlen = (maxx - minx) / xscal;
-  dhite = (maxy - miny) / yscal;
+  int d = maxx - minx;
+  xl = d / xscal;
+  yl = (maxy - miny) / yscal;
   factor = 1.0;
   xmin = ymin = 0.0;
   xcur = xmin;
   ycur = ymin;
-  xmax = dlen;
-  ymax = dhite;
+  xmax = xl;
+  ymax = yl;
   relang = 0.0;
   relsin = 0.0;
   relcos = 1.0;
@@ -198,9 +176,9 @@ void KGraph::plInit(const QPaintDevice* pd, int offLeft, int offTop)
   textdir = 0.0;
   ndigx = ndigy = -1;
   linetype(1);
-  pen1.setWidth((maxx - minx) / 240);
-  pen2.setWidth((maxx - minx) / 480);
-  pen3.setWidth((maxx - minx) / 339);
+  pen1.setWidth(d / 240);
+  pen2.setWidth(d / 480);
+  pen3.setWidth(d / 339);
   setPen(pen3);
   setFont(QFont(face[0], QMAX(qRound(0.0355 * fDpi * maxx), 1)));
   move(xcur, ycur);
@@ -224,8 +202,7 @@ void KGraph::format(double x, double y)
   xcur = xmin;
   ycur = ymin;
 #ifndef NO_CLIPPING
-  setClipRect(minx / pFactor, maxy / pFactor, (maxx - minx) / pFactor,
-              (miny - maxy) / pFactor);
+  setClipRect(minx , maxy, maxx - minx, miny - maxy);
   setClipping(false);
 #endif
 }
@@ -257,12 +234,13 @@ double KGraph::setRelSize(double r)
 {
   double old = relSiz;
   relSiz = r;
-  pen1.setWidth(qRound(0.00416667 * relSiz * (maxx - minx)));
-  pen2.setWidth(qRound(0.00208333 * relSiz * (maxx - minx)));
-  pen3.setWidth(qRound(0.00295 * relSiz * (maxx - minx)));
+  double d = relSiz * (maxx - minx);
+  pen1.setWidth(qRound(0.00416667 * d));
+  pen2.setWidth(qRound(0.00208333 * d));
+  pen3.setWidth(qRound(0.00295 * d));
   setPen(pen3);
   QFont fnt = font();
-  fnt.setPointSize(QMAX(qRound(0.0355 * fDpi * relSiz * (maxx - minx)), 1));
+  fnt.setPointSize(QMAX(qRound(0.0355 * fDpi * d), 1));
   setFont(fnt);
   return old;
 }
@@ -281,17 +259,18 @@ void KGraph::Window(double xmi, double w, double ymi, double h)
   ycur = ymin;
   move(xcur, ycur);
   dcur = 0.0;
-  int _dx = qRound(0.00416667 * relSiz * (maxx - minx));
+  double d = relSiz * (maxx - minx);
+  int _dx = qRound(0.00416667 * d);
   pen1.setWidth(_dx);
-  pen2.setWidth(qRound(0.00208333 * relSiz * (maxx - minx)));
-  pen3.setWidth(qRound(0.00295 * relSiz * (maxx - minx)));
+  pen2.setWidth(qRound(0.00208333 * d));
+  pen3.setWidth(qRound(0.00295 * d));
   setPen(pen3);
   QFont fnt = font();
-  fnt.setPointSize(QMAX(qRound(0.0355 * fDpi * relSiz * (maxx - minx)), 1));
+  fnt.setPointSize(QMAX(qRound(0.0355 * fDpi * d), 1));
   setFont(fnt);
 #ifndef NO_CLIPPING
-  setClipRect((minx + (_dx >> 1)) / pFactor , (maxy + (_dx >> 1)) / pFactor,
-              (maxx - minx - _dx) / pFactor, (miny - maxy - _dx) / pFactor);
+  setClipRect(minx + (_dx >> 1), maxy + (_dx >> 1), maxx - minx - _dx,
+              miny - maxy - _dx);
   setClipping(false);
 #endif
 }
@@ -467,15 +446,19 @@ void KGraph::raster(double xtic, double ytic, int intx, int inty, int mode,
   }
   if ((mode == AxesWithLabels) || (mode == GridWithLabels)) {
     QString label;
-    double yB = 0.0, yT = 0.0;
+    double yB = 0.0;
+    double yT = 0.0;
+    double d = 0.03225 * relSiz * (xmax - xmin) * xscal / yscal;
     if (xBottom)
-      yB = ymin + 0.03225 * relSiz * (xmax - xmin) * xscal / yscal;
+      yB = ymin + d;
     if (xTop)
-      yT = ymax - 0.03225 * relSiz * (xmax - xmin) * xscal / yscal;
+      yT = ymax - d;
     int ix, iy;
-    bool e = (logx && (xtic > 9.9) && ((xmax > 2.999999) || (xmin < -2.999999)));
+    bool e = (logx && (xtic > 9.9) && ((xmax > 2.999999) ||
+                                       (xmin < -2.999999)));
     int nd = ndigx;
     double xe = xmax + 1.0e-3 * (xmax - xmin);
+    double tol = 1.0e-12 * xtic;
     for (x = xmin + xOff; x <= xe;) {
       if (x > xmax)
          x = xmax;
@@ -494,15 +477,16 @@ void KGraph::raster(double xtic, double ytic, int intx, int inty, int mode,
             nd = 1 - int(x + 0.01);
           else
             nd = -1;
-        int l = prenum(logx ? pow(10.0, x) : x, nd, label);
+        int l = prenum(logx ? pow(10.0, x) :
+                              ((fabs(x) < tol) ? 0.0 : x), nd, label);
         setPen(pen1);
         if (xBottom) {
           r2i(x, yB, &ix, &iy);
-          drawText(ix, iy, 0, 0, AlignCenter | DontClip, label, l);
+          drawText(ix, iy, 0, 0, Qt::AlignCenter | Qt::DontClip, label, l);
         }
         if (xTop) {
           r2i(x, yT, &ix, &iy);
-          drawText(ix, iy, 0, 0, AlignCenter | DontClip, label, l);
+          drawText(ix, iy, 0, 0, Qt::AlignCenter | Qt::DontClip, label, l);
         }
       }
       if (logx)
@@ -510,15 +494,18 @@ void KGraph::raster(double xtic, double ytic, int intx, int inty, int mode,
       else
         x += xtic;
     }
-    double xL = 0.0, xR = 0.0;
+    double xL = 0.0;
+    double xR = 0.0;
+    d = 0.025 * relSiz * (xmax - xmin);
     if (yLeft)
-      xL = xmin - 0.025 * relSiz * (xmax - xmin);
+      xL = xmin - d;
     if (yRight)
-      xR = xmax + 0.025 * relSiz * (xmax - xmin);
-    dy = -0.0125 * relSiz * (xmax - xmin) * xscal / yscal;
+      xR = xmax + d;
+    dy = -0.5 * d * xscal / yscal;
     e = (logy && (ytic > 9.9) && ((ymax > 2.999999) || (ymin < -2.999999)));
     nd = ndigy;
     double ye = ymax + 1.0e-3 * (ymax - ymin);
+    tol = 1.0e-12 * ytic;
     for (y = ymin + yOff; y <= ye;) {
       if (y > ymax)
         y = ymax;
@@ -537,16 +524,19 @@ void KGraph::raster(double xtic, double ytic, int intx, int inty, int mode,
             nd = 1 - int(y + 0.01);
           else
             nd = -1;
-        int l = prenum(logy ? pow(10.0, y) : y, nd, label);
+        int l = prenum(logy ? pow(10.0, y) :
+                              ((fabs(y) < tol) ? 0.0 : y), nd, label);
         setPen(pen1);
         if (yLeft) {
           r2i(xL, y, &ix, &iy);
-          drawText(ix, iy - 1, 0, 0, AlignRight | AlignVCenter | DontClip,
+          drawText(ix, iy - 1, 0, 0,
+                   Qt::AlignRight | Qt::AlignVCenter | Qt::DontClip,
                    label, l);
         }
         if (yRight) {
           r2i(xR, y, &ix, &iy);
-          drawText(ix, iy - 1, 0, 0, AlignLeft | AlignVCenter | DontClip,
+          drawText(ix, iy - 1, 0, 0,
+                   Qt::AlignLeft | Qt::AlignVCenter | Qt::DontClip,
                    label, l);
         }
       }
@@ -586,13 +576,13 @@ void KGraph::text(const QString& str, int ix, int iy, int iorg, QRect* bRect)
     if (!str.contains('#')) {
       switch (iorg) {
         case 1:
-          tf = AlignLeft | AlignVCenter | DontClip;
+          tf = Qt::AlignLeft | Qt::AlignVCenter | Qt::DontClip;
           break;
         case 2:
-          tf = AlignCenter | DontClip;
+          tf = Qt::AlignCenter | Qt::DontClip;
           break;
         case 3:
-          tf = AlignRight | AlignVCenter | DontClip;
+          tf = Qt::AlignRight | Qt::AlignVCenter | Qt::DontClip;
       }
       drawText(0, 0, 0, 0, tf, str, -1, bRect);
     } else {
@@ -605,7 +595,7 @@ void KGraph::text(const QString& str, int ix, int iy, int iorg, QRect* bRect)
       const bool italic[7] = {false, false, false, true, false, false, true};
       const double ys[2] = {0.6, -0.4};
       int ix2 = 0;
-      tf = AlignLeft | AlignVCenter | DontClip;
+      tf = Qt::AlignLeft | Qt::AlignVCenter | Qt::DontClip;
       double dr = 0.025 * relSiz * (xmax - xmin) * xscal;
       int j0 = (iorg == 1) ? 1 : 0;
       int idx = 0;
@@ -629,7 +619,7 @@ void KGraph::text(const QString& str, int ix, int iy, int iorg, QRect* bRect)
             QRect r;
             if (j == 0) {
               r = boundingRect(0, 0, maxx, maxy,
-                               AlignLeft | AlignVCenter, s, l);
+                               Qt::AlignLeft | Qt::AlignVCenter, s, l);
               idx += r.width();
             } else {
               idy = (ilev) ? -qRound(dr * ys[ilev - 1]) : 0;
@@ -647,29 +637,16 @@ void KGraph::text(const QString& str, int ix, int iy, int iorg, QRect* bRect)
             ilev = levcode.find(c.at(2).upper());
             if ((ifnt >= 0) && (ilev >= 0)) {
               int k = iface[ifnt];
-#if QT_VERSION >= 0x030200
               if (k == 2)
                 QFontDatabase().styles(face[k]);
-#endif
               QFont fnt(face[k],
                         QMAX(qRound((ilev ? 0.0251 : 0.0355) * relSiz * fDpi *
                                     (maxx - minx)), 1),
                         weight[ifnt], italic[ifnt]);
-#if KDE_VERSION_MAJOR < 3
-              fnt.setCharSet(k ? QFont::AnyCharSet : QFont::Latin1);
-#endif
               if (k > 0) {
-#if KDE_VERSION_MAJOR < 3
-                fnt.setStyleHint(QFont::AnyStyle, QFont::PreferBitmap);
-#else
                 fnt.setStyleStrategy(QFont::PreferBitmap);
-#endif
                 if (QFontInfo(fnt).family().find(QString(face[k]), 0, false))
-#if KDE_VERSION_MAJOR < 3
-                  fnt.setStyleHint(QFont::AnyStyle, QFont::PreferDefault);
-#else
                   fnt.setStyleStrategy(QFont::PreferDefault);
-#endif
               }
               setFont(fnt);
             }
@@ -713,9 +690,9 @@ void KGraph::arrow(double x, double y, double dir, double len,
   QPointArray a;
   a.setPoints(3, 0, 0, idx, idy, idx, -idy);
   setBrush(pen1.color());
-  setPen(NoPen);
+  setPen(Qt::NoPen);
   drawPolygon(a);
-  setBrush(NoBrush);
+  setBrush(Qt::NoBrush);
   setPen(pen1);
   int idx2 = -qRound(factor * scalx * len);
   if (idx2 <= idx)
@@ -751,15 +728,15 @@ void KGraph::rectangle(double x, double y, double w, double h,
   translate(double(p.x()), double(p.y()));
   if (dir)
     rotate(-dir);
+  if (fillStyle) {
+    setBrush(QBrush(pen3.color(), (Qt::BrushStyle) pattern[fillStyle]));
+    setPen(Qt::NoPen);
+  }
   int idy = qRound(factor * scaly * h);
   QRect r(0, idy, qRound(factor * scalx * w), -idy);
-  if (fillStyle) {
-    setBrush(QBrush(pen3.color(), (BrushStyle) pattern[fillStyle]));
-    setPen(NoPen);
-  }
   drawRect(r);
   if (fillStyle) {
-    setBrush(NoBrush);
+    setBrush(Qt::NoBrush);
     setPen(pen3);
   }
   if (bRect)
@@ -775,16 +752,16 @@ void KGraph::ellipse(double x, double y, double w, double h,
   translate(double(p.x()), double(p.y()));
   if (dir)
     rotate(-dir);
+  if (fillStyle) {
+    setBrush(QBrush(pen3.color(), (Qt::BrushStyle) pattern[fillStyle]));
+    setPen(Qt::NoPen);
+  }
   int iw = qRound(factor * scalx * w);
   int ih = -qRound(factor * scaly * h);
   QRect r(-iw / 2, -ih / 2, iw, ih);
-  if (fillStyle) {
-    setBrush(QBrush(pen3.color(), (BrushStyle) pattern[fillStyle]));
-    setPen(NoPen);
-  }
   drawEllipse(r);
   if (fillStyle) {
-    setBrush(NoBrush);
+    setBrush(Qt::NoBrush);
     setPen(pen3);
   }
   if (bRect)
@@ -803,17 +780,12 @@ void KGraph::image(const KURL& url, double x, double y, double sx, double sy,
     int iw = qRound(factor * scalx * w);
     int ih = qRound(-factor * scaly * h);
     QPoint p = fromcm(x, y + h);
-#if KDE_VERSION_MAJOR < 3
-    QImage image(fn);
-    drawImage(p, image.smoothScale(iw, ih));
-#else
     QImageIO iio;
     iio.setFileName(fn);
     QString s = QString::number(iw) + ":" + QString::number(ih);
     iio.setParameters(s.latin1());
     iio.read();
     drawImage(p, iio.image());
-#endif
     if (bRect)
       *bRect = QRect(p, QSize(iw, ih));
     if (!url.isLocalFile())
@@ -847,7 +819,7 @@ void KGraph::scaleBar(const QString& str, double x, double y, int orientation,
            y + 0.5 * len + 0.014 * relSiz * (maxx - minx) / (factor * scaly),
            1, bRect);
   else
-    textcm(str, x + 0.5 * len, y - (2 + relSiz) * idy / (factor * scaly),
+    textcm(str, x + 0.5 * len, y - (2.0 + relSiz) * idy / (factor * scaly),
            2, bRect);
   if (bRect)
     *bRect = bRect->unite(r2);
@@ -889,12 +861,10 @@ void KGraph::arcrel(double x, double y, double r, double angst, double angend)
   int x0, y0;
   r2i(x, y, &x0, &y0);
   int ir = qRound(xscal * fabs(r));
-  double phi = 1.74532925e-2 * angst;
-  int xstart = qRound(ir * cos(phi));
-  int ystart = qRound(ir * sin(phi));
   if (r > 0.0) {
-    x0 -= xstart;
-    y0 += ystart;
+    double phi = 1.74532925e-2 * angst;
+    x0 -= qRound(ir * cos(phi));
+    y0 += qRound(ir * sin(phi));
   }
   drawArc(x0 - ir, y0 - ir, ir + ir, ir + ir,
           qRound(16.0 * angst), qRound(16.0 * angend));
@@ -921,7 +891,7 @@ double KGraph::incLog(double* x, double f)
 }
 
 void KGraph::plArray(const double *x, const double *y, double fx, double fy,
-                     int n, int fillStyle, bool clip)
+                     int n, int fillStyle, bool clip, double xOff, double yOff)
 {
   if (kSymb == -17)
     return;
@@ -930,14 +900,14 @@ void KGraph::plArray(const double *x, const double *y, double fx, double fy,
 #endif
   double xa, ya;
   if (fillStyle) {
-    setBrush(QBrush(pen3.color(), (BrushStyle) pattern[fillStyle]));
-    setPen(NoPen);
+    setBrush(QBrush(pen3.color(), (Qt::BrushStyle) pattern[fillStyle]));
+    setPen(Qt::NoPen);
     QPointArray ap(n);
     int kx, ky;
     int l = 0;
     for (int i = 0; i < n; i++) {
-      xa = fx * x[i];
-      ya = fy * y[i];
+      xa = fx * (xOff + x[i]);
+      ya = fy * (yOff + y[i]);
       if (Utils::valid(xa, logx) && Utils::valid(ya, logy)) {
         r2i(logx ? log10(xa) : xa, logy ? log10(ya) : ya, &kx, &ky);
         ap[l++] = QPoint(kx, ky);
@@ -945,15 +915,15 @@ void KGraph::plArray(const double *x, const double *y, double fx, double fy,
     }
     if (l > 2)
       drawPolygon(ap, true, 0, l);
-    setBrush(NoBrush);
+    setBrush(Qt::NoBrush);
     setPen(pen3);
   } else {
     if (kSymb > 0) {
       linetype(kSymb);
       bool b = false;
       for (int i = 0; i < n; i++) {
-        xa = fx * x[i];
-        ya = fy * y[i];
+        xa = fx * (xOff + x[i]);
+        ya = fy * (yOff + y[i]);
         if (Utils::valid(xa, logx) && Utils::valid(ya, logy))
           if (b)
             draw(logx ? log10(xa) : xa, logy ? log10(ya) : ya);
@@ -968,7 +938,7 @@ void KGraph::plArray(const double *x, const double *y, double fx, double fy,
       int k = (-kSymb) % 17;
       if ((k > 10) || (k == 1)) {
         setBrush(pen3.color());
-        setPen(NoPen);
+        setPen(Qt::NoPen);
       }
       const int ax[48] = {0, -2, 0, 2, 0, 2, -2, -2, 2, 2, 0, -2, 2, 0,
                           2, -2, 2, -2, 2, 2, 1, -1, -2, -2, -1, 1, 2, 2,
@@ -979,11 +949,12 @@ void KGraph::plArray(const double *x, const double *y, double fx, double fy,
                           2, -2, 0, 2, -2, 2, -2, 0, 0, 0, 2, 0, 2, 0, -2,
                           2, 0, 0, 2, -2},
                 as[10] = {0, 5, 10, 14, 19, 28, 33, 38, 43, 48};
-      int j, l = 0, r;
+      int j, r;
+      int l = 0;
       double f = 0.005 * relSiz * (maxx - minx);
       for (int i = 0; i < n; i++) {
-        xa = fx * x[i];
-        ya = fy * y[i];
+        xa = fx * (xOff + x[i]);
+        ya = fy * (yOff + y[i]);
         if (Utils::valid(xa, logx) && Utils::valid(ya, logy)) {
           move(logx ? log10(xa) : xa, logy ? log10(ya) : ya);
           switch (k) {
@@ -998,15 +969,17 @@ void KGraph::plArray(const double *x, const double *y, double fx, double fy,
               break;
             default:
               r = (k < 12) ? k : k - 10;
+              QPoint p1(kxcur, kycur);
               for (j = as[r - 2]; j < as[r - 1]; j++) {
+                QPoint p2(qRound(kxcur + f * ax[j]),
+                          qRound(kycur - f * ay[j]));
                 l = j - as[r - 2];
-                if (k < 12)
+                if (k < 12) {
                   if (l)
-                    lineTo(qRound(kxcur + f * ax[j]), qRound(kycur - f * ay[j]));
-                  else
-                    moveTo(qRound(kxcur + f * ax[j]), qRound(kycur - f * ay[j]));
-                else
-                  ap[l] = QPoint(qRound(kxcur + f * ax[j]), qRound(kycur - f * ay[j]));
+                    drawLine(p1, p2);
+                  p1 = p2;
+                } else
+                  ap[l] = p2;
               }
               if (k >= 12)
                 drawPolygon(ap, false, 0, l);
@@ -1014,7 +987,7 @@ void KGraph::plArray(const double *x, const double *y, double fx, double fy,
         }
       }
       if ((k > 10) || (k == 1)) {
-        setBrush(NoBrush);
+        setBrush(Qt::NoBrush);
         setPen(pen3);
       }
     }
@@ -1025,7 +998,8 @@ void KGraph::plArray(const double *x, const double *y, double fx, double fy,
 }
 
 void KGraph::plError(const double* x, const double* y, const double* e,
-                     double fx, double fy, int n, bool clip)
+                     double fx, double fy, int n, bool clip, double xOff,
+                     double yOff)
 {
 #ifndef NO_CLIPPING
   setClipping(clip);
@@ -1039,24 +1013,20 @@ void KGraph::plError(const double* x, const double* y, const double* e,
         ie = int(-0.4342944819 * e[i] * yscal / y[i]);
       else
         ie = int(-fy * e[i] * yscal);
-      double xa = fx * x[i];
+      double xa = fx * (xOff + x[i]);
       if (logx)
         xa = log10(xa);
-      double ya = fy * y[i];
+      double ya = fy * (yOff + y[i]);
       if (logy)
         ya = log10(ya);
       if ((xa >= xmin) && (xa <= xmax) &&
           ((ya - ie * yscal) >= ymin) && ((ya + ie * yscal) <= ymax) &&
           (ie >= idy)) {
         move(xa, ya);
-        moveTo(kxcur, kycur + idy);
-        lineTo(kxcur, kycur + ie);
-        moveTo(kxcur - idx, kycur + ie);
-        lineTo(kxcur + idx, kycur + ie);
-        moveTo(kxcur, kycur - idy);
-        lineTo(kxcur, kycur - ie);
-        moveTo(kxcur - idx, kycur - ie);
-        lineTo(kxcur + idx, kycur - ie);
+        drawLine(kxcur, kycur + idy, kxcur, kycur + ie);
+        drawLine(kxcur - idx, kycur + ie, kxcur + idx, kycur + ie);
+        drawLine(kxcur, kycur - idy, kxcur, kycur - ie);
+        drawLine(kxcur - idx, kycur - ie, kxcur + idx, kycur - ie);
       }
     }
 #ifndef NO_CLIPPING
@@ -1069,6 +1039,32 @@ void KGraph::resetDash()
   dcur = 0.0;
 }
 
+QPixmap KGraph::pixmap(int symbol, unsigned color)
+{
+  QPixmap pm((symbol > 0) ? QSize(40, 2) : QSize(16, 16));
+  plInit(&pm, 0, 0);
+  setColData(color);
+  setSymbol(symbol);
+  int n;
+  double xa[2], ya[2];
+  if (symbol > 0) {
+    setRelSize(13.0);
+    xa[0] = 2.0 / scalx;
+    xa[1] = 38.0 / scalx;
+    ya[0] = ya[1] = -1.0 / scaly;
+    n = 2;
+  } else {
+    setRelSize(34.0);
+    xa[0] = 8.0 / scalx;
+    ya[0] = -8.0 / scaly;
+    n = 1;
+  }
+  plArray(xa, ya, 1.0, 1.0, n, false, false);
+  end();
+  pm.setMask(pm.createHeuristicMask());
+  return pm;
+}
+
 void KGraph::linetype(int is)
 {
   const int pat[9][2] = {{8, 8}, {7, 0}, {2, 0}, {1, 0}, {9, 0},
