@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -23,6 +23,7 @@
 #define KGRAPH_H
 
 #include <qpainter.h>
+#include <qpixmap.h>
 #include "kplgraph.h"
 
 /**
@@ -37,16 +38,16 @@ public:
   /** Destructor */
   virtual ~KGraph();
   /**
-   * Converts from integer units to centimeters.
-   * @param p integer coordinates.
+   * Converts from pixel units to centimeters.
+   * @param p pixel coordinates.
    * @param xcm x value in centimeters (output).
    * @param ycm y value in centimeters (output).
-   * @return true fr point outside of data window.
+   * @return true for point outside of data window.
    */
   bool i2cm(const QPoint& p, double* xcm, double* ycm) const;
   /**
-   * Converts from integer units to user units.
-   * @param p integer coordinates.
+   * Converts from pixel units to user units.
+   * @param p pixel coordinates.
    * @param fxn normalization factor for x values.
    * @param fyn normalization factor for y values.
    * @param xr x value in user units (output).
@@ -55,12 +56,14 @@ public:
   void i2r(const QPoint& p, double fxn, double fyn, double* xr,
            double* yr) const;
   /**
-   * Converts from centimeters to integer units.
+   * Converts from centimeters to pixel units.
    * @param xcm x value in centimeters.
    * @param ycm y value in centimeters.
-   * @return integer coordinates.
+   * @return pixel coordinates.
    */
-  QPoint fromcm(double xcm, double ycm) const;
+  inline QPoint fromcm(double xcm, double ycm) const
+    { return QPoint(qRound(xcm * scalx * factor) + minx0,
+                    qRound(ycm * scaly * factor) + miny0); };
   /**
    * Converts from centimeters to user units.
    * @param xcm x value in centimeters.
@@ -77,7 +80,7 @@ public:
    * @param x x value in user units.
    * @param y y value in user units.
    */
-  void move(double x, double y);
+  inline void move(double x, double y) { r2i(x, y, &kxcur, &kycur); };
   /**
    * Draws line from current to given position.
    * @param x x value in user units.
@@ -98,7 +101,7 @@ public:
    * @param offLeft scroll offset from left margin.
    * @param offTop scroll offset from top margin.
    */
-  void plInit(const QPaintDevice* pd, int offLeft = 0, int offTop = 0);
+  void plInit(QPaintDevice* pd, int offLeft = 0, int offTop = 0);
   virtual void format(double x, double y);
   virtual void setColFrame(unsigned icol1);
   virtual void setColGrid(unsigned icol2);
@@ -159,10 +162,17 @@ public:
   static double incLog(double* x, double f);
   virtual void plArray(const double* x, const double* y,
                        double fx, double fy, int n, int fillStyle = 0,
-                       bool clip = true);
+                       bool clip = true, double x0 = 0.0, double y0 = 0.0);
   virtual void plError(const double* x, const double* y, const double* e,
-                       double fx, double fy, int n, bool clip = true);
+                       double fx, double fy, int n, bool clip = true,
+                       double x0 = 0.0, double y0 = 0.0);
   virtual void resetDash();
+  /**
+   * Generates pixmaps of symbols for the Kpl item list.
+   * @param symbol 0 for circles, < 0 for different markers,
+   * @param color symbol color.
+   */
+  QPixmap pixmap(int symbol, unsigned color);
   static const int pattern[];
 
 protected:
@@ -180,31 +190,36 @@ protected:
    */
   void letxy(const QString& str, int iex, int iax, bool opposite = false);
   /**
-   * Converts from user units to integer units.
+   * Converts from user units to pixel units.
    * @param x x value in user units.
    * @param y y value in user units.
-   * @param ix x value in integer units (output).
-   * @param iy y value in integer units (output).
+   * @param ix x value in pixel units (output).
+   * @param iy y value in pixel units (output).
    */
   void r2i(double x, double y, int* ix, int* iy);
+  /**
+   * Draws a solid line from current to given position.
+   * @param x x value in user units.
+   * @param y y value in user units.
+   */
+  void drawLineTo(double x, double y);
   /**
    * Plots text.
    * @param str text.
-   * @param ix x value in integer units.
-   * @param iy y value in integer units.
+   * @param ix x value in pixel units.
+   * @param iy y value in pixel units.
    * @param iorg 1: left aligned, 2: centered, 3: right aligned.
    * @param bRect bounding rectangle, calculated when non-null.
    */
   void text(const QString& str, int ix, int iy, int iorg, QRect* bRect = 0);
-  int minx, maxx, miny, maxy, kxcur, kycur, ndigx, ndigy, minx0,
-      miny0, pFactor;
-  double textdir, scalx, scaly, xmin, xmax, ymin, ymax, xcur, ycur, dlen,
-         dhite, xscal, yscal, relang, relsin, relcos, dcur, factor, fDpi;
+  int minx, maxx, miny, maxy, kxcur, kycur, ndigx, ndigy, minx0, miny0;
+  double textdir, scalx, scaly, xcur, ycur, xscal, yscal, relang, relsin,
+         relcos, dcur, factor, fDpi;
   double dash[4];
   QPen pen1, pen2, pen3;
   static const char* face[];
 
-  friend class KplApp;
+  friend class Kpl;
   friend class FrameItem;
   friend class ThreeDItem;
   friend class LegendItem;
