@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -27,16 +27,16 @@
 #include <config.h>
 #endif
 
+#include <qptrlist.h>
+#include <qstringlist.h>
 #include <dcopobject.h>
 #include <kmainwindow.h>
 #include <kurl.h>
 
-class QStrList;
 class KAccel;
 class KAction;
 class KRecentFilesAction;
 class KToggleAction;
-class KURL;
 class ArrayItem;
 class FunItem;
 class ItemDlg;
@@ -49,22 +49,22 @@ class PSGraph;
   * Provides the kpl top level main window with menubar, toolbar and statusbar.
   * @author Werner Stille
   */
-class KplApp : public KMainWindow, public DCOPObject
+class Kpl : public KMainWindow, public DCOPObject
 {
   K_DCOP
   Q_OBJECT
 public:
   /** Constructor. Creates a kpl window. */
-  KplApp();
+  Kpl();
   /** Destructor. */
-  ~KplApp();
+  ~Kpl();
   /**
    * Returns a pointer to the current document connected to the KMainWindow
    * instance and is used by the View class to access the document object's
    * methods.
    * @return pointer to the current document.
    */
-  KplDoc* getDocument() const; 	
+  KplDoc* getDocument() const;
   /**
    * Opens files from URL list.
    * @param list pointer to list with URLs.
@@ -72,6 +72,16 @@ public:
    * @param type one of the following: Unknown, Data, Plot.
    */
   void openList(KURL::List* list, int idec, int type);
+  /**
+   * Calculates step size of x shift value.
+   * @return step size of x shift value.
+   */
+  double xStep();
+  /**
+   * Calculates step size of y shift value.
+   * @return step size of y shift value.
+   */
+  double yStep();
 
 k_dcop:
   /** Creates a new plot in the current view. */
@@ -193,9 +203,9 @@ k_dcop:
    * @param errModName error model function name.
    * @param itMax maximum number of iterations (nonlinear fits only).
    * @param tol tolerance level (nonlinear fits only).
-   * @param symb function plot: 0 for circles, < 0 for different markers,
+   * @param symb data plot: 0 for circles, < 0 for different markers,
    * >0 for different line types.
-   * @param color color for function plot.
+   * @param color color for data plot.
    * @param showDlg true to display parameter fit dialog.
    * @param savePar true to save resulting parameter files.
    * @param follow true to follow parameter sets in fit series.
@@ -329,7 +339,7 @@ k_dcop:
    * @param dx argument stepsize.
    * @param symb 0 for circles, < 0 for different markers,
    * >0 for different line types.
-   * @param color color for function plot.
+   * @param color color for data plot.
    * @param fx normalization factor for x values.
    * @param fy normalization factor for y values.
    * @param active true for visible item.
@@ -362,7 +372,7 @@ k_dcop:
                     int symb, const QString& color,
                     double fx, double fy, int active);
   /**
-   * Appends new spline item.
+   * Appends new cubic spline item.
    * @param deriv order of derivative.
    * @param low lower limit for spline integral.
    * @param xmin minimum argument value.
@@ -752,35 +762,17 @@ k_dcop:
   int exportValues(const QString& url, int iItem);
 
 protected:
-  /** Initializes menu and toolbar. */
-  void initActions();
   /** Calculates precision for statusbar. */
   void calcStatusBar();
   /** Inserts statusbar items. */
   void initStatusBar();
   /** Creates and initialize new statusbar. */
   void newStatusBar();
-  /**
-   * initKeyAccel creates the keyboard accelerator items for the available slots and changes the menu accelerators.
-   * @see KAccel
-   */
-  void initKeyAccel();
-  /**
-   * Initializes the document object of the main window that is connected to the view in initView().
-   * @see initView();
-   */
-  void initDocument();
-  /**
-   * Creates the centerwidget of the KMainWindow instance and sets it as the view.
-   */
-  void initView();
   /**
    * Saves the options.
    * @param saveAll save everything when true.
    */
   void saveOptions(bool saveAll);
-  /** Reads the options on init. */
-  void readOptions();
   /**
    * Opens an existing URL or local file for reading.
    * @param type one of the following: Unknown, Data, Plot.
@@ -797,7 +789,7 @@ protected:
    * @param url URL of the file.
    * @return true when file is saved.
    */
-  bool saveAs(const KURL &url);
+  bool saveAs(const KURL& url);
   /**
    * Draws items for PostScript file.
    * @param g pointer to PSGraph instance.
@@ -823,14 +815,18 @@ protected:
    * opened file by a temporary filename provided by KApplication.
    * @see KMainWindow#saveProperties
    */
-  virtual void saveProperties(KConfig*);
+  virtual void saveProperties(KConfig* cfg);
   /**
    * Reads the session config file and restores the application's state
    * including the last opened files and documents by reading the
    * temporary files saved by saveProperties().
    * @see KMainWindow#readProperties
    */
-  virtual void readProperties(KConfig*);
+  virtual void readProperties(KConfig* cfg);
+  /** Resets status text. */
+  void ready();
+  /** Shrinks window. */
+  void shrink();
   KAction* fileSave;
   KAction* fileSaveAs;
   KAction* fileClose;
@@ -845,7 +841,7 @@ protected:
   KAction* viewReload;
   KToggleAction* showToolbar;
   KToggleAction* showStatusbar;
-  KToggleAction* autoplot;
+  KToggleAction* autoPlot;
   KToggleAction* addData;
   KToggleAction* showSource;
   KToggleAction* boundingBox;
@@ -861,8 +857,8 @@ protected:
   KAccel* key_accel;
   QTimer* timer;
   KToolBar::BarPosition toolBarPos;
-  QList<ArrayItem> arr;
-  QList<FunItem> fun;
+  QPtrList<ArrayItem> arr;
+  QPtrList<FunItem> fun;
   QStringList previews;
   enum StatusId{StatusMsg = 1, StatusAdd, StatusPos, StatusVal};
   bool plot;
@@ -870,6 +866,7 @@ protected:
   double fz;
 
   friend class KplView;
+  friend class SettingsDlg;
 
 public slots:
   /**
@@ -890,6 +887,11 @@ protected slots:
   void slotFileOpenPlot();
   /** Opens an existing data file. */
   void slotFileOpenData();
+  /**
+   * Opens a recently opened file.
+   * @param url URL of the file.
+   */
+  void slotOpenRecent(const KURL& url);
   /** Saves the current plot file. */
   void slotFileSave();
   /** Saves the current plot as a file with different name. */
@@ -956,14 +958,14 @@ protected slots:
   void slotOptionsShowSource();
   /** Displays the key bindings dialog. */
   void slotOptionsKeys();
-  /** Displays the toolbars configure dialog. */
-  void slotEditToolbars();
-  /** Displays the basic settings dialog. */
-  void slotOptionsBasic();
-  /** Displays the autoplot settings dialog. */
-  void slotOptionsAuto();
-  /** Displays the autofit settings dialog. */
-  void slotOptionsAutoFit();
+  /** Displays the toolbars configuration dialog. */
+  void slotOptionsToolbars();
+  /** Displays the notifications configuration dialog. */
+  void slotOptionsNotifications();
+  /** Applies toolbar configuration. */
+  void slotNewToolbarConfig();
+  /** Displays the Kpl configuration dialog. */
+  void slotOptionsConfigure();
   /** Saves options. */
   void slotOptionsSave();
   /**
@@ -991,8 +993,6 @@ protected slots:
   void updStatus(const QPoint& pos, bool showValues);
   /** Clears mouse position information on statusbar. */
   void clearStatus();
-  /** Shrinks window. */
-  void shrink();
   /** Shows main popup menu. */
   void showPopupMenu();
 };
