@@ -12,17 +12,17 @@
 #include <kdatastream.h>
 
 
-KplApp_stub::KplApp_stub( const QCString& app, const QCString& obj )
+Kpl_stub::Kpl_stub( const QCString& app, const QCString& obj )
   : DCOPStub( app, obj )
 {
 }
 
-KplApp_stub::KplApp_stub( DCOPClient* client, const QCString& app, const QCString& obj )
+Kpl_stub::Kpl_stub( DCOPClient* client, const QCString& app, const QCString& obj )
   : DCOPStub( client, app, obj )
 {
 }
 
-void KplApp_stub::newPlot()
+void Kpl_stub::newPlot()
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -37,7 +37,7 @@ void KplApp_stub::newPlot()
     }
 }
 
-int KplApp_stub::openPlot( const QString& arg0 )
+int Kpl_stub::openPlot( const QString& arg0 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -62,7 +62,7 @@ int KplApp_stub::openPlot( const QString& arg0 )
     return result;
 }
 
-int KplApp_stub::openData( const QString& arg0 )
+int Kpl_stub::openData( const QString& arg0 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -87,7 +87,7 @@ int KplApp_stub::openData( const QString& arg0 )
     return result;
 }
 
-void KplApp_stub::doPlot()
+void Kpl_stub::doPlot()
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -102,7 +102,7 @@ void KplApp_stub::doPlot()
     }
 }
 
-int KplApp_stub::savePlot( const QString& arg0 )
+int Kpl_stub::savePlot( const QString& arg0 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -127,7 +127,7 @@ int KplApp_stub::savePlot( const QString& arg0 )
     return result;
 }
 
-int KplApp_stub::savePS( const QString& arg0, int arg1 )
+int Kpl_stub::savePS( const QString& arg0, int arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -153,7 +153,7 @@ int KplApp_stub::savePS( const QString& arg0, int arg1 )
     return result;
 }
 
-int KplApp_stub::printPlot( const QString& arg0, const QString& arg1, int arg2, int arg3 )
+int Kpl_stub::printPlot( const QString& arg0, const QString& arg1, int arg2, int arg3 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -181,7 +181,7 @@ int KplApp_stub::printPlot( const QString& arg0, const QString& arg1, int arg2,
     return result;
 }
 
-void KplApp_stub::setAutoplotOption( int arg0 )
+void Kpl_stub::setAutoplotOption( int arg0 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -198,7 +198,7 @@ void KplApp_stub::setAutoplotOption( int arg0 )
     }
 }
 
-void KplApp_stub::setAddFilesOption( int arg0 )
+void Kpl_stub::setAddFilesOption( int arg0 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -215,7 +215,7 @@ void KplApp_stub::setAddFilesOption( int arg0 )
     }
 }
 
-void KplApp_stub::setPathOption( int arg0 )
+void Kpl_stub::setPathOption( int arg0 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -232,7 +232,7 @@ void KplApp_stub::setPathOption( int arg0 )
     }
 }
 
-void KplApp_stub::setBoundingBoxOption( int arg0 )
+void Kpl_stub::setBoundingBoxOption( int arg0 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -249,7 +249,7 @@ void KplApp_stub::setBoundingBoxOption( int arg0 )
     }
 }
 
-void KplApp_stub::setPageFormat( double arg0, double arg1 )
+void Kpl_stub::setPageFormat( double arg0, double arg1 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -267,7 +267,7 @@ void KplApp_stub::setPageFormat( double arg0, double arg1 )
     }
 }
 
-void KplApp_stub::setColors( const QString& arg0, const QString& arg1, const QString& arg2 )
+void Kpl_stub::setColors( const QString& arg0, const QString& arg1, const QString& arg2 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -286,7 +286,7 @@ void KplApp_stub::setColors( const QString& arg0, const QString& arg1, const QSt
     }
 }
 
-void KplApp_stub::setOutputFormat( const QString& arg0, int arg1 )
+void Kpl_stub::setOutputFormat( const QString& arg0, int arg1 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -304,7 +304,7 @@ void KplApp_stub::setOutputFormat( const QString& arg0, int arg1 )
     }
 }
 
-void KplApp_stub::setAutoplot( double arg0, double arg1, double arg2, double arg3, int arg4, const QString& arg5, const QString& arg6, const QString& arg7, int arg8, int arg9, int arg10, int arg11, int arg12, int arg13, int arg14, int arg15, int arg16, int arg17 )
+void Kpl_stub::setAutoplot( double arg0, double arg1, double arg2, double arg3, int arg4, const QString& arg5, const QString& arg6, const QString& arg7, int arg8, int arg9, int arg10, int arg11, int arg12, int arg13, int arg14, int arg15, int arg16, int arg17 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -338,7 +338,7 @@ void KplApp_stub::setAutoplot( double arg0, double arg1, double arg2, double arg
     }
 }
 
-void KplApp_stub::setAutofit( const QString& arg0, const QString& arg1, int arg2, int arg3, const QString& arg4, const QString& arg5, int arg6, double arg7, int arg8, const QString& arg9, int arg10, int arg11, int arg12 )
+void Kpl_stub::setAutofit( const QString& arg0, const QString& arg1, int arg2, int arg3, const QString& arg4, const QString& arg5, int arg6, double arg7, int arg8, const QString& arg9, int arg10, int arg11, int arg12 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -367,7 +367,7 @@ void KplApp_stub::setAutofit( const QString& arg0, const QString& arg1, int arg2
     }
 }
 
-int KplApp_stub::loadAutofitPar( const QString& arg0 )
+int Kpl_stub::loadAutofitPar( const QString& arg0 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -392,7 +392,7 @@ int KplApp_stub::loadAutofitPar( const QString& arg0 )
     return result;
 }
 
-int KplApp_stub::setAutofitPar( int arg0, double arg1 )
+int Kpl_stub::setAutofitPar( int arg0, double arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -418,7 +418,7 @@ int KplApp_stub::setAutofitPar( int arg0, double arg1 )
     return result;
 }
 
-int KplApp_stub::enableFitPar( int arg0, int arg1 )
+int Kpl_stub::enableFitPar( int arg0, int arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -444,7 +444,7 @@ int KplApp_stub::enableFitPar( int arg0, int arg1 )
     return result;
 }
 
-int KplApp_stub::loadErrModPar( const QString& arg0, int arg1 )
+int Kpl_stub::loadErrModPar( const QString& arg0, int arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -470,7 +470,7 @@ int KplApp_stub::loadErrModPar( const QString& arg0, int arg1 )
     return result;
 }
 
-int KplApp_stub::setErrModPar( int arg0, double arg1, int arg2 )
+int Kpl_stub::setErrModPar( int arg0, double arg1, int arg2 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -497,7 +497,7 @@ int KplApp_stub::setErrModPar( int arg0, double arg1, int arg2 )
     return result;
 }
 
-int KplApp_stub::deleteItem( int arg0 )
+int Kpl_stub::deleteItem( int arg0 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -522,7 +522,7 @@ int KplApp_stub::deleteItem( int arg0 )
     return result;
 }
 
-int KplApp_stub::moveItem( int arg0, int arg1 )
+int Kpl_stub::moveItem( int arg0, int arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -548,7 +548,7 @@ int KplApp_stub::moveItem( int arg0, int arg1 )
     return result;
 }
 
-int KplApp_stub::activateItem( int arg0, int arg1 )
+int Kpl_stub::activateItem( int arg0, int arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -574,7 +574,7 @@ int KplApp_stub::activateItem( int arg0, int arg1 )
     return result;
 }
 
-void KplApp_stub::newFrameItem( double arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, int arg8, int arg9, int arg10, int arg11, const QString& arg12, const QString& arg13, double arg14, double arg15, int arg16, int arg17, int arg18, int arg19, int arg20, const QString& arg21, const QString& arg22, const QString& arg23, double arg24, int arg25 )
+void Kpl_stub::newFrameItem( double arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, int arg8, int arg9, int arg10, int arg11, const QString& arg12, const QString& arg13, double arg14, double arg15, int arg16, int arg17, int arg18, int arg19, int arg20, const QString& arg21, const QString& arg22, const QString& arg23, double arg24, int arg25 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -616,7 +616,7 @@ void KplApp_stub::newFrameItem( double arg0, double arg1, double arg2, double ar
     }
 }
 
-void KplApp_stub::newAutoFrameItem()
+void Kpl_stub::newAutoFrameItem()
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -631,7 +631,7 @@ void KplApp_stub::newAutoFrameItem()
     }
 }
 
-int KplApp_stub::newArrayItem( const QString& arg0, int arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7, const QString& arg8, double arg9, double arg10, int arg11 )
+int Kpl_stub::newArrayItem( const QString& arg0, int arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7, const QString& arg8, double arg9, double arg10, int arg11 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -667,7 +667,7 @@ int KplApp_stub::newArrayItem( const QString& arg0, int arg1, int arg2, int arg3
     return result;
 }
 
-int KplApp_stub::newFunItem( const QString& arg0, const QString& arg1, double arg2, double arg3, double arg4, int arg5, const QString& arg6, double arg7, double arg8, int arg9 )
+int Kpl_stub::newFunItem( const QString& arg0, const QString& arg1, double arg2, double arg3, double arg4, int arg5, const QString& arg6, double arg7, double arg8, int arg9 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -701,7 +701,7 @@ int KplApp_stub::newFunItem( const QString& arg0, const QString& arg1, double ar
     return result;
 }
 
-int KplApp_stub::newParFunItem( const QString& arg0, const QString& arg1, const QString& arg2, const QString& arg3, double arg4, double arg5, double arg6, int arg7, const QString& arg8, double arg9, double arg10, int arg11 )
+int Kpl_stub::newParFunItem( const QString& arg0, const QString& arg1, const QString& arg2, const QString& arg3, double arg4, double arg5, double arg6, int arg7, const QString& arg8, double arg9, double arg10, int arg11 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -737,7 +737,7 @@ int KplApp_stub::newParFunItem( const QString& arg0, const QString& arg1, const
     return result;
 }
 
-void KplApp_stub::newSplineItem( int arg0, double arg1, double arg2, double arg3, double arg4, int arg5, const QString& arg6, double arg7, double arg8, double arg9, int arg10 )
+void Kpl_stub::newSplineItem( int arg0, double arg1, double arg2, double arg3, double arg4, int arg5, const QString& arg6, double arg7, double arg8, double arg9, int arg10 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -764,7 +764,7 @@ void KplApp_stub::newSplineItem( int arg0, double arg1, double arg2, double arg3
     }
 }
 
-int KplApp_stub::newArray3DItem( double arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, double arg8, double arg9, int arg10, int arg11, int arg12, int arg13, int arg14, int arg15, const QString& arg16, const QString& arg17, const QString& arg18, double arg19, double arg20, double arg21, int arg22, int arg23, int arg24, int arg25, int arg26, int arg27, double arg28, double arg29, double arg30, double arg31, double arg32, double arg33, double arg34, int arg35, int arg36, int arg37, const QString& arg38, const QString& arg39, const QString& arg40, const QString& arg41, double arg42, const QString& arg43, int arg44, int arg45, int arg46, int arg47, int arg48, int arg49, int arg50, double arg51, double arg52, double arg53, double arg54, double arg55, double arg56, int arg57 )
+int Kpl_stub::newArray3DItem( double arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, double arg8, double arg9, int arg10, int arg11, int arg12, int arg13, int arg14, int arg15, const QString& arg16, const QString& arg17, const QString& arg18, double arg19, double arg20, double arg21, int arg22, int arg23, int arg24, int arg25, int arg26, int arg27, double arg28, double arg29, double arg30, double arg31, double arg32, double arg33, double arg34, int arg35, int arg36, int arg37, const QString& arg38, const QString& arg39, const QString& arg40, const QString& arg41, double arg42, const QString& arg43, int arg44, int arg45, int arg46, int arg47, int arg48, int arg49, int arg50, double arg51, double arg52, double arg53, double arg54, double arg55, double arg56, int arg57 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -846,7 +846,7 @@ int KplApp_stub::newArray3DItem( double arg0, double arg1, double arg2, double a
     return result;
 }
 
-int KplApp_stub::newFun3DItem( double arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, double arg8, double arg9, int arg10, int arg11, int arg12, int arg13, int arg14, int arg15, const QString& arg16, const QString& arg17, const QString& arg18, double arg19, double arg20, double arg21, int arg22, int arg23, int arg24, int arg25, int arg26, int arg27, double arg28, double arg29, double arg30, double arg31, double arg32, double arg33, double arg34, int arg35, int arg36, int arg37, const QString& arg38, const QString& arg39, const QString& arg40, const QString& arg41, double arg42, const QString& arg43, const QString& arg44, double arg45, double arg46, double arg47, double arg48, double arg49, int arg50 )
+int Kpl_stub::newFun3DItem( double arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, double arg8, double arg9, int arg10, int arg11, int arg12, int arg13, int arg14, int arg15, const QString& arg16, const QString& arg17, const QString& arg18, double arg19, double arg20, double arg21, int arg22, int arg23, int arg24, int arg25, int arg26, int arg27, double arg28, double arg29, double arg30, double arg31, double arg32, double arg33, double arg34, int arg35, int arg36, int arg37, const QString& arg38, const QString& arg39, const QString& arg40, const QString& arg41, double arg42, const QString& arg43, const QString& arg44, double arg45, double arg46, double arg47, double arg48, double arg49, int arg50 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -921,7 +921,7 @@ int KplApp_stub::newFun3DItem( double arg0, double arg1, double arg2, double arg
     return result;
 }
 
-void KplApp_stub::newImageItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, int arg5 )
+void Kpl_stub::newImageItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, int arg5 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -943,7 +943,7 @@ void KplApp_stub::newImageItem( const QString& arg0, double arg1, double arg2, d
     }
 }
 
-void KplApp_stub::newLegendItem( int arg0, const QString& arg1, double arg2, double arg3, const QString& arg4, const QString& arg5, double arg6, double arg7, double arg8, int arg9 )
+void Kpl_stub::newLegendItem( int arg0, const QString& arg1, double arg2, double arg3, const QString& arg4, const QString& arg5, double arg6, double arg7, double arg8, int arg9 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -969,7 +969,7 @@ void KplApp_stub::newLegendItem( int arg0, const QString& arg1, double arg2, dou
     }
 }
 
-void KplApp_stub::newTextItem( const QString& arg0, const QString& arg1, int arg2, double arg3, double arg4, double arg5, double arg6, int arg7 )
+void Kpl_stub::newTextItem( const QString& arg0, const QString& arg1, int arg2, double arg3, double arg4, double arg5, double arg6, int arg7 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -993,7 +993,7 @@ void KplApp_stub::newTextItem( const QString& arg0, const QString& arg1, int arg
     }
 }
 
-void KplApp_stub::newLineItem( int arg0, const QString& arg1, double arg2, double arg3, double arg4, double arg5, double arg6, int arg7 )
+void Kpl_stub::newLineItem( int arg0, const QString& arg1, double arg2, double arg3, double arg4, double arg5, double arg6, int arg7 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -1017,7 +1017,7 @@ void KplApp_stub::newLineItem( int arg0, const QString& arg1, double arg2, doubl
     }
 }
 
-void KplApp_stub::newArrowItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, int arg6 )
+void Kpl_stub::newArrowItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, int arg6 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -1040,7 +1040,7 @@ void KplApp_stub::newArrowItem( const QString& arg0, double arg1, double arg2, d
     }
 }
 
-void KplApp_stub::newArcItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, double arg8, int arg9 )
+void Kpl_stub::newArcItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7, double arg8, int arg9 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -1066,7 +1066,7 @@ void KplApp_stub::newArcItem( const QString& arg0, double arg1, double arg2, dou
     }
 }
 
-void KplApp_stub::newRectangleItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, int arg6, int arg7 )
+void Kpl_stub::newRectangleItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, int arg6, int arg7 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -1090,7 +1090,7 @@ void KplApp_stub::newRectangleItem( const QString& arg0, double arg1, double arg
     }
 }
 
-void KplApp_stub::newEllipseItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, int arg6, int arg7 )
+void Kpl_stub::newEllipseItem( const QString& arg0, double arg1, double arg2, double arg3, double arg4, double arg5, int arg6, int arg7 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -1114,7 +1114,7 @@ void KplApp_stub::newEllipseItem( const QString& arg0, double arg1, double arg2,
     }
 }
 
-void KplApp_stub::newScaleBarItem( const QString& arg0, const QString& arg1, double arg2, double arg3, double arg4, double arg5, int arg6, int arg7 )
+void Kpl_stub::newScaleBarItem( const QString& arg0, const QString& arg1, double arg2, double arg3, double arg4, double arg5, int arg6, int arg7 )
 {
     if ( !dcopClient()  ) {
 	setStatus( CallFailed );
@@ -1138,7 +1138,7 @@ void KplApp_stub::newScaleBarItem( const QString& arg0, const QString& arg1, dou
     }
 }
 
-int KplApp_stub::autoScaleFrame( int arg0, int arg1 )
+int Kpl_stub::autoScaleFrame( int arg0, int arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1164,7 +1164,7 @@ int KplApp_stub::autoScaleFrame( int arg0, int arg1 )
     return result;
 }
 
-int KplApp_stub::loadPar( const QString& arg0, int arg1, int arg2 )
+int Kpl_stub::loadPar( const QString& arg0, int arg1, int arg2 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1191,7 +1191,7 @@ int KplApp_stub::loadPar( const QString& arg0, int arg1, int arg2 )
     return result;
 }
 
-int KplApp_stub::setPar( int arg0, int arg1, double arg2, int arg3 )
+int Kpl_stub::setPar( int arg0, int arg1, double arg2, int arg3 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1219,7 +1219,7 @@ int KplApp_stub::setPar( int arg0, int arg1, double arg2, int arg3 )
     return result;
 }
 
-int KplApp_stub::setArrayRange( int arg0, int arg1, int arg2 )
+int Kpl_stub::setArrayRange( int arg0, int arg1, int arg2 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1246,7 +1246,7 @@ int KplApp_stub::setArrayRange( int arg0, int arg1, int arg2 )
     return result;
 }
 
-int KplApp_stub::addFitItems( int arg0, int arg1, int arg2, int arg3, const QString& arg4, const QString& arg5 )
+int Kpl_stub::addFitItems( int arg0, int arg1, int arg2, int arg3, const QString& arg4, const QString& arg5 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1276,7 +1276,7 @@ int KplApp_stub::addFitItems( int arg0, int arg1, int arg2, int arg3, const QStr
     return result;
 }
 
-int KplApp_stub::fit( int arg0, int arg1, int arg2 )
+int Kpl_stub::fit( int arg0, int arg1, int arg2 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1303,7 +1303,7 @@ int KplApp_stub::fit( int arg0, int arg1, int arg2 )
     return result;
 }
 
-int KplApp_stub::splineFit( int arg0, int arg1, int arg2, double arg3, double arg4, double arg5, int arg6, const QString& arg7, const QString& arg8 )
+int Kpl_stub::splineFit( int arg0, int arg1, int arg2, double arg3, double arg4, double arg5, int arg6, const QString& arg7, const QString& arg8 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1336,7 +1336,7 @@ int KplApp_stub::splineFit( int arg0, int arg1, int arg2, double arg3, double ar
     return result;
 }
 
-double KplApp_stub::chiSquare()
+double Kpl_stub::chiSquare()
 {
     double result;
     if ( !dcopClient()  ) {
@@ -1359,7 +1359,7 @@ double KplApp_stub::chiSquare()
     return result;
 }
 
-int KplApp_stub::saveFitPar( const QString& arg0 )
+int Kpl_stub::saveFitPar( const QString& arg0 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
@@ -1384,7 +1384,7 @@ int KplApp_stub::saveFitPar( const QString& arg0 )
     return result;
 }
 
-int KplApp_stub::exportValues( const QString& arg0, int arg1 )
+int Kpl_stub::exportValues( const QString& arg0, int arg1 )
 {
     int result = 0;
     if ( !dcopClient()  ) {
