@@ -11,16 +11,18 @@
 
 #include <dcopstub.h>
 #include <config.h>
+#include <qptrlist.h>
+#include <qstringlist.h>
 #include <dcopobject.h>
 #include <kmainwindow.h>
 #include <kurl.h>
 
 
-class KplApp_stub : virtual public DCOPStub
+class Kpl_stub : virtual public DCOPStub
 {
 public:
-    KplApp_stub( const QCString& app, const QCString& id );
-    KplApp_stub( DCOPClient* client, const QCString& app, const QCString& id );
+    Kpl_stub( const QCString& app, const QCString& id );
+    Kpl_stub( DCOPClient* client, const QCString& app, const QCString& id );
     virtual void newPlot();
     virtual int openPlot( const QString& url );
     virtual int openData( const QString& url );
@@ -73,7 +75,7 @@ public:
     virtual int saveFitPar( const QString& url );
     virtual int exportValues( const QString& url, int iItem );
 protected:
-    KplApp_stub() : DCOPStub( never_use ) {};
+    Kpl_stub() : DCOPStub( never_use ) {};
 };
 
 
