@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 22 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -20,26 +20,17 @@
  ***************************************************************************/
 
 #include <kiconloader.h>
-#include <kapp.h>
 #include "kplchecklistitem.h"
 
 KplCheckListItem::KplCheckListItem(KListView* _parent, KplCheckListItem* after) :
-#if KDE_VERSION >= 220
   KListViewItem(_parent, after), on(false)
-#else
-  QListViewItem(_parent, after), on(false)
-#endif
 {
   init();
 }
 
 KplCheckListItem::KplCheckListItem(KplCheckListItem* _parent,
                                    KplCheckListItem* after) :
-#if KDE_VERSION >= 220
   KListViewItem(_parent, after), on(false)
-#else
-  QListViewItem(_parent, after), on(false)
-#endif
 {
   init();
 }
