@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -27,9 +27,11 @@
 #include <qhbox.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <kapp.h>
+#include <qtextstream.h>
+#include <kapplication.h>
 #include <kfiledialog.h>
 #include <kglobal.h>
+#include <kio/job.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -53,7 +55,8 @@
 #include "utils.h"
 
 KplDoc::KplDoc(QObject* _parent) :
- QObject(_parent), modified(false), fType(Unknown), chisq(0.0)
+ QObject(_parent), modified(false), app((QWidget*) _parent), fType(Unknown),
+ chisq(0.0)
 {
   memset(pLast, 0, sizeof(pLast));
   memset(pErr, 0, sizeof(pErr));
@@ -75,40 +78,27 @@ void KplDoc::newDocument()
   aut.nyLeg = 0;
 }
 
-bool KplDoc::saveDocument(const KURL& url, QList<KplItem>* _items, bool _abs)
+bool KplDoc::saveDocument(const KURL& url, QPtrList<KplItem>* _items, bool _abs)
 {
   QString filename = url.isLocalFile() ? url.path() : tmpFile();
   bool success = true;
   if (QFile::exists(filename))
     success = QFile::remove(filename);
   if (success) {
-    {
-      KSimpleConfig plo(filename);
-      plo.setGroup("Items");
-      plo.writeEntry("nitems", _items->count());
-      for (unsigned int i = 0; i < _items->count(); i++) {
-        plo.setGroup("Item " + QString::number(i));
-        _items->at(i)->writePlo(&plo, url, _abs, this);
-      }
+    KSimpleConfig plo(filename);
+    plo.setGroup("Items");
+    plo.writeEntry("nitems", _items->count());
+    for (unsigned i = 0; i < _items->count(); i++) {
+      plo.setGroup("Item " + QString::number(i));
+      _items->at(i)->writePlo(&plo, url, _abs, this);
     }
     if (!url.isLocalFile())
       copyTmp(filename, url);
   } else
-    KMessageBox::sorry((QWidget*) parent(),
-                       i18n("Writing to this file not possible."));
+    KMessageBox::sorry(app, i18n("Writing to this file not possible."));
   return success;
 }
 
-void KplDoc::setModified(bool m)
-{
-  modified = m;
-}
-
-bool KplDoc::isModified() const
-{
-  return modified;
-}
-
 void KplDoc::setCurrentDir(const KURL& url)
 {
   QFileInfo fi(url.path());
@@ -117,11 +107,6 @@ void KplDoc::setCurrentDir(const KURL& url)
   m_dir = u.url(+1);
 }
 
-const QString& KplDoc::currentDir() const
-{
-  return m_dir;
-}
-
 void KplDoc::setURL(const KURL& url)
 {
   docURL = url;
@@ -133,26 +118,6 @@ void KplDoc::setURL(const KURL& url)
     m_time = QDateTime();
 }
 
-const KURL& KplDoc::URL() const
-{
-  return docURL;
-}
-
-const QDateTime& KplDoc::URLTime() const
-{
-  return m_time;
-}
-
-KplDoc::FileType KplDoc::fileType() const
-{
-  return fType;
-}
-
-void KplDoc::setFileType(FileType iType)
-{
-  fType = iType;
-}
-
 void KplDoc::freeAllItems()
 {
   itd.clear();
@@ -217,121 +182,6 @@ void KplDoc::newItem(KplItem::ItemTypes ityp, int index)
     itd.insert(index, it);
 }
 
-void KplDoc::autoFile(double* xmi, double* xma, double* tic, int* mtic,
-                      int* ndig, int* ie, double* fn, const double* x, int n,
-                      double c, bool _log)
-{
-  double xmin, xmax;
-  Utils::minMaxFile(&xmin, &xmax, x, n);
-  if (aut.autoNorm)
-    Utils::expo(QMAX(fabs(xmin), fabs(xmax)), ie, fn);
-  else {
-    *ie = 0;
-    *fn = 1.0;
-  }
-  Utils::autoSc(xmi, xma, tic, mtic, ndig, xmin, xmax, *fn, c, _log);
-}
-
-bool KplDoc::autoScale(FrameItem* fd, ArrayItem* ad)
-{
-  if ((ad->x) && (aut.ixAuto < ad->ncols) && (aut.iyAuto < ad->ncols)) {
-    autoFile(&fd->xmi, &fd->xma, &fd->xtic, &fd->mticx, &fd->ndigx,
-             &fd->iex, &ad->fx, ad->x[aut.ixAuto], ad->nrows,
-             0.2, aut.autoLogX);
-    autoFile(&fd->ymi, &fd->yma, &fd->ytic, &fd->mticy, &fd->ndigy,
-             &fd->iey, &ad->fy, ad->x[aut.iyAuto], ad->nrows,
-             0.2 * aut.xlAuto / aut.ylAuto, aut.autoLogY);
-    if (aut.autohPath)
-      fd->sh = ad->url.isLocalFile() ? ad->url.path() : ad->url.url();
-    int minCol = ad->ncols - 1;
-    ad->ix = QMIN(aut.ixAuto, minCol);
-    ad->iy = QMIN(aut.iyAuto, minCol);
-    ad->ie = QMIN(aut.ieAuto, minCol);
-    ad->symb = aut.autoSymb;
-    ad->istart = 0;
-    ad->n = ad->nrows;
-    ad->errbars = aut.autoErr & (ad->ie < ad->ncols);
-    return false;
-  }
-  return true;
-}
-
-void KplDoc::autoScaleFrame(bool autoNorm, int item, int* iex, int* iey,
-                            double* fx, double* fy, double* xmi, double* xma,
-                            double* ymi, double* yma, double* xtic, double* ytic,
-                            int* mticx, int* mticy, int* ndigx, int* ndigy,
-                            double c, bool logx, bool logy)
-{
-  if (autoNorm) {
-    double fxt, fyt;
-    int iext, ieyt;
-    *iex = *iey = 999;
-    for (KplItem* itm = itd.at(item + 1); itm; itm = itd.next()) {
-      if (itm->iType() == KplItem::Frame)
-        break;
-      if (itm->active) {
-        iext = *iex;
-        ieyt = *iey;
-        itm->expoItem(&iext, &ieyt, &fxt, &fyt);
-        if (iext < *iex) {
-          *iex = iext;
-          *fx = fxt;
-        }
-        if (ieyt < *iey) {
-          *iey = ieyt;
-          *fy = fyt;
-        }
-      }
-    }
-  } else {
-    *iex = *iey = 0;
-    *fx = *fy = 1.0;
-  }
-  if ((*iex != 999) && (*iey != 999)) {
-    double xmin = 1.0e300;
-    double ymin = xmin;
-    double xmax = -xmin;
-    double ymax = xmax;
-    for (KplItem *itm = itd.at(item + 1); itm; itm = itd.next()) {
-      if (itm->iType() == KplItem::Frame)
-        break;
-      if (itm->active) {
-        *xmi = xmin;
-        *ymi = ymin;
-        *xma = xmax;
-        *yma = ymax;
-        itm->minMax(xmi, xma, ymi, yma);
-        xmin = QMIN(xmin, *xmi);
-        xmax = QMAX(xmax, *xma);
-        ymin = QMIN(ymin, *ymi);
-        ymax = QMAX(ymax, *yma);
-      }
-    }
-    Utils::autoSc(xmi, xma, xtic, mticx, ndigx, xmin, xmax, *fx, 0.2, logx);
-    Utils::autoSc(ymi, yma, ytic, mticy, ndigy, ymin, ymax, *fy, 0.2 * c, logy);
-  }
-}
-
-void KplDoc::setOptions(Kpl::AutoStruct* opt)
-{
-  aut = *opt;
-}
-
-const Kpl::AutoStruct* KplDoc::options() const
-{
-  return &aut;
-}
-
-const QString& KplDoc::separator() const
-{
-  return separators[aut.iSep];
-}
-
-QList<KplItem>* KplDoc::items()
-{
-  return &itd;
-}
-
 QString KplDoc::tmpFile() const
 {
   KTempFile f;
@@ -344,11 +194,6 @@ void KplDoc::copyTmp(const QString& src, const KURL& dest)
           SIGNAL(result(KIO::Job*)), this, SLOT(slotIOfinished(KIO::Job*)));
 }
 
-const QString KplDoc::number(double val) const
-{
-  return QString::number(val, aut.format, aut.prec);
-}
-
 bool KplDoc::getWriteURL(QWidget* parent, KURL& url, const QString& filter)
 {
   url = KFileDialog::getSaveURL(currentDir(), filter);
@@ -363,7 +208,7 @@ bool KplDoc::getWriteURL(QWidget* parent, KURL& url, const QString& filter)
       return false;
     }
   } else {
-#if KDE_VERSION >= 0x03015a
+#if KDE_VERSION >= 0x030200
     if (!KIO::NetAccess::exists(url, true, parent))
       return true;
     if (!KIO::NetAccess::exists(url, false, parent)) {
@@ -426,7 +271,7 @@ bool KplDoc::loadPar(const KURL& url, QWidget* parent, double* p, int idec)
 {
   bool success = false;
   QString fn;
-#if KDE_VERSION >= 0x03015a
+#if KDE_VERSION >= 0x030200
   if (KIO::NetAccess::download(url, fn, parent)) {
 #else
   if (KIO::NetAccess::download(url, fn)) {
@@ -436,7 +281,7 @@ bool KplDoc::loadPar(const KURL& url, QWidget* parent, double* p, int idec)
       memset(p, 0, KPL_NPMAX * sizeof(double));
       QTextStream t(&f);
       int i = -1;
-      while (!t.eof() && (++i < KPL_NPMAX)){
+      while (!t.atEnd() && (++i < KPL_NPMAX)){
         QString line = t.readLine();
         Utils::translate(line, idec);
         p[i] = line.toDouble();
@@ -500,7 +345,7 @@ void KplDoc::autoFit(ArrayItem* ad, FunItem* fd)
   fd->tmax = ad->x[ad->ix][ad->istart + ad->n - 1];
   fd->fx = ad->fx;
   fd->fy = ad->fy;
-  if (FunItem::getFuncAddr(fd->pathy.path(), fd->namey, &fd->hmody, &fd->fkty))
+  if (!FunItem::getFuncAddr(fd->pathy.path(), fd->namey, &fd->liby, &fd->fkty))
     return;
   int mode = 0;
   if (aut.fitShowDlg)
@@ -509,9 +354,9 @@ void KplDoc::autoFit(ArrayItem* ad, FunItem* fd)
     mode |= FitDlg::SavePar;
   if (aut.fitFollow)
     mode |= FitDlg::Follow;
-  QList<ArrayItem> arr;
+  QPtrList<ArrayItem> arr;
+  QPtrList<FunItem> fun;
   arr.append(ad);
-  QList<FunItem> fun;
   fun.append(fd);
   KConfig* config = KGlobal::config();
   config->setGroup("DataErrors0");
@@ -519,13 +364,13 @@ void KplDoc::autoFit(ArrayItem* ad, FunItem* fd)
   if (!aut.err.fitErrCol) {
     config->writeEntry("ErrorModelPath", aut.err.errModPath);
     config->writeEntry("ErrorModelName", aut.err.errModName);
-    QStrList s1;
+    QStringList s1;
     for (int i = 0; i < KPL_NPMAX; i++)
-      s1.insert(i, number(aut.err.pErrMod[i]));
+      s1.append(number(aut.err.pErrMod[i]));
     config->writeEntry("ErrorModelParam", s1, ' ');
     config->writeEntry("ErrorModelArgument", aut.err.errModArg);
   }
-  FitDlg dlg((QWidget*) parent(), this, &arr, &fun, mode);
+  FitDlg dlg(app, this, &arr, &fun, mode);
   dlg.fit();
   if (aut.fitShowDlg) {
     backupItems();
@@ -545,13 +390,8 @@ QComboBox* KplDoc::decimalWidget(int idec, KFileDialog* dlg, QHBox* hbox,
   cb->insertStringList(list);
   cb->setCurrentItem(idec);
   cb->setFixedWidth(80);
-#if QT_VERSION >= 0x030100
   (new QLabel("", hbox))->setSizePolicy(QSizePolicy::MinimumExpanding,
                                         QSizePolicy::Minimum);
-#else
-  (new QLabel("", hbox))->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
-                                        QSizePolicy::Minimum));
-#endif
   hbox->setSpacing(dlg->spacingHint());
   dlg->setOperationMode(KFileDialog::Opening);
   dlg->setCaption(i18n("Open"));
@@ -588,31 +428,15 @@ bool KplDoc::openDocument(const KURL& url, int idec, FileType type)
     ArrayItem* ad = (ArrayItem*) itd.last();
     ad->url = url;
     ad->idec = idec;
-    ad->n = ad->nrows = ArrayItem::readFile(url, &ad->ncols, &ad->x, ad->idec);
+    ad->n = ad->readFile();
     success = ad->n;
     if (success) {
-      if (itd.count() == 2) {
-        if (autoScale(fd, ad))
-          success = false;
-      } else {
-        double fx, fy;
-        int iex = 0, iey = 0;
-        autoScaleFrame(aut.autoNorm, iItem, &iex, &iey, &fx, &fy,
-                       &fd->xmi, &fd->xma, &fd->ymi, &fd->yma,
-                       &fd->xtic, &fd->ytic, &fd->mticx, &fd->mticy,
-                       &fd->ndigx, &fd->ndigy, fd->w / fd->h,
-                       fd->logx, fd->logy);
-        if ((iex != 999) && (iey != 999)) {
-          fd->iex = iex;
-          fd->iey = iey;
-          for (KplItem* itm = itd.at(iItem + 1); itm; itm = itd.next()) {
-            if (itm->iType() == KplItem::Frame)
-              break;
-            itm->normalize(fx, fy);
-          }
-        } else
-          success = false;
-      }
+      success = fd->autoScale(aut.autoNorm, &itd);
+      ad->adjustCols(aut.ixAuto, aut.iyAuto, aut.ieAuto);
+      ad->errbars = aut.autoErr & (aut.ieAuto < ad->ncols);
+      if (itd.count() == 2)
+        if (aut.autohPath)
+          fd->sh = ad->url.isLocalFile() ? ad->url.path() : ad->url.url();
       if (success) {
         setURL(url);
         if (aut.autoFit) {
@@ -624,8 +448,8 @@ bool KplDoc::openDocument(const KURL& url, int idec, FileType type)
     }
   } else {
     QString tmpfile;
-#if KDE_VERSION >= 0x03015a
-    success = KIO::NetAccess::download(url, tmpfile, (QWidget*) parent());
+#if KDE_VERSION >= 0x030200
+    success = KIO::NetAccess::download(url, tmpfile, app);
 #else
     success = KIO::NetAccess::download(url, tmpfile);
 #endif
@@ -728,10 +552,8 @@ bool KplDoc::openDocument(const KURL& url, int idec, FileType type)
       itd.removeLast();
       if (newFrame)
         itd.removeLast();
-    } else
-      if (!aut.addData)
-        restoreItems();
-    KMessageBox::error((QWidget*) parent(),
+    }
+    KMessageBox::error(app,
                        QString(i18n("while loading the file\n")) + url.path());
   }
   return success;
@@ -739,7 +561,7 @@ bool KplDoc::openDocument(const KURL& url, int idec, FileType type)
 
 bool KplDoc::restoreItems(bool undo)
 {
-  QList<KplItem>* itc = 0;
+  QPtrList<KplItem>* itc = 0;
   if (undo) {
     if (undoAllowed())
       itc = itb.prev();
@@ -748,7 +570,7 @@ bool KplDoc::restoreItems(bool undo)
       itc = itb.next();
   if (itc) {
     itd.clear();
-    for (unsigned int i = 0; i < itc->count(); i++)
+    for (unsigned i = 0; i < itc->count(); i++)
     itd.append(itc->at(i)->copy());
     emit modelChanged(true, true);
     return true;
@@ -787,7 +609,7 @@ void KplDoc::slotIOfinished(KIO::Job* job)
 
 void KplDoc::backupItems(bool list)
 {
-  QList<KplItem>* itc = itb.current();
+  QPtrList<KplItem>* itc = itb.current();
   if (itc) {
     if (itc == itb.getLast()) {
       if (itb.count() >= 20)
@@ -797,9 +619,9 @@ void KplDoc::backupItems(bool list)
         itb.removeLast();
       while (itc != itb.current());
   }
-  itb.append(new QList<KplItem>);
+  itb.append(new QPtrList<KplItem>);
   itb.current()->setAutoDelete(true);
-  for (unsigned int i = 0; i < itd.count(); i++)
+  for (unsigned i = 0; i < itd.count(); i++)
     itb.current()->append(itd.at(i)->copy());
   emit modelChanged(true, list);
 }
@@ -821,3 +643,15 @@ void KplDoc::moveItem(int is, int id)
   setModified();
   backupItems();
 }
+
+void KplDoc::orderItems(QValueList<int>& list)
+{
+  for (unsigned i = 0; i < list.count(); i++)
+    itd.append(itd.at(list[i]));
+  itd.setAutoDelete(false);
+  for (unsigned i = 0; i < list.count(); i++)
+    itd.removeFirst();
+  itd.setAutoDelete(true);
+  setModified();
+  backupItems();
+}
