@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -27,10 +27,10 @@
 #include <config.h>
 #endif
 
-#include <qobject.h>
-#include <qlist.h>
 #include <qdatetime.h>
-#include <kfile.h>
+#include <qobject.h>
+#include <qptrlist.h>
+#include <qstringlist.h>
 #include <kio/job.h>
 #include <kurl.h>
 #include "kplitem.h"
@@ -39,7 +39,9 @@
 class QComboBox;
 class QHBox;
 class QLineEdit;
+template<class> class QValueList;
 class KFileDialog;
+class Kpl;
 class ArrayItem;
 class FrameItem;
 class FunItem;
@@ -71,19 +73,19 @@ public:
    * @param abs save absolute URL when true.
    * @return true for success.
    */
-  bool saveDocument(const KURL& url, QList<KplItem>* items, bool abs = true);
+  bool saveDocument(const KURL& url, QPtrList<KplItem>* items, bool abs = true);
   /**
    * Sets the modified flag for the document after a modifying action on the
    * view connected to the document.
-   * @param modified true for document modified after last save action.
+   * @param m true for document modified after last save action.
    */
-  void setModified(bool modified = true);
+  inline void setModified(bool m = true) { modified = m; };
   /**
    * Returns if the document is modified or not. Use this to determine if your
    * document needs saving by the user on closing.
    * @return true for document modified after last save action.
    */
-  bool isModified() const;
+  inline bool isModified() const { return modified; };
   /**
    * Sets the current directory path.
    * @param url current path.
@@ -93,7 +95,7 @@ public:
    * Returns the current path.
    * @return current directory path.
    */
-  const QString& currentDir() const;
+  inline const QString& currentDir() const { return m_dir; };
   /**
    * Sets the URL of the document.
    * @param url URL.
@@ -103,22 +105,22 @@ public:
    * Returns the URL of the document.
    * @return URL.
    */
-  const KURL& URL() const;
+  inline const KURL& URL() const { return docURL; };
   /**
    * Returns the modification time of the URL of the document.
    * @return modification date and time.
    */
-  const QDateTime& URLTime() const;
+  inline const QDateTime& URLTime() const { return m_time; };
   /**
    * Returns the type of current document file.
    * @return file type (Plot or Data).
    */
-  FileType fileType() const;
+  inline FileType fileType() const { return fType; };
   /**
    * Set the type of current document file.
    * @param iType file type (Plot or Data).
    */
-  void setFileType(FileType iType);
+  inline void setFileType(FileType iType) { fType = iType; };
   /**
    * Appends or inserts new item to list and initializes structure.
    * @param ityp type of item. One of the following:
@@ -167,54 +169,30 @@ public:
    */
   void moveItem(int is, int id);
   /**
-   * Calculates scaling parameters for all child items of a frame item.
-   * @param autonorm true for automatic normalization.
-   * @param item index of frame item.
-   * @param iex logarithm of normalization factor for x axis.
-   * @param iey logarithm of normalization factor for y axis.
-   * @param fx normalization factor for x axis.
-   * @param fy normalization factor for y axis.
-   * @param xmi rounded minimum x value.
-   * @param xma rounded maximum x value.
-   * @param ymi rounded minimum y value.
-   * @param yma rounded maximum y value.
-   * @param xtic major x tic distance.
-   * @param ytic major y tic distance.
-   * @param mticx intervals between major x tics.
-   * @param mticy intervals between major y tics.
-   * @param ndigx number of places after decimal point for lettering of
-   * the x axis.
-   * @param ndigy number of places after decimal point for lettering of
-   * the y axis.
-   * @param c scaling constant, desired value for tic / (xma - xmi).
-   * @param logx true for logarithmic x axis.
-   * @param logy true for logarithmic y axis.
+   * Reorders item list.
+   * @param list new index list.
    */
-  void autoScaleFrame(bool autonorm, int item, int* iex, int* iey,
-                      double*fx, double* fy, double* xmi, double* xma,
-                      double* ymi, double* yma, double* xtic, double* ytic,
-                      int* mticx, int* mticy, int* ndigx, int* ndigy,
-                      double c, bool logx, bool logy);
+  void orderItems(QValueList<int>& list);
   /**
    * Sets option structure.
    * @param opt pointer to option structure.
    */
-  void setOptions(Kpl::AutoStruct* opt);
+  inline void setOptions(KplNamespace::AutoStruct* opt) { aut = *opt; };
   /**
    * Returns option structure.
    * @return pointer to option structure.
    */
-  const Kpl::AutoStruct* options() const;
+  inline KplNamespace::AutoStruct* options() { return &aut; };
   /**
    * Returns separator for output.
    * @return separator.
    */
-  const QString& separator() const;
+  inline const QString& separator() const {return separators[aut.iSep]; };
   /**
    * Returns plot item list.
    * @return pointer to item list.
    */
-  QList<KplItem>* items();
+  inline QPtrList<KplItem>* items() { return &itd; };
   /**
    * Returns temporary filename.
    * @return filename.
@@ -230,7 +208,8 @@ public:
    * Returns formatted double value string.
    * @param val value.
    */
-  const QString number(double val) const;
+  inline const QString number(double val) const
+    { return QString::number(val, aut.format, aut.prec); };
   /**
    * Retrieves URL for saving.
    * @param parent parent widget.
@@ -301,36 +280,12 @@ signals:
 protected:
   /** Deallocates storage of all plot items. */
   void freeAllItems();
-  /**
-   * Calculates scaling parameters for an array.
-   * @param xmi pointer to double for rounded minimum value.
-   * @param xma pointer to double for rounded maximum value.
-   * @param tic pointer to double for major tic distance.
-   * @param mtic pointer to int for intervals between major tics.
-   * @param ndig pointer to int for number of places after decimal point
-   * for lettering.
-   * @param ie pointer to int for logarithm of normalization factor.
-   * @param fn pointer to double for normalization factor.
-   * @param x double array.
-   * @param n size of array.
-   * @param c scaling constant, desired value for tic / (xma - xmi).
-   * @param log true for logarithmic axis.
-   */
-  void autoFile(double* xmi, double* xma, double* tic, int* mtic,
-                int* ndig, int* ie, double* fn, const double* x, int n,
-                double c, bool log);
   /**
    * Sets array and frame item elements by autoscaling.
    * @param fd pointer to frame item.
    * @param ad pointer to array item.
    * @return true for error
    */
-  bool autoScale(FrameItem* fd, ArrayItem* ad);
-  /**
-   * Sets function item elements for autofit.
-   * @param ad pointer to array item.
-   * @param fd pointer to function item.
-   */
   void autoFit(ArrayItem* ad, FunItem* fd);
   /**
    * Inserts a widget for decimal symbol choice into a file dialog.
@@ -344,18 +299,19 @@ protected:
                            unsigned mode);
   /** The modified flag of the current document. */
   bool modified;
+  QWidget* app;
   FileType fType;
   KURL docURL;
   QString m_dir;
   QDateTime m_time;
-  QList<KplItem> itd;
-  QList<QList<KplItem> > itb;
-  Kpl::AutoStruct aut;
+  QPtrList<KplItem> itd;
+  QPtrList<QPtrList<KplItem> > itb;
+  KplNamespace::AutoStruct aut;
   QStringList separators;
   double pLast[KPL_NPMAX], pErr[KPL_NPMAX];
   double chisq;
 
-  friend class KplApp;
+  friend class Kpl;
   friend class FitDlg;
   friend class SplFitDlg;
 
