@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Wed Sep 08 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -45,11 +45,11 @@ public:
   /** Returns device type
    * @return device type
    */
-  DevTypes type() const;
+  inline DevTypes type() const { return devType; };
   /** Returns relative symbol size
    * @return relative symbol size
    */
-  double relSize() const;
+  inline double relSize() const { return relSiz; };
   /**
    * Converts from centimeters to user units.
    * @param xcm x value in centimeters.
@@ -261,10 +261,12 @@ public:
    * @param n number of points.
    * @param fillStyle > 0 for filled polygon representation.
    * @param clip false for non-clipping by frame rectangle.
+   * @param x0 x offset.
+   * @param y0 y offset.
    */
   virtual void plArray(const double* x, const double* y,
                        double fx, double fy, int n, int fillStyle = 0,
-                       bool clip = true) = 0;
+                       bool clip = true, double x0 = 0.0, double y0 = 0.0) = 0;
   /**
    * Plots error bars for an array of data points.
    * @param x array of x values in user units.
@@ -274,9 +276,12 @@ public:
    * @param fy normalization factor for y values.
    * @param n number of points.
    * @param clip false for non-clipping by frame rectangle.
+   * @param x0 x offset.
+   * @param y0 y offset.
    */
   virtual void plError(const double* x, const double* y, const double* e,
-                       double fx, double fy, int n, bool clip = true) = 0;
+                       double fx, double fy, int n, bool clip = true,
+                       double x0 = 0.0, double y0 = 0.0) = 0;
   /** Resets dash pattern position. */
   virtual void resetDash() = 0;
   /**
@@ -294,6 +299,12 @@ public:
    * @return QRgb value for actual Qt version.
    */
   static unsigned rgbQt(unsigned u);
+  /**
+   * Converts Qt1 QRgb to QRgb.
+   * @param col hexadecimal coded Qt1 rgb value.
+   * @return QRgb value for actual Qt version.
+   */
+  static unsigned rgbQt(const QString& col);
   /**
    * Converts QRgb to Qt1 QRgb.
    * @param rgb QRgb value of actual Qt version.
@@ -304,8 +315,7 @@ public:
 protected:
   bool logx, logy;
   int kSymb;
-  double relSiz;
-  double fxn, fyn;
+  double relSiz, xl, yl, xmin, xmax, ymin, ymax, fxn, fyn;
   DevTypes devType;
 
   friend class ScaledItem;
