@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Wed Aug 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -46,13 +46,21 @@ KplItem::~KplItem()
 {
 }
 
+#ifndef KPL_CLASSES_ONLY
 void KplItem::writePlo(KSimpleConfig* plo, const KURL&, bool, KplDoc*) const
 {
   if (!active)
     plo->writeEntry("active", active);
+  plo->writeEntry("x", x0);
+  plo->writeEntry("y", y0);
   plo->writeEntry("relsiz", relsiz);
 }
 
+void KplItem::exportTable(QTextStream&, KplDoc*) const
+{
+}
+#endif
+
 void KplItem::normalize(double, double)
 {
 }
@@ -69,45 +77,17 @@ void KplItem::setPar(int, double, bool)
 {
 }
 
-void KplItem::exportTable(QTextStream&, KplDoc*) const
-{
-}
-
-QRect KplItem::boundingRect() const
-{
-  return bRect;
-}
-
-double KplItem::xPos() const
-{
-  return x0;
-}
-double KplItem::yPos() const
-{
-  return y0;
-}
-
-void KplItem::setPos(double x, double y)
-{
-  x0 = x;
-  y0 = y;
-}
-
-void KplItem::setActive(bool act)
-{
-  active = act;
-}
-
 ScaledItem::ScaledItem() : fillStyle(0), symb(0), color(0), fx(1.0), fy(1.0)
 {
 }
 
-ScaledItem::ScaledItem(Kpl::AutoStruct* aut) : fillStyle(0),
+ScaledItem::ScaledItem(KplNamespace::AutoStruct* aut) : fillStyle(0),
  symb(aut->autoSymb), color(aut->colData), fx(1.0), fy(1.0)
 {
 }
 
-ScaledItem::ScaledItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) : KplItem(plo)
+ScaledItem::ScaledItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
+ KplItem(plo)
 {
   readPlo(plo, aut);
 }
@@ -116,41 +96,35 @@ ScaledItem::ScaledItem(bool act, int fill, int sym, const QString& col,
                        double fxa, double fya, double relSize) :
  KplItem(act, 0.0, 0.0, relSize), fillStyle(fill), symb(sym), fx(fxa), fy(fya)
 {
-  unsigned u;
-  sscanf(col.latin1(), "%x", &u);
-  color = KplGraph::rgbQt(u);
+  color = KplGraph::rgbQt(col);
 }
 
 ScaledItem::~ScaledItem()
 {
 }
 
-void ScaledItem::readPlo(KSimpleConfig* plo, Kpl::AutoStruct* aut)
+void ScaledItem::readPlo(KSimpleConfig* plo, KplNamespace::AutoStruct* aut)
 {
   fillStyle = plo->readNumEntry("fillstyle");
   symb = plo->readNumEntry("symb", aut->autoSymb);
   QString s = plo->readEntry("color", "");
-  if (!s.isEmpty()) {
-    unsigned u;
-    sscanf(s.latin1(), "%x", &u);
-    color = KplGraph::rgbQt(u);
-  } else
-    color = aut->colData;
+  color = s.isEmpty() ? aut->colData : KplGraph::rgbQt(s);
   fx = plo->readDoubleNumEntry("fx", 1.0);
   fy = plo->readDoubleNumEntry("fy", 1.0);
 }
 
+#ifndef KPL_CLASSES_ONLY
 void ScaledItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                           KplDoc* m) const
 {
   KplItem::writePlo(plo, url, abs, m);
   plo->writeEntry("fillstyle", fillStyle);
   plo->writeEntry("symb", symb);
-  QString s;
-  plo->writeEntry("color", s.sprintf("%x", KplGraph::rgbQt1(color)));
+  plo->writeEntry("color", QString::number(KplGraph::rgbQt1(color), 16));
   plo->writeEntry("fx", fx);
   plo->writeEntry("fy", fy);
 }
+#endif
 
 void ScaledItem::normalize(double fx0, double fy0)
 {
@@ -170,40 +144,33 @@ DecoItem::DecoItem() : color(0)
 {
 }
 
-DecoItem::DecoItem(Kpl::AutoStruct* aut) :
+DecoItem::DecoItem(KplNamespace::AutoStruct* aut) :
  color(aut->colFrame)
 {
 }
 
-DecoItem::DecoItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) : KplItem(plo)
+DecoItem::DecoItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
+ KplItem(plo)
 {
   QString s = plo->readEntry("colsymb", "");
-  if (!s.isEmpty()) {
-    unsigned u;
-    sscanf(s.latin1(), "%x", &u);
-    color = KplGraph::rgbQt(u);
-  } else
-    color = aut->colFrame;
+  color = s.isEmpty() ? aut->colFrame : KplGraph::rgbQt(s);
 }
 
 DecoItem::DecoItem(bool act, const QString& col, double x, double y,
                    double relSize) : KplItem(act, x, y, relSize)
 {
-  unsigned u;
-  sscanf(col.latin1(), "%x", &u);
-  color = KplGraph::rgbQt(u);
+  color = KplGraph::rgbQt(col);
 }
 
 DecoItem::~DecoItem()
 {
 }
 
+#ifndef KPL_CLASSES_ONLY
 void DecoItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const
 {
   KplItem::writePlo(plo, url, abs, m);
-  QString s;
-  plo->writeEntry("colsymb", s.sprintf("%x", KplGraph::rgbQt1(color)));
-  plo->writeEntry("x", x0);
-  plo->writeEntry("y", y0);
+  plo->writeEntry("colsymb", QString::number(KplGraph::rgbQt1(color), 16));
 }
+#endif
