@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Wed Aug 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,16 +22,18 @@
 #ifndef KPLITEM_H
 #define KPLITEM_H
 
+//#define KPL_CLASSES_ONLY
+
 #include <qrect.h>
-#include <qtextstream.h>
-#include <kurl.h>
 #include "kplnamespace.h"
 
+class QTextStream;
 class QWidget;
+class QListViewItem;
 class KSimpleConfig;
+class KURL;
 class KplDoc;
 class KplGraph;
-class KplCheckListItem;
 
 /**
   * Kpl item class. Base class for plot items.
@@ -73,6 +75,7 @@ public:
    * @param g pointer to KplGraph object.
    */
   virtual void draw(KplGraph* g) = 0;
+#ifndef KPL_CLASSES_ONLY
   /**
    * Writes into plot file.
    * @param plo KSimpleConfig object.
@@ -89,8 +92,7 @@ public:
    * @param funcs pointer to bool which is set true in case of an
    * ordinary or parametric function item.
    */
-  virtual void setText(KplCheckListItem* it, bool* arrays,
-                       bool* funcs) const = 0;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const = 0;
   /**
    * Opens dialog for editing the item.
    * @param parent pointer parent widget.
@@ -99,6 +101,13 @@ public:
    * @return return code of QDialog::exec().
    */
   virtual int editItem(QWidget* parent, KplDoc* m, int i) = 0;
+  /**
+   * Exports function value table to file.
+   * @param ts stream for output file.
+   * @param m KplDoc model object.
+   */
+  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
+#endif
   /**
    * Copies item.
    * @return pointer to item copy.
@@ -134,47 +143,43 @@ public:
    *  (only for parametric functions).
    */
   virtual void setPar(int i, double value, bool yFun);
-  /**
-   * Exports function value table to file.
-   * @param ts stream for output file.
-   * @param m KplDoc model object.
-   */
-  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
   /**
    * Returns boundings rectangle of the item.
    * @return boundings rectangle.
    */
-  QRect boundingRect() const;
+  inline QRect boundingRect() const { return bRect; };
   /**
    * Returns x position of the item in cm.
    * @return x position in cm.
    */
-  double xPos() const;
+  inline double xPos() const { return x0; };
   /**
    * Returns y position of the item in cm.
    * @return y position in cm.
    */
-  double yPos() const;
+  inline double yPos() const { return y0; };
   /**
    * Sets position of the item in cm.
    * @param x x position in cm.
    * @param y y position in cm.
    */
-  void setPos(double x, double y);
+  inline void setPos(double x, double y) { x0 = x; y0 = y; };
+  /**
+   * Returns activation state of the item.
+   * @return true for visible.
+   */
+  inline bool isActive() { return active; };
   /**
    * Sets activation state of the item.
-   * @param active true for visible.
+   * @param act true for visible.
    */
-  void setActive(bool active);
+  inline void setActive(bool act) { active = act; };
 
 protected:
   /** Active state of item. */
   bool active;
   double x0, y0, relsiz;
   QRect bRect;
-
-  friend class ItemDlg;
-  friend class KplDoc;
 };
 
 /**
@@ -190,20 +195,20 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  ScaledItem(Kpl::AutoStruct* aut);
+  ScaledItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  ScaledItem(KSimpleConfig* plo, Kpl::AutoStruct* aut);
+  ScaledItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
     * @param fillStyle > 0 for filled polygon representation.
     * @param symb 0 for circles, < 0 for different markers,
     * >0 for different line types.
-    * @param color color for function plot.
+    * @param color color for data plot.
     * @param fx normalization factor for x values.
     * @param fy normalization factor for y values.
     * @param relSize relative size.
@@ -217,9 +222,11 @@ public:
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  void readPlo(KSimpleConfig* plo, Kpl::AutoStruct* aut);
+  void readPlo(KSimpleConfig* plo, KplNamespace::AutoStruct* aut);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
+#endif
   virtual void normalize(double fx, double fy);
 
 protected:
@@ -236,8 +243,6 @@ protected:
   friend class FuncDlg;
   friend class ParFuncDlg;
   friend class ItemDlg;
-  friend class KplDoc;
-  friend class KplView;
 };
 
 /**
@@ -253,17 +258,17 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  DecoItem(Kpl::AutoStruct* aut);
+  DecoItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  DecoItem(KSimpleConfig* plo, Kpl::AutoStruct* aut);
+  DecoItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
-    * @param color color for function plot.
+    * @param color color for plot.
     * @param x x position in cm.
     * @param y y position in cm.
     * @param relSize relative size.
@@ -272,8 +277,10 @@ public:
            double relSize);
   /** Destructor */
   virtual ~DecoItem();
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
+#endif
 
 protected:
   unsigned color;
