@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -26,6 +26,9 @@
 #include <qdragobject.h>
 #include <qpaintdevicemetrics.h>
 #include <qtimer.h>
+#include <kapplication.h>
+#include <klocale.h>
+#include <knotifyclient.h>
 #include "frameitem.h"
 #include "funitem.h"
 #include "itemdlg.h"
@@ -35,10 +38,10 @@
 #include "splineitem.h"
 #include "utils.h"
 
-KplView::KplView(KplApp* _parent, double f) :
- KplWidget(_parent), fZoom(f), hPos(0.0), vPos(1.0)
+KplView::KplView(Kpl* _parent, double f) :
+ KplWidget(_parent), app(_parent), doc(_parent->getDocument()), fZoom(f),
+ hPos(0.0), vPos(1.0)
 {
-  doc = _parent->getDocument();
   fxn = fyn = 1.0;
   setFrameStyle(NoFrame);
   QScrollView::viewport()->setAcceptDrops(true);
@@ -50,11 +53,7 @@ KplView::~KplView()
 {
 }
 
-#if KDE_VERSION >= 220
 void KplView::print(KPrinter* printer) const
-#else
-void KplView::print(QPrinter* printer) const
-#endif
 {
   KplWidget::print(printer, doc->items());
 }
@@ -73,34 +72,16 @@ void KplView::layout()
   QTimer::singleShot(0, this, SLOT(setScrollBars()));
 }
 
-void KplView::eraseWidget()
-{
-  doPaint(false);
-}
-
-void KplView::setZoom(double f)
-{
-  fZoom = f;
-}
-
-double KplView::zoom() const
-{
-  return fZoom;
-}
-
 void KplView::doPaint(bool paint)
 {
   layout();
-  QScrollView::viewport()->setCursor(waitCursor);
-  pm.resize(contentsWidth(), contentsHeight());
-  plInit(&pm);
-  factor = fZoom;
-  format(doc->options()->xf, doc->options()->yf);
   if (paint)
-    drawItems(this, doc->items());
-  end();
+    QScrollView::viewport()->setCursor(waitCursor);
+  KplWidget::paintWidget(doc->items(), contentsWidth(), contentsHeight(),
+                         fZoom, doc->options()->xf, doc->options()->yf, paint);
   repaintContents(0, 0, pm.width(), pm.height(), false);
-  QScrollView::viewport()->setCursor(crossCursor);
+  if (paint)
+    QScrollView::viewport()->setCursor(crossCursor);
 }
 
 void KplView::slotScrollLeft()
@@ -166,6 +147,11 @@ void KplView::slotScrollEndUp()
 void KplView::paintWidget()
 {
   doPaint(true);
+  KNotifyClient::event(
+#if KDE_VERSION >= 0x030101
+                       winId(),
+#endif
+                       "PlotCompleted", i18n("Plot completed."));
 }
 
 void KplView::setScrollBars()
@@ -186,8 +172,7 @@ void KplView::contentsMousePressEvent(QMouseEvent* e)
          break;
     if (e->button() == RightButton)
       if (item)
-        ((KplApp*) parent())->itemDlg->showPopup(doc->items()->findRef(item),
-                                                 QCursor::pos());
+        app->itemDlg->showPopup(doc->items()->findRef(item), QCursor::pos());
       else
         emit rightButtonPressed();
     else
@@ -257,8 +242,8 @@ void KplView::contentsMouseReleaseEvent(QMouseEvent* e)
           }
         }
         if (it) {
-          int mnx = minx0 + qRound(scalx * factor * it->x0);
-          int mny = miny0 + qRound(scaly * factor * it->y0);
+          int mnx = minx0 + qRound(scalx * factor * it->xPos());
+          int mny = miny0 + qRound(scaly * factor * it->yPos());
           double xmi = it->logx ? log10(it->xmi) : it->xmi;
           double ymi = it->logy ? log10(it->ymi) : it->ymi;
           double xsc = qRound(scalx * factor * it->w) /
@@ -277,10 +262,7 @@ void KplView::contentsMouseReleaseEvent(QMouseEvent* e)
             yMin = pow(10, yMin);
             yMax = pow(10, yMax);
           }
-          Utils::autoSc(&it->xmi, &it->xma, &it->xtic, &it->mticx, &it->ndigx,
-                        xMin, xMax, 1.0, 0.2, it->logx);
-          Utils::autoSc(&it->ymi, &it->yma, &it->ytic, &it->mticy, &it->ndigy,
-                        yMin, yMax, 1.0, 0.2 * it->w / it->h, it->logy);
+          it->autoScale(xMin, xMax, 1.0, yMin, yMax, 1.0);
           it->xOff = it->yOff = 0.0;
           for (item = doc->items()->next(); item; item = doc->items()->next()) {
             KplItem::ItemTypes typ = item->iType();
