@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -28,16 +28,12 @@
 #endif
 
 #include <qpoint.h>
-#include <kapp.h>
+#include <qptrlist.h>
 #include <kurl.h>
 #include "kplwidget.h"
 
-#if KDE_VERSION >= 220
 class KPrinter;
-#else
-class QPrinter;
-#endif
-class KplApp;
+class Kpl;
 class KplDoc;
 
 /**
@@ -54,32 +50,28 @@ public:
    * @param parent pointer to parent widget.
    * @param f zoom factor.
    */
-  KplView(KplApp* parent, double f);
+  KplView(Kpl* parent, double f);
   /** Destructor. */
   ~KplView();
   /**
    * Contains the implementation for printing functionality.
    * @param printer printer device.
    */
-#if KDE_VERSION >= 220
   void print(KPrinter* printer) const;
-#else
-  void print(QPrinter* printer) const;
-#endif
   /** Adjusts scrollbars and page widget size. */
   void layout();
   /** Erases page widget. */
-  void eraseWidget();
+  inline void eraseWidget() { doPaint(false); };
   /**
    * Sets zoom factor.
    * @param f zoom factor.
    */
-  void setZoom(double f);
+  inline void setZoom(double f) { fZoom = f; };
   /**
    * Returns zoom factor.
    * @return zoom factor.
    */
-  double zoom() const;
+  inline double zoom() const { return fZoom; };
 
 public slots:
   /** Scrolls left. */
@@ -154,8 +146,9 @@ protected:
    * @return rectangle.
    */
   QRect sortedRect(QPoint& p1, QPoint& p2);
+  Kpl* app;
   KplDoc* doc;
-  QList<KplItem> sel;
+  QPtrList<KplItem> sel;
   double fZoom, hPos, vPos;
   QPoint startPos, dragPos;
 
