@@ -2,7 +2,7 @@
                           kplwidget.cpp  -  description
                              -------------------
     begin                : Mon Jul 16 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -15,52 +15,48 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "kplwidget.h"
-#if KDE_VERSION >= 220
+#include <qptrlist.h>
 #include <kprinter.h>
-#else
-#include <qprinter.h>
-#endif
 #include "kplitem.h"
+#include "kplwidget.h"
 
 KplWidget::KplWidget(QWidget* parent) : QScrollView(parent)
 {
   QScrollView::viewport()->setBackgroundMode(PaletteBase);
 }
 
-KplWidget::KplWidget(QWidget* parent, QList<KplItem>* items, int w, int h,
-                     double zoom) : QScrollView(parent)
+KplWidget::KplWidget(QWidget* parent, QPtrList<KplItem>* items, int w, int h,
+                     double zoom, double xf, double yf) : QScrollView(parent)
 {
   QScrollView::viewport()->setBackgroundMode(PaletteBase);
-  paintWidget(items, w, h, zoom);
+  paintWidget(items, w, h, zoom, xf, yf);
 }
 
 KplWidget::~KplWidget()
 {
 }
 
-void KplWidget::paintWidget(QList<KplItem>* items, int w, int h,
-                            double zoom)
+void KplWidget::paintWidget(QPtrList<KplItem>* items, int w, int h,
+                            double zoom, double xf, double yf, bool paint)
 {
+  if ((w != contentsWidth()) || (h != contentsHeight()))
+    resizeContents(w, h);
   pm.resize(w, h);
-  resizeContents(w, h);
   plInit(&pm);
   factor = zoom;
-  drawItems(this, items);
+  format(xf, yf);
+  if (paint)
+    drawItems(this, items);
   end();
 }
 
-void KplWidget::drawItems(KplGraph* g, QList<KplItem>* items)
+void KplWidget::drawItems(KplGraph* g, QPtrList<KplItem>* items)
 {
   for (KplItem* item = items->first(); item; item = items->next())
     item->draw(g);
 }
 
-#if KDE_VERSION >= 220
-void KplWidget::print(KPrinter* printer, QList<KplItem>* items)
-#else
-void KplWidget::print(QPrinter* printer, QList<KplItem>* items)
-#endif
+void KplWidget::print(KPrinter* printer, QPtrList<KplItem>* items)
 {
   KGraph g;
   QSize sz = printer->margins();
@@ -71,7 +67,7 @@ void KplWidget::print(QPrinter* printer, QList<KplItem>* items)
 
 QSize KplWidget::sizeHint() const
 {
-  return QSize(contentsWidth() + 5, contentsHeight() + 5);
+  return QSize(contentsWidth() + 4, contentsHeight() + 4);
 }
 
 void KplWidget::drawContents(QPainter*, int clipx, int clipy, int clipw,
