@@ -2,7 +2,7 @@
                           kplwidget.h  -  description
                              -------------------
     begin                : Mon Jul 16 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,17 +18,12 @@
 #ifndef KPLWIDGET_H
 #define KPLWIDGET_H
 
-#include <qscrollview.h>
 #include <qpixmap.h>
-#include <qlist.h>
-#include <kapp.h>
+#include <qscrollview.h>
 #include "kgraph.h"
 
-#if KDE_VERSION >= 220
+template<class> class QPtrList;
 class KPrinter;
-#else
-class QPrinter;
-#endif
 class KplItem;
 
 /**
@@ -51,9 +46,11 @@ public:
     * @param w width.
     * @param h height.
     * @param zoom magnification factor.
+    * @param xf page width in cm.
+    * @param yf page height in cm.
     */
-  KplWidget(QWidget* parent, QList<KplItem>* items, int w = 640, int h = 480,
-            double zoom = 1.0);
+  KplWidget(QWidget* parent, QPtrList<KplItem>* items, int w = 640, int h = 480,
+            double zoom = 1.0, double xf = 21.9, double yf = 29.7);
   /** Destructor. */
   ~KplWidget();
   /**
@@ -62,25 +59,25 @@ public:
     * @param w width.
     * @param h height.
     * @param zoom magnification factor.
+    * @param xf page width in cm.
+    * @param yf page height in cm.
+    * @param paint true for painting.
     */
-  void paintWidget(QList<KplItem>* items, int w = 640, int h = 480,
-                   double zoom = 1.0);
+  void paintWidget(QPtrList<KplItem>* items, int w = 640, int h = 480,
+                   double zoom = 1.0, double xf = 21.9, double yf = 29.7,
+                   bool paint = true);
   /**
     * Draws plot items.
     * @param g graphics instance.
     * @param items list of plot items.
     */
-  static void drawItems(KplGraph* g, QList<KplItem>* items);
+  static void drawItems(KplGraph* g, QPtrList<KplItem>* items);
   /**
     * Contains the implementation for printing functionality.
     * @param printer printer device.
     * @param items list of plot items.
     */
-#if KDE_VERSION >= 220
-  static void print(KPrinter* printer, QList<KplItem>* items);
-#else
-  static void print(QPrinter* printer, QList<KplItem>* items);
-#endif
+  static void print(KPrinter* printer, QPtrList<KplItem>* items);
   /**
     * Reimplemented to avoid scrollbars if not necessary.
     */
