@@ -1,12 +1,12 @@
 /***************************************************************************
-                          legenddlg.h  -  description
+                          legenddlg.cpp  -  description
                              -------------------
 
     This file is a part of kpl - a program for graphical presentation of
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -24,7 +24,7 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <klocale.h>
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 #include "kplspinbox.h"
 #include "legenddlg.h"
 #include "legenditem.h"
