@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Tue Aug 31 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -21,18 +21,20 @@
 
 #include <klocale.h>
 #include <ksimpleconfig.h>
-#include "legenditem.h"
-#include "legenddlg.h"
-#include "kplchecklistitem.h"
 #include "kgraph.h"
+#include "legenditem.h"
 #include "utils.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
+#include "legenddlg.h"
+#endif
 
 LegendItem::LegendItem() : symb(0), coltext(0),
  xtext(0.0), ytext(0.0), symbSize(1.0)
 {
 }
 
-LegendItem::LegendItem(Kpl::AutoStruct* aut) :
+LegendItem::LegendItem(KplNamespace::AutoStruct* aut) :
  DecoItem(aut), symb(aut->autoSymb), coltext(aut->colFrame), symbSize(1.0)
 {
   color = aut->colData;
@@ -43,17 +45,12 @@ LegendItem::LegendItem(Kpl::AutoStruct* aut) :
   ytext = -0.18 * dx;
 }
 
-LegendItem::LegendItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
+LegendItem::LegendItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
  DecoItem(plo, aut)
 {
   symb = plo->readNumEntry("symb", aut->autoSymb);
   QString s1 = plo->readEntry("coltext", "");
-  if (!s1.isEmpty()) {
-    unsigned u;
-    sscanf(s1.latin1(), "%x", &u);
-    coltext = KplGraph::rgbQt(u);
-  } else
-    coltext = aut->colFrame;
+  coltext = s1.isEmpty() ? aut->colFrame : KplGraph::rgbQt(s1);
   double dx = aut->xlAuto / 15.0;
   xtext = plo->readDoubleNumEntry("xtext", dx);
   ytext = plo->readDoubleNumEntry("ytext", -0.18 * dx);
@@ -68,9 +65,7 @@ LegendItem::LegendItem(bool act, int sym, const QString& colSymb,
  DecoItem(act, colSymb, x, y, relSize), symb(sym), xtext(xoff), ytext(yoff),
  symbSize(1.0), s(text)
 {
-  unsigned u;
-  sscanf(colText.latin1(), "%x", &u);
-  coltext = KplGraph::rgbQt(u);
+  coltext = KplGraph::rgbQt(colText);
 }
 
 LegendItem::~LegendItem()
@@ -116,24 +111,27 @@ void LegendItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void LegendItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                           KplDoc* m) const
 {
   plo->writeEntry("Type", "LEGENDITEM");
   DecoItem::writePlo(plo, url, abs, m);
   plo->writeEntry("symb", symb);
-  QString s1;
-  plo->writeEntry("coltext", s1.sprintf("%x", KplGraph::rgbQt1(coltext)));
+  plo->writeEntry("coltext", QString::number(KplGraph::rgbQt1(coltext), 16));
   plo->writeEntry("xtext", xtext);
   plo->writeEntry("ytext", ytext);
   plo->writeEntry("symbsize", symbSize);
   plo->writeEntry("s", s);
 }
 
-void LegendItem::setText(KplCheckListItem* it, bool*, bool*) const
+void LegendItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Legend"));
-  it->setText(2, i18n("symbol") + " " + QString::number(symb));
+  KGraph g;
+  it->setPixmap(2, g.pixmap(symb, color));
+  it->setText(2, "\"" + s + "\", x = " + QString::number(x0) +
+              " cm, y = " + QString::number(y0) + " cm");
 }
 
 int LegendItem::editItem(QWidget* parent, KplDoc* m, int)
@@ -141,6 +139,7 @@ int LegendItem::editItem(QWidget* parent, KplDoc* m, int)
   LegendDlg dlg(parent, m, this);
   return dlg.exec();
 }
+#endif
 
 KplItem* LegendItem::copy() const
 {
