@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Tue Aug 31 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,11 +22,8 @@
 #ifndef LEGENDITEM_H
 #define LEGENDITEM_H
 
-#include <qstring.h>
 #include "kplitem.h"
 
-class KplCheckListItem;
-
 /**
   * Legend item class. Class for legends items explaining markers
   * and line types.
@@ -41,13 +38,13 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  LegendItem(Kpl::AutoStruct* aut);
+  LegendItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  LegendItem(KSimpleConfig* plo, Kpl::AutoStruct* aut);
+  LegendItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
@@ -70,10 +67,12 @@ public:
   virtual ~LegendItem();
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
+#endif
   virtual KplItem* copy() const;
 
 protected:
