@@ -2,7 +2,7 @@
                           linedlg.cpp  -  description
                              -------------------
     begin                : Mon Apr 16 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -35,7 +35,7 @@ LineDlg::LineDlg(QWidget* _parent, KplDoc* model, LineItem* ld0) :
   grid->addWidget(new QLabel(i18n("Type"), frame), 3, 0);
   grid->addWidget(symb = new KplSpinBox(1, 9, 1, frame), 3, 1);
   symb->setValue(ld->symb);
-  grid->addWidget(new SymbolButton(frame, symb, true), 3, 2);
+  grid->addWidget(new SymbolButton(frame, symb, false, true), 3, 2);
 }
 
 LineDlg::~LineDlg()
