@@ -2,7 +2,7 @@
                           lineitem.cpp  -  description
                              -------------------
     begin                : Mon Apr 16 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,20 +19,22 @@
 #include <klocale.h>
 #include <ksimpleconfig.h>
 #include "kgraph.h"
-#include "kplchecklistitem.h"
-#include "linedlg.h"
 #include "lineitem.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
+#include "linedlg.h"
+#endif
 
 LineItem::LineItem() : symb(1)
 {
 }
 
-LineItem::LineItem(Kpl::AutoStruct* aut) :
+LineItem::LineItem(KplNamespace::AutoStruct* aut) :
  ArrowItem(aut), symb(1)
 {
 }
 
-LineItem::LineItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
+LineItem::LineItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
  ArrowItem(plo, aut)
 {
   symb = plo->readNumEntry("symb", 1);
@@ -77,6 +79,7 @@ void LineItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void LineItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const
 {
@@ -85,12 +88,14 @@ void LineItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
   plo->writeEntry("symb", symb);
 }
 
-void LineItem::setText(KplCheckListItem* it, bool*, bool*) const
+void LineItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Line"));
+  KGraph g;
+  it->setPixmap(2, g.pixmap(symb, color));
   QString s1, s2;
   it->setText(2, s1.sprintf("x = %g cm, y = %g cm, ", x0, y0) +
-              i18n("direction") + s2.sprintf(" %g", dir));
+              i18n("direction") + s2.sprintf(" %g\260", dir));
 }
 
 int LineItem::editItem(QWidget* parent, KplDoc* m, int)
@@ -98,6 +103,7 @@ int LineItem::editItem(QWidget* parent, KplDoc* m, int)
   LineDlg dlg(parent, m, this);
   return dlg.exec();
 }
+#endif
 
 KplItem* LineItem::copy() const
 {
