@@ -2,7 +2,7 @@
                           lineitem.h  -  description
                              -------------------
     begin                : Mon Apr 16 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -33,13 +33,13 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  LineItem(Kpl::AutoStruct* aut);
+  LineItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  LineItem(KSimpleConfig* plo, Kpl::AutoStruct* aut);
+  LineItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param active true for visible item.
@@ -57,10 +57,12 @@ public:
   ~LineItem();
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
+#endif
   virtual KplItem* copy() const;
 
 protected:
