@@ -18,18 +18,21 @@
 
 #include <float.h>
 #include <math.h>
-#include <kapp.h>
+#include <qptrlist.h>
+#include <qstring.h>
+#include <kapplication.h>
 #include <klocale.h>
-#include "lmfit.h"
-#include "kplnamespace.h"
 #include "arrayitem.h"
 #include "funitem.h"
+#include "kplnamespace.h"
+#include "lmfit.h"
 
 /*********************** lmdif.c ****************************/
 #define BUG 0
 
-LMFit::LMFit(QObject* _parent) : QObject(_parent), bFit(0), userBreak(false),
- p(0)
+LMFit::LMFit(QPtrList<ArrayItem>* _ad, QPtrList<FunItem>* _fd, bool* _bFit,
+             double* _p, QObject* _parent) : QObject(_parent), bFit(_bFit),
+ userBreak(false), p(_p), ad(_ad), fd(_fd)
 {
 }
 
@@ -42,21 +45,23 @@ bool LMFit::linFit(int nd, int np, double px[], double fvec[], double a[],
                    double wa3[], double wa4[])
 {
   int i = 0, j, ij, jj;
-  QArray<double> pt(KPL_NPMAX);
+  QMemArray<double> pt(KPL_NPMAX);
   pt.fill(0.0);
   int iflag = 0;
-  fcn(nd, np, pt, wa4, &iflag);
+  fcn(nd, np, pt.data(), wa4, &iflag);
   if (!iflag) {
     double dx = sqrt(DBL_MAX);
     ij = jj = 0;
     for (j = 0; j < KPL_NPMAX; j++)
       if (bFit[j]) {
         pt[jj] = dx;
-        fcn(nd, np, pt, &a[ij], &iflag);
+        fcn(nd, np, pt.data(), &a[ij], &iflag);
         if (iflag)
           break;
-        for (i = 0; i < nd; i++)
-          a[ij++] = (wa4[i] - a[ij]) / dx;
+        for (i = 0; i < nd; i++) {
+          a[ij] = (wa4[i] - a[ij]) / dx;
+          ++ij;
+        }
         pt[jj++] = 0.0;
       }
   }
@@ -78,7 +83,7 @@ bool LMFit::linFit(int nd, int np, double px[], double fvec[], double a[],
       jj += nd + 1;
       qtf[j] = wa4[j];
     }
-    qrsolv(np, a, nd, ipvt, pt, qtf, px, wa1, wa2);
+    qrsolv(np, a, nd, ipvt, pt.data(), qtf, px, wa1, wa2);
     fcn(nd, 1, px, fvec, &iflag);
     if (!iflag) {
       double temp = enorm(nd, fvec);
@@ -312,7 +317,7 @@ if( mode == 2 )
 		{
 		if( diag[j] <= 0.0 )
 			goto L300;
-		}	
+		}
 	}
 #if BUG
 printf( "lmdif\n" );
@@ -1309,8 +1314,8 @@ void LMFit::fcn(int, int, const double a[], double fvec[], int* iflag)
       p[i] = a[j++];
   int k = 0;
   for (i = 0; i < (int) ad->count(); i++) {
-    ArrayItem *ar = ad->at(i);
-    double (*f)(double, const double *) = fd->at(i)->fkty;
+    ArrayItem* ar = ad->at(i);
+    double (*f)(double, const double*) = fd->at(i)->fkty;
     for (j = 0; j < ar->n; j++) {
       fvec[k] = (ar->x[ar->iy][ar->istart + j] -
         (*f)(ar->x[ar->ix][ar->istart + j], p)) / sig[k];
