@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,34 +22,34 @@
 
 #include <dcopclient.h>
 #include <kaboutdata.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include "kpl.h"
 
-static const char* description =
+static const char description[] =
   I18N_NOOP("An application for plotting of data sets and functions");
 
 static KCmdLineOptions options[] = {
-  {"+[File]", I18N_NOOP("File or URL to open"), 0},
-  {0, 0, 0}
+  {"+[URL]", I18N_NOOP("Document to open"), 0},
+  KCmdLineLastOption
 };
 
 int main(int argc, char** argv)
 {
-  KAboutData aboutData("kpl", I18N_NOOP("Kpl"), VERSION, description,
-                       KAboutData::License_GPL, "(c) 2004, Werner Stille",
-                       0, 0, "stille@uni-freiburg.de");
-  aboutData.addAuthor("Werner Stille", 0, "stille@uni-freiburg.de");
-  KCmdLineArgs::init(argc, argv, &aboutData);
+  KAboutData about("kpl", I18N_NOOP("Kpl"), VERSION, description,
+                   KAboutData::License_GPL, "(c) 2005, Werner Stille", 0, 0,
+                   "stille@uni-freiburg.de");
+  about.addAuthor("Werner Stille", 0, "stille@uni-freiburg.de");
+  KCmdLineArgs::init(argc, argv, &about);
   KCmdLineArgs::addCmdLineOptions(options);
   KApplication app;
   app.dcopClient()->registerAs(app.name(), false);
   if (app.isRestored()) {
-    RESTORE(KplApp);
+    RESTORE(Kpl);
   } else {
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
-    KplApp* kpl = new KplApp;
+    Kpl* kpl = new Kpl;
     if (args->count()) {
       KURL::List list;
       for (int i = 0; i < args->count(); i++)
