@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Wed Sep 08 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,19 +19,18 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <math.h>
 #include <qfile.h>
 #include <qglobal.h>
 #include <qtextstream.h>
 #include <qdatetime.h>
 #include <kio/netaccess.h>
-#include <math.h>
 #include "psgraph.h"
 #include "utils.h"
 
 const double PSGraph::pts = 28.34645669;
 
-PSGraph::PSGraph() : x0(0.0), xl(0.0), y0(0.0), yl(0.0), xmin(0.0), xmax(0.0),
- ymin(0.0), ymax(0.0), ts(0)
+PSGraph::PSGraph() : x0(0.0), y0(0.0), ts(0)
 {
   devType = PS;
 }
@@ -40,12 +39,6 @@ PSGraph::~PSGraph()
 {
 }
 
-void PSGraph::psInit(QTextStream* t, double xf, double yf, bool orientation)
-{
-  psInit(t, xf, yf, orientation, 0, 0, qRound((orientation ? yf : xf) * pts),
-         qRound((orientation ? xf : yf) * pts));
-}
-
 void PSGraph::psInit(QTextStream* t, double xf, double yf, bool orientation,
                      int llx, int lly, int urx, int ury)
 {
@@ -266,11 +259,11 @@ void PSGraph::psInit(QTextStream* t, double xf, double yf, bool orientation,
     "   xT {/yT yma xma xmi sub rs mul xs mul ys div 0.025 mul neg sub d} if\n"
     "   /e xma 2.99 gt xmi -2.99 lt or xt 9.9 gt and\n"
     "   lx and d /nd nx d /x xmi xO add d /xe xma xmi sub\n"
-    "   1e-3 mul xma add d {\n"
+    "   1e-3 mul xma add d /tol xt 1e-6 mul d {\n"
     "    x xma gt {/x xma d} if e {(10#nu) x round cvi 4 sg cvs sc\n"
     "     xB {dup x yB rr 2 text} if xT {x yT rr 2 text} {p} IE}\n"
     "     {lx {x 0 lt {/nd 1 x 0.01 add cvi sub d} {/nd -1 d} IE}\n"
-    "     if x lx {10 ex exp} if nd pn cf sC\n"
+    "     if x lx {10 ex exp} {x abs tol lt {p 0} if} IE nd pn cf sC\n"
     "     xB {dup x yB mv SC} if xT {x yT mv SC} {p} IE}\n"
     "    IE lx {/x x xt il d} {/x x xt add d} IE x xe gt {exit} if\n"
     "   } L yL {/xL xmi xma xmi sub rs mul 0.025 mul sub d} if\n"
@@ -278,13 +271,13 @@ void PSGraph::psInit(QTextStream* t, double xf, double yf, bool orientation,
     "   /dy xma xmi sub 0.0125 mul rs mul xs mul ys div d\n"
     "   /e yma 2.99 gt ymi -2.99 lt or yt 9.9 gt and ly and d\n"
     "   /nd ny d /y ymi yO add d /ye yma ymi sub 1e-3 mul\n"
-    "   yma add d {\n"
+    "   yma add d /tol yt 1e-6 mul d {\n"
     "    y yma gt {/y yma d} if\n"
     "    e {(10#nu) y round cvi 4 sg cvs sc\n"
     "     yL {dup xL y dy sub rr 3 text} if"
     " yR {xR y dy sub rr 1 text} {p} IE}\n"
     "     {ly {y 0 lt {/nd 1 y 0.01 add cvi sub d} {/nd -1 d} IE}\n"
-    "     if y ly {10 ex exp} if nd pn cf sC\n"
+    "     if y ly {10 ex exp} {y abs tol lt {p 0} if} IE nd pn cf sC\n"
     "     yL {dup xL y dy sub mv SR} if yR {xR y dy sub mv SH} {p} IE\n"
     "    } IE ly {/y y yt il d} {/y y yt add d} IE y ye gt {exit} if\n"
     "   } L\n"
@@ -394,7 +387,7 @@ void PSGraph::psInit(QTextStream* t, double xf, double yf, bool orientation,
     "} D\n\n"
     << "%%Page: 1 1\n\n"
     "gs\n"
-    "/l1 /Helvetica EF FF 0.033333 sf\n"
+    "/l1 /Helvetica EF 0.033333 sf\n"
     "/l1B /Helvetica-Bold EF p\n"
     "/l1O /Helvetica-Oblique EF p\n"
     "/l1I /Helvetica-BoldOblique EF p\n"
@@ -459,19 +452,19 @@ void PSGraph::setDig(int nx, int ny)
 
 void PSGraph::setColFrame(unsigned icol)
 {
-  QCString s;
+  QString s;
   *ts << s.sprintf("/cf 16#%x d\n", rgbQt1(icol));
 }
 
 void PSGraph::setColGrid(unsigned icol)
 {
-  QCString s;
+  QString s;
   *ts << s.sprintf("/cg 16#%x d\n", rgbQt1(icol));
 }
 
 void PSGraph::setColData(unsigned icol)
 {
-  QCString s;
+  QString s;
   *ts << s.sprintf("/cd 16#%x d\ncd sC\n",  rgbQt1(icol));
 }
 
@@ -545,10 +538,10 @@ void PSGraph::image(const KURL& url, double x, double y, double fx, double fy,
   QString fn;
   double x1, x2, y1, y2;
   if (Utils::boundingBox(url, fn, &x1, &y1, &x2, &y2)) {
-    *ts << "save /showpage { } d 0 setlinecap 1 setlinewidth 0 setlinejoin\n"
-           "[ ] 0 setdash\n" << x << " sx mul " << y << " sx mul TR " << fx
-        << " " << fy << " scale\n" << -x1 << " " << -y1 << " TR " << x1 << " "
-        << y1 << " " << x2 << " " << y2 << " re clip\n"
+    *ts << "save /showpage { } d 0 setlinecap 1 setlinewidth 0 setlinejoin "
+           "0 setgray\n[ ] 0 setdash\n" << x << " sx mul " << y
+        << " sx mul TR " << fx << " " << fy << " scale\n" << -x1 << " " << -y1
+        << " TR " << x1 << " " << y1 << " " << x2 << " " << y2 << " re clip\n"
         << "%%BeginDocument: " << url.path() << "\n";
     ts->device()->flush();
     QFile f(fn);
@@ -598,15 +591,16 @@ void PSGraph::setSymbol(int is)
 }
 
 void PSGraph::plArray(const double* x, const double* y,
-                      double fx, double fy, int n, int fillStyle, bool clip)
+                      double fx, double fy, int n, int fillStyle, bool clip,
+                      double xOff, double yOff)
 {
   if (n > 0)
     if (fillStyle) {
       bool pl = false;
-      QCString s;
+      QString s;
       for (int i = 0; i < n; i++) {
-        double xa = fx * x[i];
-        double ya = fy * y[i];
+        double xa = fx * (xOff + x[i]);
+        double ya = fy * (yOff + y[i]);
         if (Utils::valid(xa, logx) && Utils::valid(ya, logy)) {
           xa = (((logx ? log10(xa) : xa) - xmin) / (xmax - xmin) * xl + x0)
                * pts;
@@ -635,11 +629,26 @@ void PSGraph::plArray(const double* x, const double* y,
         ia = QMIN(n - 1, ie + 127);
         *ts << "\n";
         int fail = 0;
-        QCString s;
+        QString s;
         for (int i = ia; i >= ie; i--) {
-          double xa = xNorm ? (fx * x[i]) : x[i];
-          double ya = yNorm ? (fy * y[i]) : y[i];
-          if (Utils::valid(xa, logx) && Utils::valid(ya, logy))
+          double xa = xOff + x[i];
+          if (xNorm)
+            xa *= fx;
+          double ya = yOff + y[i];
+          if (yNorm)
+            ya *= fy;
+          bool b = Utils::valid(xa, logx) && Utils::valid(ya, logy);
+          if (b && (kSymb <= 0)) {
+            double t = xNorm ? xa : fx * xa;
+            b = (fabs(((logx ? log10(t) : t) - xmin) /
+                      (xmax - xmin) - 0.5) <= 1.0);
+            if (b) {
+              t = yNorm ? ya : fy * ya;
+              b = (fabs(((logy ? log10(t) : t) - ymin) /
+                        (ymax - ymin) - 0.5) <= 1.0);
+            }
+          }
+          if (b)
             *ts << xa << " " << ya << "\n";
           else
             fail++;
@@ -656,7 +665,8 @@ void PSGraph::plArray(const double* x, const double* y,
 }
 
 void PSGraph::plError(const double* x, const double* y, const double* e,
-                      double fx, double fy, int n, bool clip)
+                      double fx, double fy, int n, bool clip, double xOff,
+                      double yOff)
 {
   if (n > 0) {
     int ie = 0;
@@ -667,10 +677,14 @@ void PSGraph::plError(const double* x, const double* y, const double* e,
       ia = QMIN(n - 1, ie + 127);
       *ts << "\n";
       int fail = 0;
-      QCString s;
+      QString s;
       for (int i = ia; i >= ie; i--) {
-        double xa = xNorm ? (fx * x[i]) : x[i];
-        double ya = yNorm ? (fy * y[i]) : y[i];
+        double xa = xOff + x[i];
+        if (xNorm)
+          xa *= fx;
+        double ya = yOff + y[i];
+        if (yNorm)
+          ya *= fy;
         double ea = yNorm ? (fy * e[i]) : e[i];
         if (Utils::valid(xa, logx) && Utils::valid(ya, logy) &&
             Utils::valid(ea, logy))
@@ -695,11 +709,11 @@ void PSGraph::psExit(void)
   *ts << "\nshowpage gr\n\n%%Trailer\n%%EOF\n";
 }
 
-void PSGraph::psStr(const char* str)
+void PSGraph::psStr(const QString& str)
 {
   *ts << "(";
-  QCString s;
-  const unsigned char* c = (const unsigned char*) str;
+  QString s;
+  const unsigned char* c = (const unsigned char*) str.latin1();
   while (*c) {
     if (*c > 127)
       *ts << s.sprintf("\\%03o", *c);
