@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Wed Sep 08 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -46,7 +46,11 @@ public:
    * @param yf height of page in cm.
    * @param orientation true for landscape orientation.
    */
-  void psInit(QTextStream* ts, double xf, double yf, bool orientation = false);
+  inline void psInit(QTextStream* ts, double xf, double yf,
+                     bool orientation = false) {
+    psInit(ts, xf, yf, orientation, 0, 0,
+           qRound((orientation ? yf : xf) * pts),
+           qRound((orientation ? xf : yf) * pts)); };
   /**
    * Initializes PostScript graphics.
    * @param ts pointer to stream opened for write access.
@@ -96,9 +100,10 @@ public:
   virtual void setSymbol(int is);
   virtual void plArray(const double* x, const double* y,
                        double fx, double fy, int n, int fillStyle = 0,
-                       bool clip = true);
+                       bool clip = true, double x0 = 0.0, double y0 = 0.0);
   virtual void plError(const double* x, const double* y, const double* e,
-                       double fx, double fy, int n, bool clip = true);
+                       double fx, double fy, int n, bool clip = true,
+                       double x0 = 0.0, double y0 = 0.0);
   virtual void resetDash();
   /** Ends PostScript graphic and closes output stream. */
   void psExit();
@@ -110,7 +115,7 @@ protected:
    * Converts to PostScript string.
    * @param str text.
    */
-  void psStr(const char* str);
+  void psStr(const QString& str);
   /**
    * Plots text.
    * @param str text.
@@ -119,7 +124,7 @@ protected:
    * @param iorg 1: left aligned, 2: centered, 3: right aligned.
    */
   void text(const QString& str, double x, double y, int iorg);
-  double x0, xl, y0, yl, xmin, xmax, ymin, ymax;
+  double x0, y0;
   QTextStream* ts;
 };
 
