@@ -2,7 +2,7 @@
                           rectdlg.h  -  description
                              -------------------
     begin                : Sat Apr 28 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,9 +18,10 @@
 #ifndef RECTDLG_H
 #define RECTDLG_H
 
-#include <decodlg.h>
+#include "decodlg.h"
 
 class BrushButton;
+class QCheckBox;
 class RectItem;
 
 /**
@@ -49,10 +50,16 @@ protected:
    */
   void getValues(bool accept);
   RectItem* rd;
+  QCheckBox* isotropic;
   BrushButton* fill;
   KplDoubleEdit *eWidth, *eHeight, *eDir;
 
 protected slots:
+  /**
+   * Sets height widget.
+   * @param iso true to set widget for isotropic scaling.
+   */
+  void slotAspect(bool iso);
   /** Applies settings and leaves the dialog. */
   virtual void slotOk();
   /** Applies settings without leaving the dialog. */
