@@ -2,7 +2,7 @@
                           rectitem.cpp  -  description
                              -------------------
     begin                : Sat Apr 28 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -15,25 +15,27 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <ksimpleconfig.h>
 #include <klocale.h>
-#include "kplchecklistitem.h"
+#include <ksimpleconfig.h>
 #include "kgraph.h"
-#include "rectdlg.h"
 #include "rectitem.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
+#include "rectdlg.h"
+#endif
 
 RectItem::RectItem() : fillStyle(0), width(3.0), height(2.0), dir(0.0)
 {
 }
 
-RectItem::RectItem(Kpl::AutoStruct* aut) :
+RectItem::RectItem(KplNamespace::AutoStruct* aut) :
  DecoItem(aut), fillStyle(0), width(3.0), height(2.0), dir(0.0)
 {
   x0 = aut->x0Auto + 0.5 * aut->xlAuto - 1.5;
   y0 = aut->y0Auto + 0.5 * aut->ylAuto - 1.0;
 }
 
-RectItem::RectItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
+RectItem::RectItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
  DecoItem(plo, aut)
 {
   fillStyle = plo->readNumEntry("fillstyle");
@@ -74,6 +76,7 @@ void RectItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void RectItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const
 {
@@ -86,9 +89,11 @@ void RectItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
     plo->writeEntry("dir", dir);
 }
 
-void RectItem::setText(KplCheckListItem* it, bool*, bool*) const
+void RectItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Rectangle"));
+  KGraph g;
+  it->setPixmap(2, g.pixmap(fillStyle ? -13 : -3, color));
   QString s1, s2;
   it->setText(2, s1.sprintf("x = %g cm, y = %g cm, ", x0, y0) + i18n("size")
               + s2.sprintf(" %g cm x %g cm", width, height));
@@ -100,6 +105,7 @@ int RectItem::editItem(QWidget* parent, KplDoc* m, int)
   dlg.setCaption(i18n("Rectangle"));
   return dlg.exec();
 }
+#endif
 
 KplItem* RectItem::copy() const
 {
