@@ -2,7 +2,7 @@
                           rootdlg.cpp  -  description
                              -------------------
     begin                : Sam Jan 25 2003
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -21,9 +21,9 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qtable.h>
+#include <qtextstream.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include "fitpack.h"
 #include "kpldoc.h"
 #include "kpldoubleedit.h"
 #include "rootdlg.h"
@@ -69,15 +69,14 @@ RootDlg::~RootDlg()
 
 void RootDlg::findRoots()
 {
-  int nz, ier;
+  int nz;
   int mest = 3 * spl->nk;
-  QArray<double> zero(mest);
+  QMemArray<double> zero(mest);
   int cond = eCond->currentItem();
   bool extrema = (cond > 2);
   update->setDisabled(extrema);
   double offset = extrema ? 0.0 : eOff->value();
-  FitPack::sproot(spl->t.data(), spl->nk, spl->c.data(), zero.data(), mest,
-                  &nz, &ier, extrema ? 1 : cond, offset);
+  spl->roots(zero.data(), mest, &nz, extrema ? 1 : cond, offset);
   int count = 0;
   if (nz) {
     table->setNumRows(nz);
@@ -86,8 +85,7 @@ void RootDlg::findRoots()
     for (int i = 0; i < nz; ++i) {
       double y[3];
       for (int j = 0; j < 3; ++j)
-        FitPack::splder(spl->t.data(), spl->nk, spl->c.data(), 3, j, &zero[i],
-                        &y[j], 1, &ier);
+        spl->calcValues(&zero[i], &y[j], 1, j);
       bool insert = true;
       switch (cond) {
         case 3:
