@@ -2,7 +2,7 @@
                           sourcewidget.cpp  -  description
                              -------------------
     begin                : Sun Apr 16 2000
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -15,9 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qtextstream.h>
 #include <qfile.h>
-#include <kapp.h>
+#include <qtextstream.h>
 #include <kglobalsettings.h>
 #include "sourcewidget.h"
 
@@ -26,12 +25,8 @@ SourceWidget::SourceWidget(QWidget* _parent, QFile* f) :
 {
   setFont(KGlobalSettings::fixedFont());
   setReadOnly(true);
-#if KDE_VERSION_MAJOR > 2
   setUndoRedoEnabled(false);
   setWordWrap(NoWrap);
-#else
-  setUndoEnabled(false);
-#endif
   if (f)
     fill(f);
 }
@@ -44,13 +39,7 @@ void SourceWidget::fill(QFile *f)
 {
   setAutoUpdate(false);
   clear();
-#if KDE_VERSION_MAJOR > 2
   append(QTextStream(f).read());
-#else
-  QTextStream t(f);
-  while (!t.eof())
-    append(t.readLine());
-#endif
   f->close();
   setAutoUpdate(true);
   repaint();
@@ -77,11 +66,6 @@ void SourceWidget::slotHighlight()
 {
   if (col1 > 0) {
     setCursorPosition(line + 15, col1);
-#if KDE_VERSION_MAJOR > 2
     setSelection(line, col1, line, col2);
-#else
-    setCursorPosition(line, col1);
-    setCursorPosition(line, col2, true);
-#endif
   }
 }
