@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,21 +19,26 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qlabel.h>
-#include <qradiobutton.h>
 #include <qbuttongroup.h>
+#include <qlabel.h>
 #include <qlayout.h>
-#include <kapp.h>
-#include <klocale.h>
+#include <qradiobutton.h>
+#include <kapplication.h>
 #include <kiconloader.h>
+#include <klocale.h>
 #include "kplspinbox.h"
 #include "symboldlg.h"
 
-SymbolButton::SymbolButton(QWidget* _parent, KplSpinBox* sb, bool lines) :
+SymbolButton::SymbolButton(QWidget* _parent, KplSpinBox* sb, bool disable,
+                           bool lines) :
  QPushButton(_parent), symb(sb), linesOnly(lines)
 {
   setButtonSymbol(symb->value());
   setFixedSize(50, 24);
+  if (disable) {
+    setDisabled(disable);
+    symb->setDisabled(disable);
+  }
   connect(symb, SIGNAL(valueChanged(int)), SLOT(setButtonSymbol(int)));
   connect(this, SIGNAL(clicked()), SLOT(slotSymbol()));
 }
@@ -46,7 +51,7 @@ void SymbolButton::setButtonSymbol(int isymb)
 {
   QString s;
   if (isymb > 0)
-#if KDE_VERSION >= 0x03015a
+#if KDE_VERSION >= 0x030200
     setPixmap(QPixmap(kapp->iconLoader()->iconPath(s.sprintf("line%i", isymb),
                                                    0)));
 #else
@@ -106,7 +111,7 @@ SymbolDlg::SymbolDlg(QWidget* _parent, KplSpinBox* sb0, bool lines) :
     grid->addWidget(r = new QRadioButton(QString::number(i + 1), g1), i, 1);
     bg->insert(r);
     grid->addWidget(l = new QLabel(g1), i, 0);
-#if KDE_VERSION >= 0x03015a
+#if KDE_VERSION >= 0x030200
     l->setPixmap(QPixmap(kapp->iconLoader()->iconPath(s.sprintf("line%i",
                                                                 i + 1), 0)));
 #else
