@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -42,9 +42,11 @@ public:
    * Constructor.
    * @param parent pointer to parent widget.
    * @param sb pointer to QSpinBox containing the symbol number.
+   * @param disable true for disabled button and spinbox.
    * @param linesOnly true to allow only lines.
    */
-  SymbolButton(QWidget* parent, KplSpinBox* sb, bool linesOnly = false);
+  SymbolButton(QWidget* parent, KplSpinBox* sb, bool disable = false,
+               bool linesOnly = false);
   /** Destructor. */
   ~SymbolButton();
 
