@@ -2,7 +2,7 @@
                           textdlg.cpp  -  description
                              -------------------
     begin                : Wed Apr 18 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -15,16 +15,16 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qcombobox.h>
 #include <qpushbutton.h>
 #include <qstringlist.h>
 #include <klocale.h>
 #include "edittextdlg.h"
 #include "kpldoubleedit.h"
-#include "textitem.h"
 #include "textdlg.h"
+#include "textitem.h"
 
 TextDlg::TextDlg(QWidget* _parent, KplDoc* model, TextItem* td0) :
  DecoDlg(_parent, i18n("Text"), "SEC-TEXT", model, td0, 4), td(td0)
@@ -39,7 +39,7 @@ TextDlg::TextDlg(QWidget* _parent, KplDoc* model, TextItem* td0) :
   grid->addWidget(new QLabel(i18n("Direction"), frame), 1, 0);
   grid->addWidget(eDir = new KplDoubleEdit(td->dir, -360.0, 360.0, frame),
                   1, 1);
-  grid->addWidget(new QLabel("", frame), 1, 2);
+  grid->addWidget(new QLabel("\260", frame), 1, 2);
   grid->addWidget(new QLabel(i18n("Alignment"), frame), 1, 4);
   grid->addWidget(eAlign = new QComboBox(false, frame), 1, 5);
   QStringList list;
