@@ -2,7 +2,7 @@
                           textitem.cpp  -  description
                              -------------------
     begin                : Wed Apr 18 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -17,24 +17,26 @@
 
 #include <klocale.h>
 #include <ksimpleconfig.h>
-#include "kplchecklistitem.h"
 #include "kgraph.h"
-#include "utils.h"
-#include "textdlg.h"
 #include "textitem.h"
+#include "utils.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
+#include "textdlg.h"
+#endif
 
 TextItem::TextItem() : iAlign(1), dir(0.0)
 {
 }
 
-TextItem::TextItem(Kpl::AutoStruct* aut) :
+TextItem::TextItem(KplNamespace::AutoStruct* aut) :
  DecoItem(aut), iAlign(1), dir(0.0)
 {
   x0 = aut->x0Auto + 0.5 * aut->xlAuto;
   y0 = aut->y0Auto + 0.5 * aut->ylAuto;
 }
 
-TextItem::TextItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
+TextItem::TextItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
  DecoItem(plo, aut)
 {
   iAlign = plo->readNumEntry("align", 1);
@@ -72,6 +74,7 @@ void TextItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void TextItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const
 {
@@ -82,12 +85,11 @@ void TextItem::writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
   plo->writeEntry("s", s);
 }
 
-void TextItem::setText(KplCheckListItem* it, bool*, bool*) const
+void TextItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("Text"));
-  QString s1, s2;
-  it->setText(2, s1.sprintf("x = %g cm, y = %g cm, ", x0, y0) +
-              i18n("direction") + s2.sprintf(" %g", dir));
+  it->setText(2, "\"" + s + "\", x = " + QString::number(x0) +
+              " cm, y = " + QString::number(y0) + " cm");
 }
 
 int TextItem::editItem(QWidget* parent, KplDoc* m, int)
@@ -95,6 +97,7 @@ int TextItem::editItem(QWidget* parent, KplDoc* m, int)
   TextDlg dlg(parent, m, this);
   return dlg.exec();
 }
+#endif
 
 KplItem* TextItem::copy() const
 {
