@@ -2,7 +2,7 @@
                           threeddlg.cpp  -  description
                              -------------------
     begin                : Thu Apr 25 2002
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,13 +22,11 @@
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qlibrary.h>
 #include <qlineedit.h>
 #include <qradiobutton.h>
-#include <kapp.h>
-#if KDE_VERSION_MAJOR < 3
-#include <qmultilineedit.h>
-#endif
-#include <kcolorbtn.h>
+#include <qtextstream.h>
+#include <kcolorbutton.h>
 #include <kfiledialog.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -98,11 +96,11 @@ ThreeDDlg::ThreeDDlg(QWidget* _parent, KplDoc* model, ThreeDItem *td0,
   grid2 = new QGridLayout(g->layout(), 2, 3, spacingHint());
   grid2->addWidget(new QLabel("phi", g), 0, 0);
   grid2->addWidget(ePhi = new KplDoubleEdit(td->phi, -360.0, 360.0, g), 0, 1);
-  grid2->addWidget(new QLabel("", g), 0, 2);
+  grid2->addWidget(new QLabel("\260", g), 0, 2);
   grid2->addWidget(new QLabel("theta", g), 1, 0);
   grid2->addWidget(eTheta = new KplDoubleEdit(td->theta, -360.0, 360.0, g),
                    1, 1);
-  grid2->addWidget(new QLabel("", g), 1, 2);
+  grid2->addWidget(new QLabel("\260", g), 1, 2);
   grid->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Automatic"),
                   frame), 1, 2);
   QVBoxLayout* vbox2 = new QVBoxLayout(g->layout(), spacingHint());
@@ -242,17 +240,7 @@ void ThreeDDlg::initRange(QGridLayout* grid, int row)
   grid->addWidget(exMax = new KplDoubleEdit(td->xma, g1, frm, prec), row, 4);
   exMax->setMinimumWidth(w);
   grid->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), row, 5);
-#if KDE_VERSION_MAJOR > 2
   grid->addWidget(new QLabel(QString::fromUtf8("\316\224x"), g1), row, 6);
-#else
-  QHBoxLayout* hbox = new QHBoxLayout(1);
-  grid->addLayout(hbox = new QHBoxLayout(1), row, 6);
-  QLabel* l = new QLabel("D", g1);
-  l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
-  hbox->addWidget(l);
-  hbox->addWidget(new QLabel("x", g1));
-  hbox->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding));
-#endif
   grid->addWidget(exStep = new KplDoubleEdit(td->dx, g1, frm, prec), row, 7);
   exStep->setMinimumWidth(w);
   grid->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), row, 8);
@@ -270,16 +258,7 @@ void ThreeDDlg::initRange(QGridLayout* grid, int row)
   grid->addWidget(new QLabel("zmax", g1), row, 3);
   grid->addWidget(ezMax = new KplDoubleEdit(td->zma, g1, frm, prec), row, 4);
   ezMax->setMinimumWidth(w);
-#if KDE_VERSION_MAJOR > 2
   grid->addWidget(new QLabel(QString::fromUtf8("\316\224z"), g1), row, 6);
-#else
-  grid->addLayout(hbox = new QHBoxLayout(1), row, 6);
-  l = new QLabel("D", g1);
-  l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
-  hbox->addWidget(l);
-  hbox->addWidget(new QLabel("z", g1));
-  hbox->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding));
-#endif
   grid->addWidget(ezStep = new KplDoubleEdit(td->dz, g1, frm, prec), row, 7);
   ezStep->setMinimumWidth(w);
   grid->addWidget(logZ = new QCheckBox("log", g1), row, 9);
@@ -505,10 +484,9 @@ bool Fun3DDlg::getTemp()
 {
   fdt->pathy = fileName->text();
   fdt->namey = func->text();
-  if (fdt->hmody)
-    lt_dlclose(fdt->hmody);
-  if (Fun3DItem::getFunc3DAddr(fdt->pathy.path(), fdt->namey, &fdt->hmody,
-                           &fdt->fkty))
+  delete fdt->liby;
+  if (!Fun3DItem::getFunc3DAddr(fdt->pathy.path(), fdt->namey, &fdt->liby,
+                                &fdt->fkty))
     return false;
   return true;
 }
@@ -631,19 +609,14 @@ Array3DDlg::Array3DDlg(QWidget* _parent, KplDoc* model, Array3DItem *ad0) :
   if (!ad->internal)
     fileName->setText(ad->url.isLocalFile() ?  ad->url.path() : ad->url.url());
   fileName->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-#if QT_VERSION >= 0x030100
   fileName->setSizePolicy(QSizePolicy::MinimumExpanding,
                           QSizePolicy::Minimum);
-#else
-  fileName->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
-                                      QSizePolicy::Minimum));
-#endif
   QPushButton* b = new QPushButton("...", g);
   b->setFixedWidth(28);
   hbox->addWidget(b);
   connect(b, SIGNAL(clicked()), SLOT(slotFile()));
   hbox->addWidget(bReload = new QPushButton(g));
-  bReload->setPixmap(BarIcon("reload"));
+  bReload->setIconSet(BarIconSet("reload"));
   bReload->setDisabled(fileName->text().isEmpty());
   connect(bReload, SIGNAL(clicked()), SLOT(slotReload()));
   grid->addLayout(hbox = new QHBoxLayout(), 1, 1);
@@ -803,6 +776,7 @@ void Array3DDlg::slotFile()
     disconnect(internal, SIGNAL(toggled(bool)), this,
                SLOT(slotInternal(bool)));
     internal->setChecked(false);
+    edit->setEnabled(false);
     connect(internal, SIGNAL(toggled(bool)), SLOT(slotInternal(bool)));
   }
 }
@@ -895,22 +869,13 @@ void Array3DDlg::slotEdit()
     for (int j = 0; j < src->ncols; j++)
       t << m->number(src->xv[j][i])
         << (j < (src->ncols - 1) ? m->separator() : QString("\n"));
-#if KDE_VERSION_MAJOR > 2
   EditDlg dlg(this, &buf, m->options()->prec + 4);
-#else
-  int sav = QMultiLineEdit::defaultTabStop();
-  QMultiLineEdit::setDefaultTabStop(m->options()->prec + 4);
-  EditDlg dlg(this, &buf);
-#endif
   connect(&dlg, SIGNAL(applyClicked()), SLOT(slotEditApply()));
   if (dlg.exec()) {
     delete adt;
     adt = new Array3DItem;
     readData(true);
   }
-#if KDE_VERSION_MAJOR < 3
-  QMultiLineEdit::setDefaultTabStop(sav);
-#endif
 }
 
 void Array3DDlg::slotEditApply()
