@@ -2,7 +2,7 @@
                           threeditem.cpp  -  description
                              -------------------
     begin                : Tue Dec 25 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -15,30 +15,35 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <stdlib.h>
 #include <float.h>
 #include <math.h>
-#include <qurl.h>
+#include <stdlib.h>
 #include <qfileinfo.h>
-#include <ksimpleconfig.h>
+#include <qlibrary.h>
+#include <qtextstream.h>
+#include <qurl.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include "threeditem.h"
+#include <ksimpleconfig.h>
 #include "arrayitem.h"
-#include "kgraph.h"
-#include "utils.h"
-#include "kplchecklistitem.h"
-#include "kpldoc.h"
 #include "fitpack.h"
+#include "kgraph.h"
+#include "splineitem.h"
+#include "threeditem.h"
+#include "utils.h"
+#ifndef KPL_CLASSES_ONLY
+#include <qlistview.h>
 #include "framedlg.h"
+#include "kpldoc.h"
 #include "threeddlg.h"
+#endif
 
 static int sortCol;
 
 static int cmpasc(const void *e1, const void *e2)
 {
-  double a1 = (*((double **) e1))[sortCol];
-  double a2 = (*((double **) e2))[sortCol];
+  double a1 = (*((double**) e1))[sortCol];
+  double a2 = (*((double**) e2))[sortCol];
   if (a1 < a2)
     return -1;
   if (a1 > a2)
@@ -79,16 +84,16 @@ ThreeDItem::ThreeDItem(const ThreeDItem& a) :
   yv = ArrayItem::copyX(a.yv, a.nx, a.nz);
 }
 
-ThreeDItem::ThreeDItem(Kpl::AutoStruct* aut) : FrameItem(aut), showFrame(true),
- logz(false), logxo(false), logzo(false), ndigz(-1), mticz(5), iez(0),
- mode3D(2), colData(aut->colData), zmi(0.0), zma(15.0), dx(0.0), dz(0.0),
- ztic(5.0), phi(20.0), theta(-20.0), boxx(7.5), boxy(7.5), boxz(7.5),
+ThreeDItem::ThreeDItem(KplNamespace::AutoStruct* aut) : FrameItem(aut),
+ showFrame(true), logz(false), logxo(false), logzo(false), ndigz(-1), mticz(5),
+ iez(0), mode3D(2), colData(aut->colData), zmi(0.0), zma(15.0), dx(0.0),
+ dz(0.0), ztic(5.0), phi(20.0), theta(-20.0), boxx(7.5), boxy(7.5), boxz(7.5),
  xref(7.5), yref(4.0), fx(1.0), fy(1.0), fz(1.0), xmio(0.0), xmao(0.0),
  dxo(0.0), zmio(0.0), zmao(0.0), dzo(0.0), yv(0)
 {
 }
 
-ThreeDItem::ThreeDItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
+ThreeDItem::ThreeDItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut) :
  FrameItem(plo, aut), logxo(false), logzo(false), xmio(0.0), xmao(0.0),
  dxo(0.0), zmio(0.0), zmao(0.0), dzo(0.0), yv(0)
 {
@@ -99,12 +104,7 @@ ThreeDItem::ThreeDItem(KSimpleConfig* plo, Kpl::AutoStruct* aut) :
   iez = plo->readNumEntry("iez");
   mode3D = plo->readNumEntry("mode3d", 2);
   QString s = plo->readEntry("coldata", "");
-  if (!s.isEmpty()) {
-    unsigned u;
-    sscanf(s.latin1(), "%x", &u);
-    colData = KplGraph::rgbQt(u);
-  } else
-    colData = aut->colData;
+  colData = s.isEmpty() ? aut->colData : KplGraph::rgbQt(s);
   zmi = plo->readDoubleNumEntry("zmi");
   zma = plo->readDoubleNumEntry("zma", zmi + 1.0);
   dx = plo->readDoubleNumEntry("dx");
@@ -135,7 +135,7 @@ ThreeDItem::ThreeDItem(bool act, bool lgx, bool lgy, bool lgz, bool frame,
                        double b_y, double b_z, double xr, double yr,
                        double f_x, double f_y, double f_z, const QString& sX,
                        const QString& sY, const QString& sZ, const QString& sH,
-                       Kpl::AutoStruct* aut) :
+                       KplNamespace::AutoStruct* aut) :
  FrameItem(act, lgx, lgy, ndx, ndy, mtx, mty, gm, ex, ey, col_f, col_g, x_0,
            wx, y_0, hy, xmin, xmax, ymin, ymax, xt, yt, relSize, sX, sY, sH,
            aut),
@@ -145,9 +145,7 @@ ThreeDItem::ThreeDItem(bool act, bool lgx, bool lgy, bool lgz, bool frame,
  xref(xr), yref(yr), fx(f_x), fy(f_y), fz(f_z), xmio(0.0), xmao(0.0), dxo(0.0),
  zmio(0.0), zmao(0.0), dzo(0.0), yv(0), sz(sZ), p3d(2000)
 {
-  unsigned u;
-  sscanf(col_d.latin1(), "%x", &u);
-  colData = KplGraph::rgbQt(u);
+  colData = KplGraph::rgbQt(col_d);
 }
 
 ThreeDItem::~ThreeDItem()
@@ -230,6 +228,7 @@ void ThreeDItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void ThreeDItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
                           KplDoc* m) const
 {
@@ -241,8 +240,7 @@ void ThreeDItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
   plo->writeEntry("mticz", mticz);
   plo->writeEntry("iez", iez);
   plo->writeEntry("mode3d", mode3D);
-  QString s;
-  plo->writeEntry("coldata", s.sprintf("%x", KplGraph::rgbQt1(colData)));
+  plo->writeEntry("coldata", QString::number(KplGraph::rgbQt1(colData), 16));
   plo->writeEntry("zmi", zmi);
   plo->writeEntry("zma", zma);
   plo->writeEntry("dx", dx);
@@ -269,6 +267,7 @@ void ThreeDItem::exportTable(QTextStream& ts, KplDoc* m) const
          << m->number(zmi + iz * zStep) << m->separator()
          << m->number(yv[ix][iz]) << "\n";
 }
+#endif
 
 void ThreeDItem::rot3d(double phi, double theta)
 {
@@ -334,8 +333,8 @@ void ThreeDItem::plot3d(KplGraph* g, bool xArr, bool yArr, bool zArr,
   int jOld = -1;
   double xOld = 0.0;
   double yOld = 0.0;
-  QArray<double> xBuf(nPnts);
-  QArray<double> yBuf(nPnts);
+  QMemArray<double> xBuf(nPnts);
+  QMemArray<double> yBuf(nPnts);
   int nBuf = 0;
   if (firstLine)
     for (int i = 0; i < p3d.nRes; i++) {
@@ -405,7 +404,7 @@ void ThreeDItem::plot3d(KplGraph* g, bool xArr, bool yArr, bool zArr,
               if ((low ^ lowOld) && (high ^ highOld)) {
                 if (nBuf > 1) {
                   yBuf[nBuf - 1] = lowOld ? ymi1 : yma1;
-                  g->plArray(xBuf, yBuf, 1.0, 1.0, nBuf);
+                  g->plArray(xBuf.data(), yBuf.data(), 1.0, 1.0, nBuf);
                   xBuf[0] = xBuf[nBuf - 1];
                   yBuf[0] = low ? ymi1 : yma1;
                 }
@@ -419,7 +418,7 @@ void ThreeDItem::plot3d(KplGraph* g, bool xArr, bool yArr, bool zArr,
           } else { // not visible
             if (nBuf > 1) {
               yBuf[nBuf - 1] = lowOld ? ymi1 : yma1;
-              g->plArray(xBuf, yBuf, 1.0, 1.0, nBuf);
+              g->plArray(xBuf.data(), yBuf.data(), 1.0, 1.0, nBuf);
             }
             nBuf = 0;
           }
@@ -459,7 +458,7 @@ void ThreeDItem::plot3d(KplGraph* g, bool xArr, bool yArr, bool zArr,
     xOutOld = xOut;
   }
   if (nBuf > 1)
-    g->plArray(xBuf, yBuf, 1.0, 1.0, nBuf);
+    g->plArray(xBuf.data(), yBuf.data(), 1.0, 1.0, nBuf);
 }
 
 void ThreeDItem::frame3d(KplGraph* g, int ihcor)
@@ -751,7 +750,7 @@ void ThreeDItem::plar3d(KplGraph* g)
   p3d.yOff = yref - p3d.a21 * x - p3d.a23 * z;
   if (mode3D != 1) {
     x = fx * scalx * (logx ? log10(xmi) : xmi);
-    QArray<double> y(nx);
+    QMemArray<double> y(nx);
     bool dec = (p3d.a11 * p3d.a22 * zStep > 0.0);
     for (int nline = 0; nline < nz; nline++) {
       int lz = dec ? (nz - 1 - nline) : nline;
@@ -760,13 +759,13 @@ void ThreeDItem::plar3d(KplGraph* g)
         double ya = QMIN(QMAX(yv[i][lz], ymi), yma);
         y[i] = logy ? log10(ya / ymi) : (fy * (ya - ymi));
       }
-      plot3d(g, false, true, false, &x, y, &z, fx * xStep * scalx, scaly,
-             0.0, nline == 0, nx, p3d.xOff, p3d.yOff, vertex);
+      plot3d(g, false, true, false, &x, y.data(), &z, fx * xStep * scalx,
+             scaly, 0.0, nline == 0, nx, p3d.xOff, p3d.yOff, vertex);
     }
   }
   if (mode3D != 0) {
     z = fz * (logz ? log10(zmi) : zmi) * scalz;
-    QArray<double> y(nz);
+    QMemArray<double> y(nz);
     bool dec = (p3d.a13 * p3d.a22 * xStep < 0.0);
     for (int nline = 0; nline < nx; nline++) {
       int lx = dec ? (nx - 1 - nline) : nline;
@@ -775,38 +774,36 @@ void ThreeDItem::plar3d(KplGraph* g)
         double ya = QMIN(QMAX(yv[lx][i], ymi), yma);
         y[i] = logy ? log10(ya / ymi) : (fy * (ya - ymi));
       }
-      plot3d(g, false, true, false, &x, y, &z, 0.0, scaly,
+      plot3d(g, false, true, false, &x, y.data(), &z, 0.0, scaly,
              fz * zStep * scalz, nline == 0, nz, p3d.xOff, p3d.yOff, vertex);
     }
   }
   g->setRelSize(sav);
 }
 
-Fun3DItem::Fun3DItem() : fkty(0), fktyo(0), hmody(0)
+Fun3DItem::Fun3DItem() : fkty(0), fktyo(0), liby(0)
 {
   init();
 }
 
 Fun3DItem::Fun3DItem(const Fun3DItem& f) : ThreeDItem(f), fkty(f.fkty),
- fktyo(f.fktyo), namey(f.namey), pathy(f.pathy), hmody(f.hmody)
+ fktyo(f.fktyo), namey(f.namey), pathy(f.pathy), liby(0)
 {
-  lt_dlinit();
   memcpy(py, f.py, sizeof(py));
   memcpy(pyo, f.pyo, sizeof(pyo));
-  if (f.hmody)
-    getFunc3DAddr(pathy.path(), namey, &hmody, &fkty);
+  if (f.liby)
+    getFunc3DAddr(pathy.path(), namey, &liby, &fkty);
 }
 
-Fun3DItem::Fun3DItem(Kpl::AutoStruct* aut) : ThreeDItem(aut), fkty(0), fktyo(0),
- hmody(0)
+Fun3DItem::Fun3DItem(KplNamespace::AutoStruct* aut) : ThreeDItem(aut), fkty(0),
+ fktyo(0), liby(0)
 {
   init();
 }
 
-Fun3DItem::Fun3DItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
+Fun3DItem::Fun3DItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
                      const KURL& uPlo) : ThreeDItem(plo, aut), fktyo(0)
 {
-  lt_dlinit();
   memset(pyo, 0, sizeof(pyo));
   QStringList list = plo->readListEntry("p", ' ');
   int cnt = list.count();
@@ -815,7 +812,7 @@ Fun3DItem::Fun3DItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
   namey = plo->readEntry("name", "");
   QString s = plo->readEntry("path", "");
   pathy = QUrl::isRelativeUrl(s) ? (uPlo.directory(false) + s) : s;
-  getFunc3DAddr(pathy.path(), namey, &hmody, &fkty);
+  getFunc3DAddr(pathy.path(), namey, &liby, &fkty);
 }
 
 Fun3DItem::Fun3DItem(bool act, bool lgx, bool lgy, bool lgz, bool frame,
@@ -831,22 +828,20 @@ Fun3DItem::Fun3DItem(bool act, bool lgx, bool lgy, bool lgz, bool frame,
                      double f_y, double f_z, const QString& sX,
                      const QString& sY, const QString& sZ, const QString& sH,
                      const QString& name, const KURL& path,
-                     Kpl::AutoStruct* aut) :
+                     KplNamespace::AutoStruct* aut) :
  ThreeDItem(act, lgx, lgy, lgz,frame, ndx, ndy, ndz, mtx, mty, mtz, gm, gm3,
             ex, ey, ez, col_f, col_g, col_d, x_0, wx, y_0, hy, xmin, xmax,
             ymin, ymax, zmin, zmax, d_x, d_z, xt, yt, zt, relSize, phi_,
             theta_, b_x, b_y, b_z, xr, yr, f_x, f_y, f_z, sX, sY, sZ, sH, aut),
- fkty(0), fktyo(0), namey(name), pathy(path), hmody(0)
+ fkty(0), fktyo(0), namey(name), pathy(path), liby(0)
 {
   init();
-  getFunc3DAddr(pathy.path(), namey, &hmody, &fkty);
+  getFunc3DAddr(pathy.path(), namey, &liby, &fkty);
 }
 
 Fun3DItem::~Fun3DItem()
 {
-  if (hmody)
-    lt_dlclose(hmody);
-  lt_dlexit();
+  delete liby;
 }
 
 Fun3DItem& Fun3DItem::operator=(const Fun3DItem& f)
@@ -859,11 +854,10 @@ Fun3DItem& Fun3DItem::operator=(const Fun3DItem& f)
     memcpy(pyo, f.pyo, sizeof(pyo));
     namey = f.namey;
     pathy = f.pathy;
-    if (hmody)
-      lt_dlclose(hmody);
-    hmody = 0;
-    if (f.hmody)
-      getFunc3DAddr(pathy.path(), namey, &hmody, &fkty);
+    delete liby;
+    liby = 0;
+    if (f.liby)
+      getFunc3DAddr(pathy.path(), namey, &liby, &fkty);
   }
   return *this;
 }
@@ -881,6 +875,7 @@ void Fun3DItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void Fun3DItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
                          KplDoc* m) const
 {
@@ -894,15 +889,15 @@ void Fun3DItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
   plo->writeEntry("zma", zma, true, false, frm, prec);
   plo->writeEntry("dx", dx, true, false, frm, prec);
   plo->writeEntry("dz", dz, true, false, frm, prec);
-  QStrList list;
+  QStringList list;
   for (int i = 0; i < KPL_NPMAX; i++)
-    list.insert(i, m->number(py[i]));
+    list.append(m->number(py[i]));
   plo->writeEntry("p", list, ' ');
   plo->writeEntry("name", namey);
   plo->writeEntry("path", Utils::relPath(url, pathy, _abs));
 }
 
-void Fun3DItem::setText(KplCheckListItem* it, bool*, bool*) const
+void Fun3DItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("3D function"));
   QFileInfo fi(pathy.path());
@@ -915,6 +910,13 @@ int Fun3DItem::editItem(QWidget* parent, KplDoc* m, int)
   return dlg.exec();
 }
 
+void Fun3DItem::exportTable(QTextStream& ts, KplDoc* m) const
+{
+  calcTable();
+  ThreeDItem::exportTable(ts, m);
+}
+#endif
+
 KplItem* Fun3DItem::copy() const
 {
   return new Fun3DItem(*this);
@@ -925,38 +927,33 @@ void Fun3DItem::setPar(int i, double value, bool)
   py[i] = value;
 }
 
-void Fun3DItem::exportTable(QTextStream& ts, KplDoc* m) const
-{
-  calcTable();
-  ThreeDItem::exportTable(ts, m);
-}
-
 bool Fun3DItem::getFunc3DAddr(const QString& path, const QString& name,
-                              lt_dlhandle* hmod,
+                              QLibrary** lib,
                               double (**fkt)(double, double, const double*))
 {
-  *hmod = 0;
+  *lib = 0;
   *fkt = 0;
   if (path.isEmpty() || name.isEmpty())
     KMessageBox::sorry(0, i18n("no library or no function specified!"));
-  else
-    if (!(*hmod = lt_dlopen(path)))
-      KMessageBox::error(0, lt_dlerror());
+  else {
+    *lib = new QLibrary(path);
+    if (!(*lib)->load())
+      KMessageBox::error(0, path + "\n" + i18n("library cannot be opened!"));
     else
       if ((*fkt = (double (*)(double, double, const double *))
-                  lt_dlsym(*hmod, name)))
-        return false;
-      else {
-        KMessageBox::error(0, lt_dlerror());
-        lt_dlclose(*hmod);
-        *hmod = 0;
-      }
-  return true;
+                  (*lib)->resolve(name)))
+        return true;
+      else
+        KMessageBox::error(0, path + ": " + name + "\n" +
+                           i18n("function name cannot be resolved!"));
+    delete *lib;
+    *lib = 0;
+  }
+  return false;
 }
 
 void Fun3DItem::init()
 {
-  lt_dlinit();
   memset(py, 0, sizeof(py));
   memset(pyo, 0, sizeof(pyo));
 }
@@ -991,8 +988,8 @@ int Fun3DItem::calcTable() const
     yv = new double*[nx];
     for (int ix = 0; ix < nx; ix++) {
       yv[ix] = &y1[ix * nz];
+      double xa = (logx ? log10(xmi) : xmi) + ix * xStep;
       for (int iz = 0; iz < nz; iz++) {
-        double xa = (logx ? log10(xmi) : xmi) + ix * xStep;
         double za = (logz ? log10(zmi) : zmi) + iz * zStep;
         yv[ix][iz] = ((*fkty)((logx ? pow(10.0, xa) : xa),
                               (logz ? pow(10.0, za) : za), py));
@@ -1030,7 +1027,7 @@ Array3DItem::Array3DItem(const Array3DItem& a) : ThreeDItem(a),
   xv = ArrayItem::copyX(a.xv, a.ncols, a.nrows);
 }
 
-Array3DItem::Array3DItem(Kpl::AutoStruct* aut) : ThreeDItem(aut),
+Array3DItem::Array3DItem(KplNamespace::AutoStruct* aut) : ThreeDItem(aut),
  internal(false), ix(aut->ixAuto), iy(aut->iyAuto), iz(2), ie(aut->ieAuto),
  istart(0), n(0), errbars(aut->autoErr), nrows(0), ncols(0), idec(aut->iDec),
  ixo(0), iyo(0), izo(0), ieo(0), istarto(0), no(0), errbarso(0), smf(0.0),
@@ -1038,7 +1035,7 @@ Array3DItem::Array3DItem(Kpl::AutoStruct* aut) : ThreeDItem(aut),
 {
 }
 
-Array3DItem::Array3DItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
+Array3DItem::Array3DItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
                          const KURL& uPlo) : ThreeDItem(plo, aut),
  ix(0), iy(0), iz(0), ie(0), istart(0), n(0), errbars(0), ixo(0), iyo(0),
  izo(0), ieo(0), istarto(0), no(0), errbarso(0), smfo(0.0), xv(0)
@@ -1046,10 +1043,10 @@ Array3DItem::Array3DItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
   QString s = plo->readEntry("path", "");
   url = QUrl::isRelativeUrl(s) ? (uPlo.directory(false) + s) : s;
   url.cleanPath();
-  internal = plo->readNumEntry("internal", false);
+  internal = plo->readBoolEntry("internal");
   if (internal) {
     n = nrows = plo->readNumEntry("n");
-    ncols = 3;
+    ncols = plo->readListEntry("r0", ' ').count();
     idec = 0;
     double* x1 = new double[ncols * nrows];
     xv = new double*[ncols];
@@ -1096,7 +1093,7 @@ Array3DItem::Array3DItem(bool act, bool lgx, bool lgy, bool lgz, bool frame,
                      const QString& sY, const QString& sZ, const QString& sH,
                      int i_x, int i_y, int i_z, int i_e, int i_start, int np,
                      int errb, double _smf, const KURL& u,
-                     Kpl::AutoStruct* aut, bool _int, int iDec) :
+                     KplNamespace::AutoStruct* aut, bool _int, int iDec) :
  ThreeDItem(act, lgx, lgy, lgz,frame, ndx, ndy, ndz, mtx, mty, mtz, gm, gm3,
             ex, ey, ez, col_f, col_g, col_d, x_0, wx, y_0, hy, xmin, xmax,
             ymin, ymax, zmin, zmax, d_x, d_z, xt, yt, zt, relSize, phi_,
@@ -1106,7 +1103,7 @@ Array3DItem::Array3DItem(bool act, bool lgx, bool lgy, bool lgz, bool frame,
 {
   if (internal) {
     n = nrows = np;
-    ncols = 3;
+    ncols = QMIN(3, QMAX(QMAX(QMAX(ix, iy), iz), ie) + 1);
     idec = 0;
     int dim = ncols * nrows;
     double* x1 = new double[dim];
@@ -1174,6 +1171,7 @@ void Array3DItem::draw(KplGraph* g)
   }
 }
 
+#ifndef KPL_CLASSES_ONLY
 void Array3DItem::writePlo(KSimpleConfig* plo, const KURL& uPlo, bool _abs,
                            KplDoc* m) const
 {
@@ -1190,9 +1188,9 @@ void Array3DItem::writePlo(KSimpleConfig* plo, const KURL& uPlo, bool _abs,
   if (internal) {
     plo->writeEntry("istart", 0);
     for (int i = 0; i < n; i++) {
-      QStrList list;
+      QStringList list;
       for (int j = 0; j < ncols; j++)
-        list.insert(j, QString::number(xv[j][i + istart]));
+        list.append(QString::number(xv[j][i + istart]));
       QString s;
       plo->writeEntry(s.sprintf("r%i", i), list, ' ');
     }
@@ -1203,10 +1201,11 @@ void Array3DItem::writePlo(KSimpleConfig* plo, const KURL& uPlo, bool _abs,
   }
 }
 
-void Array3DItem::setText(KplCheckListItem* it, bool*, bool*) const
+void Array3DItem::setText(QListViewItem* it, bool*, bool*) const
 {
   it->setText(1, i18n("3D array"));
-  it->setText(2, i18n("file") + " " + url.fileName());
+  it->setText(2, internal ? i18n("internal data") :
+                            (i18n("file") + " " + url.fileName()));
 }
 
 int Array3DItem::editItem(QWidget* parent, KplDoc* m, int)
@@ -1215,16 +1214,17 @@ int Array3DItem::editItem(QWidget* parent, KplDoc* m, int)
   return dlg.exec();
 }
 
-KplItem* Array3DItem::copy() const
-{
-  return new Array3DItem(*this);
-}
-
 void Array3DItem::exportTable(QTextStream& ts, KplDoc* m) const
 {
   calcTable();
   ThreeDItem::exportTable(ts, m);
 }
+#endif
+
+KplItem* Array3DItem::copy() const
+{
+  return new Array3DItem(*this);
+}
 
 void Array3DItem::calcTable() const
 {
@@ -1253,7 +1253,7 @@ void Array3DItem::calcTable() const
     yv = new double*[nx];
     for (int i = 0; i < nx; i++)
       yv[i] = &y1[i * nz];
-    int nkx, nkz, ier, nk, k, k1, nest, lwrk;
+    int nkx, nkz, ier;
     double xmin, xmax, zmin, zmax, fp;
     Utils::minMaxFile(&xmin, &xmax, &xv[ix][istart], n);
     Utils::minMaxFile(&zmin, &zmax, &xv[iz][istart], n);
@@ -1269,10 +1269,10 @@ void Array3DItem::calcTable() const
       zmin = log10(zmin);
       zmax = log10(zmax);
     }
-    QArray<double> xi(nx);
+    QMemArray<double> xi(nx);
     for (int i = 0; i < nx; i++)
       xi[i] = (logx ? log10(xmi) : xmi) + i * xStep;
-    QArray<double> zi(nz);
+    QMemArray<double> zi(nz);
     for (int i = 0; i < nz; i++)
       zi[i] = (logz ? log10(zmi) : zmi) + i * zStep;
     if (smf == 0.0) {
@@ -1288,8 +1288,8 @@ void Array3DItem::calcTable() const
       qsort(a2, n, sizeof(double*), cmpasc);
       int ib = 0;
       nkz = 0;
-      QArray<double> z;
-      QArray<double*> c2;
+      QMemArray<double> z;
+      QMemArray<double*> c2;
       while (ib < n) {
         int j = ib + 1;
         while ((j < n) && (a2[j][1] == a2[j - 1][1]))
@@ -1304,58 +1304,40 @@ void Array3DItem::calcTable() const
         }
         sortCol = 0;
         qsort(b2, nkx, sizeof(double*), cmpasc);
-        QArray<double> x(nkx);
-        QArray<double> y(nkx);
-        QArray<double> wt(nkx);
+        QMemArray<double> x(nkx);
+        QMemArray<double> y(nkx);
         for (int i = 0; i < nkx; i++) {
           x[i] = b2[i][0];
           y[i] = b2[i][1];
-          wt[i] = 1.0;
         }
-        k = QMIN(3, nkx - 1);
-        k1 = k + 1;
-        nest = nkx + k1;
-        QArray<double> t(nest);
-        QArray<double> c(nest);
-        QArray<int> iwrk(nest);
-        lwrk = nkx * k1 + nest * (7 + 3 * k);
-        QArray<double> wrk(lwrk);
-        FitPack::curfit(0, nkx, x, y, wt, xmin, xmax, k, 0.0, nest, &nk,
-                        t.data(), c.data(), &fp, wrk.data(), lwrk,
-                        iwrk.data(), &ier);
-        if (ier < 4) {
-          z.resize(nkz + 1);
-          z[nkz] = a2[ib][1];
-          c2.resize(nkz + 1);
-          c2[nkz] = new double[nx];
-          FitPack::splev(t, nk, c, k, xi, c2[nkz++], nx, &ier);
-        }
-        ArrayItem::freeX(&b2);
+        SplineItem spl(QMIN(3, nkx - 1));
+        ier = spl.interpolation(x.data(), y.data(), nkx, xmin, xmax);
+        if (ier > 3)
+          break;
+        z.resize(nkz + 1);
+        z[nkz] = a2[ib][1];
+        c2.resize(nkz + 1);
+        c2[nkz] = new double[nx];
+        spl.calcValues(xi.data(), c2[nkz++], nx);
+        delete [] b1;
+        delete [] b2;
         ib += nkx;
       }
-      QArray<double> y(nkz);
-      QArray<double> wt(nkz);
-      for (int i = 0; i < nkz; i++)
-        wt[i] = 1.0;
-      k = QMIN(3, nkz - 1);
-      k1 = k + 1;
-      nest = nkz + k1;
-      QArray<double> t(nest);
-      QArray<double> c(nest);
-      QArray<int> iwrk(nest);
-      lwrk = nkz * k1 + nest * (7 + 3 * k);
-      QArray<double> wrk(lwrk);
-      for (int j = 0; j < nx; j++) {
-        for (int i = 0; i < nkz; i++)
-          y[i] = c2[i][j];
-        FitPack::curfit(0, nkz, z, y, wt, zmin, zmax, k, 0.0, nest, &nk,
-                        t.data(), c.data(), &fp, wrk.data(), lwrk,
-                        iwrk.data(), &ier);
-        if (ier < 4)
-          FitPack::splev(t, nk, c, k, zi, yv[j], nz, &ier);
+      if (ier < 4) {
+        QMemArray<double> y(nkz);
+        for (int j = 0; j < nx; j++) {
+          for (int i = 0; i < nkz; i++)
+            y[i] = c2[i][j];
+          SplineItem spl(QMIN(3, nkz - 1));
+          ier = spl.interpolation(z.data(), y.data(), nkz, zmin, zmax);
+          if (ier < 4)
+            spl.calcValues(zi.data(), yv[j], nz);
+        }
       }
-      ArrayItem::freeX(&a2);
+      delete [] a1;
+      delete [] a2;
     } else {
+      int nk, k, k1, nest, lwrk;
       int iopt = 0;
       k = 3;
       k1 = k + 1;
@@ -1367,9 +1349,9 @@ void Array3DItem::calcTable() const
       int ib3 = k1 * nk + 1;
       lwrk = nk * nk * (ib1 + 2 + ib3) +
              2 * (nrint + nest * (k1 + 1) + n * k1) + ib3 + 1;
-      QArray<double> x(n);
-      QArray<double> z(n);
-      QArray<double> wt(n);
+      QMemArray<double> x(n);
+      QMemArray<double> z(n);
+      QMemArray<double> wt(n);
       bool errcol = errbars && (ie < ncols);
       for (int i = 0; i < n; i++) {
         x[i] = xv[ix][istart + i];
@@ -1380,15 +1362,17 @@ void Array3DItem::calcTable() const
            z[i] = log10(z[i]);
         wt[i] = errcol ? (1.0 / xv[ie][istart + i]) : 1.0;
       }
-      QArray<double> tx(nest);
-      QArray<double> tz(nest);
-      QArray<double> c(nk * nk);
-      QArray<double> wrk(lwrk);
-      FitPack::surfit(iopt, n, x.data(), z.data(), &xv[iy][istart], wt,
+      QMemArray<double> tx(nest);
+      QMemArray<double> tz(nest);
+      QMemArray<double> c(nk * nk);
+      QMemArray<double> wrk(lwrk);
+      FitPack::surfit(iopt, n, x.data(), z.data(), &xv[iy][istart], wt.data(),
                       xmin, xmax, zmin, zmax, k, k, smf * smf * n, nest, nest,
                       nest, DBL_EPSILON, &nkx, tx.data(), &nkz, tz.data(),
                       c.data(), &fp, wrk.data(), lwrk, &ier);
-      FitPack::bispev(tx, nkx, tz, nkz, c, k, k, xi, nx, zi, nz, yv[0], &ier);
+      if (ier < 6)
+        FitPack::bispev(tx.data(), nkx, tz.data(), nkz, c.data(), k, k,
+                        xi.data(), nx, zi.data(), nz, yv[0], &ier);
     }
   }
   xmio = xmi;
