@@ -2,7 +2,7 @@
                           threeditem.h  -  description
                              -------------------
     begin                : Tue Dec 25 2001
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,9 +18,11 @@
 #ifndef THREEDITEM_H
 #define THREEDITEM_H
 
-#include "ltdl.h"
+#include <kurl.h>
 #include "frameitem.h"
 
+class QLibrary;
+
 /**
   * 3D item class. Base class for 3D array items and 3d function items.
   * @author Werner Stille
@@ -36,13 +38,13 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  ThreeDItem(Kpl::AutoStruct* aut);
+  ThreeDItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  ThreeDItem(KSimpleConfig* plo, Kpl::AutoStruct* aut);
+  ThreeDItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param act true for visible item.
@@ -108,15 +110,17 @@ public:
              double theta_, double b_x, double b_y, double b_z, double xr,
              double yr, double f_x, double f_y, double f_z, const QString& sX,
              const QString& sY, const QString& sZ, const QString& sH,
-             Kpl::AutoStruct* aut);
+             KplNamespace::AutoStruct* aut);
   /** Destructor */
   ~ThreeDItem();
   /** Assignment operator */
   ThreeDItem& operator=(const ThreeDItem& a);
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
   virtual void exportTable(QTextStream& ts, KplDoc* m) const;
+#endif
 
 protected:
   /**
@@ -244,14 +248,15 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  Fun3DItem(Kpl::AutoStruct* aut);
+  Fun3DItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     * @param url URL of plot file.
     */
-  Fun3DItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& url);
+  Fun3DItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
+            const KURL& url);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param act true for visible item.
@@ -320,29 +325,32 @@ public:
             double b_z, double xr, double yr, double f_x, double f_y,
             double f_z, const QString& sX, const QString& sY,
             const QString& sZ, const QString& sH, const QString& name,
-            const KURL& url, Kpl::AutoStruct* aut);
+            const KURL& url, KplNamespace::AutoStruct* aut);
   /** Destructor */
   ~Fun3DItem();
   /** Assignment operator */
   Fun3DItem& operator=(const Fun3DItem& f);
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
+  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
+#endif
   virtual KplItem* copy() const;
   virtual void setPar(int i, double value, bool yFun);
-  virtual void exportTable(QTextStream& ts, KplDoc* m) const;
   /**
    * Gets module handle and address of a shared library function for 3D plots.
    * @param path path of the library.
    * @param name function name.
-   * @param hmod pointer to module handle.
+   * @param lib pointer to library.
    * @param fkt pointer to function address.
+   * @return true for success.
    */
   static bool getFunc3DAddr(const QString& path, const QString& name,
-                            lt_dlhandle* hmod,
+                            QLibrary** lib,
                             double (**fkt)(double, double, const double*));
 
 protected:
@@ -360,10 +368,10 @@ protected:
   mutable double pyo[20];
   QString namey;
   KURL pathy;
-  lt_dlhandle hmody;
+  QLibrary* liby;
 
   friend class Fun3DDlg;
-  friend class KplApp;
+  friend class Kpl;
 };
 
 class Array3DItem : public ThreeDItem
@@ -377,13 +385,14 @@ public:
     * Constructor. Initializes corresponding to autoplot settings.
     * @param aut pointer to structure containing autoplot settings.
     */
-  Array3DItem(Kpl::AutoStruct* aut);
+  Array3DItem(KplNamespace::AutoStruct* aut);
   /**
     * Constructor. Initializes corresponding to plot file.
     * @param plo pointer to KSimpleConfig object containing item data.
     * @param aut pointer to structure containing autoplot settings.
     */
-  Array3DItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& uPlo);
+  Array3DItem(KSimpleConfig* plo, KplNamespace::AutoStruct* aut,
+              const KURL& uPlo);
   /**
     * Constructor. Initializes corresponding to arguments.
     * @param act true for visible item.
@@ -462,7 +471,7 @@ public:
               double f_y, double f_z, const QString& sX, const QString& sY,
               const QString& sZ, const QString& sH, int i_x, int i_y, int i_z,
               int i_e, int i_start, int np, int errb, double _smf,
-              const KURL& u, Kpl::AutoStruct* aut, bool _int = false,
+              const KURL& u, KplNamespace::AutoStruct* aut, bool _int = false,
               int idec = 0);
   /** Destructor */
   ~Array3DItem();
@@ -470,12 +479,14 @@ public:
   Array3DItem& operator=(const Array3DItem& a);
   virtual ItemTypes iType() const;
   virtual void draw(KplGraph* g);
+#ifndef KPL_CLASSES_ONLY
   virtual void writePlo(KSimpleConfig* plo, const KURL& url, bool abs,
                         KplDoc* m) const;
-  virtual void setText(KplCheckListItem* it, bool* arrays, bool* funcs) const;
+  virtual void setText(QListViewItem* it, bool* arrays, bool* funcs) const;
   virtual int editItem(QWidget* parent, KplDoc* m, int i);
-  virtual KplItem* copy() const;
   virtual void exportTable(QTextStream& ts, KplDoc* m) const;
+#endif
+  virtual KplItem* copy() const;
 
 protected:
   /**
@@ -491,7 +502,7 @@ protected:
   KURL url;
 
   friend class Array3DDlg;
-  friend class KplApp;
+  friend class Kpl;
 };
 
 #endif
