@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,21 +19,15 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <math.h>
 #include <qfile.h>
 #include <qwidget.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <kio/netaccess.h>
 #include <kurl.h>
 #include "utils.h"
 
-bool Utils::valid(double x, bool logx)
-{
-  return (x == x) && (fabs(x) <= 1.0e300) && ((!logx) || (x > 0));
-}
-
 bool Utils::minMaxFile(double* xmin, double* xmax, const double* x, int n)
 {
   *xmin = 1.0e300;
@@ -248,7 +242,7 @@ bool Utils::boundingBox(const KURL& url, QString& filename, double* x1,
   if (url.isLocalFile())
     filename = url.path();
   else
-#if KDE_VERSION >= 0x03015a
+#if KDE_VERSION >= 0x030200
     if (!KIO::NetAccess::download(url, filename, 0))
 #else
     if (!KIO::NetAccess::download(url, filename))
@@ -277,13 +271,7 @@ bool Utils::boundingBox(const KURL& url, QString& filename, double* x1,
 void Utils::translate(QString& line, int idec)
 {
   if (idec)
-#if KDE_VERSION_MAJOR > 2
     line.replace(',', '.');
   line.replace('D', 'E');
   line.replace('d', 'e');
-#else
-    line.replace(QRegExp(","), ".");
-  line.replace(QRegExp("D"), "E");
-  line.replace(QRegExp("d"), "e");
-#endif
 }
