@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2004 by Werner Stille
+    copyright            : (C) 2005 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,8 +22,10 @@
 #ifndef UTILS_H
 #define UTILS_H
 
+#include <math.h>
 #include <qstring.h>
 
+class QWidget;
 class KURL;
 
 /**
@@ -40,7 +42,8 @@ public:
    * @param logx true for use as argument of log function.
    * @return true for valid.
    */
-  static bool valid(double x, bool logx = false);
+  static inline bool valid(double x, bool logx = false)
+    { return (x == x) && (fabs(x) <= 1.0e300) && ((!logx) || (x > 0)); };
   /**
    * Calculates minimum and maximum values of an array.
    * @param xmin pointer to minimum value.
